
IF NOT EXISTS ( SELECT  1
                FROM    systypes
                WHERE   name = 'udtBoolean' ) 
    CREATE TYPE udtBoolean FROM BIT
go

IF NOT EXISTS ( SELECT  1
                FROM    systypes
                WHERE   name = 'udtByte' ) 
    CREATE TYPE udtByte FROM TINYINT
go

IF NOT EXISTS ( SELECT  1
                FROM    systypes
                WHERE   name = 'udtDateTime' ) 
    CREATE TYPE udtDateTime FROM DATETIME
go

IF NOT EXISTS ( SELECT  1
                FROM    systypes
                WHERE   name = 'udtFloat' ) 
    CREATE TYPE udtFloat FROM FLOAT
go

IF NOT EXISTS ( SELECT  1
                FROM    systypes
                WHERE   name = 'udtId' ) 
    CREATE TYPE udtId FROM BIGINT NOT NULL
go

IF NOT EXISTS ( SELECT  1
                FROM    systypes
                WHERE   name = 'udtInteger' ) 
    CREATE TYPE udtInteger FROM INT
go

IF NOT EXISTS ( SELECT  1
                FROM    systypes
                WHERE   name = 'udtLong' ) 
    CREATE TYPE udtLong FROM BIGINT
go

IF NOT EXISTS ( SELECT  1
                FROM    systypes
                WHERE   name = 'udtName' ) 
    CREATE TYPE udtName FROM VARCHAR(50)
go

IF NOT EXISTS ( SELECT  1
                FROM    systypes
                WHERE   name = 'udtNameId' ) 
    CREATE TYPE udtNameId FROM VARCHAR(50) NOT NULL
go

IF NOT EXISTS ( SELECT  1
                FROM    systypes
                WHERE   name = 'udtStringSize1024' ) 
    CREATE TYPE udtStringSize1024 FROM VARCHAR(1024)
go

IF NOT EXISTS ( SELECT  1
                FROM    systypes
                WHERE   name = 'udtStringSize128' ) 
    CREATE TYPE udtStringSize128 FROM VARCHAR(128)
go

IF NOT EXISTS ( SELECT  1
                FROM    systypes
                WHERE   name = 'udtStringSize2048' ) 
    CREATE TYPE udtStringSize2048 FROM VARCHAR(2048)
go

IF NOT EXISTS ( SELECT  1
                FROM    systypes
                WHERE   name = 'udtStringSize255' ) 
    CREATE TYPE udtStringSize255 FROM VARCHAR(255)
go

IF NOT EXISTS ( SELECT  1
                FROM    systypes
                WHERE   name = 'udtStringSize4096' ) 
    CREATE TYPE udtStringSize4096 FROM VARCHAR(4096)
go

IF NOT EXISTS ( SELECT  1
                FROM    systypes
                WHERE   name = 'udtStringSize512' ) 
    CREATE TYPE udtStringSize512 FROM VARCHAR(512)
go

IF NOT EXISTS ( SELECT  1
                FROM    systypes
                WHERE   name = 'udtStringSize8000' ) 
    CREATE TYPE udtStringSize8000 FROM VARCHAR(8000)
go

IF NOT EXISTS ( SELECT  1
                FROM    systypes
                WHERE   name = 'udtDecimal10_4' ) 
    CREATE TYPE udtDecimal10_4 FROM DECIMAL(10,4)
go

IF NOT EXISTS ( SELECT  1
                FROM    systypes
                WHERE   name = 'udtNumeric10_2' ) 
    CREATE TYPE udtNumeric10_2 FROM NUMERIC(10,2)
go

IF EXISTS ( SELECT  name
            FROM    sysobjects
            WHERE   name = 'PadL'
                    AND type = 'FN' ) 
    DROP FUNCTION dbo.PadL
GO

CREATE FUNCTION [dbo].[PadL](@nvalor INTEGER, @cvalor VARCHAR(100), @nlen INTEGER, @cchar CHAR(1))

RETURNS VARCHAR(500)

AS

BEGIN

  DECLARE @creturn VARCHAR(500)

  IF @nvalor IS NOT NULL
    SET @creturn = LTRIM(RTRIM(CONVERT(VARCHAR(500),@nvalor)))
  ELSE
    SET @creturn = LTRIM(RTRIM(@cvalor))


  IF LEN(@creturn) < @nlen
    SET @creturn = REPLICATE(@cchar,@nlen - LEN(@creturn)) + @creturn
  ELSE
    SET @creturn = LEFT(@creturn,@nlen)

  RETURN (@creturn)

END


GO

IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'[dbo].[relch_clave]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE [dbo].[relch_clave]
            (
              [empresa] [numeric](18, 0) NOT NULL ,
              [clave] [numeric](18, 0) NOT NULL ,
              [descripcion] [char](50) NULL
            )
        ON  [PRIMARY]
        ALTER TABLE [dbo].[relch_clave] WITH NOCHECK ADD 
        CONSTRAINT [PK_relch_clave] PRIMARY KEY  CLUSTERED 
        (
        [empresa],
        [clave]
        )  ON [PRIMARY] 

    END

GO

IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'[dbo].[relch_exep]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE [dbo].[relch_exep]
            (
              [empresa] [numeric](18, 0) NOT NULL ,
              [codigo] [numeric](18, 0) NOT NULL ,
              [nochecar] [char](1) NULL ,
              [tarde] [char](1) NULL ,
              [mintarde] [numeric](18, 0) NULL ,
              [chora] [char](1) NULL ,
              [aus] [char](1) NULL ,
              [notmp_extra] [char](1) NULL ,
              [hor_esp] [char](1) NULL ,
              [hcomida] [char](1) NULL ,
              [entra1] [char](8) NULL ,
              [sale1] [char](8) NULL ,
              [entra2] [char](8) NULL ,
              [sale2] [char](8) NULL
            )
        ON  [PRIMARY]
        ALTER TABLE [dbo].[relch_exep] WITH NOCHECK ADD 
        CONSTRAINT [PK_relch_exep] PRIMARY KEY  CLUSTERED 
        (
        [empresa],
        [codigo]
        )  ON [PRIMARY] 
    END

GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'[dbo].[relch_reporte]')
                    AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        DROP TABLE dbo.relch_reporte
    END
go

IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'[dbo].[relch_fnomina]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE [dbo].[relch_fnomina]
            (
              [empresa] [numeric](18, 0) NOT NULL ,
              [codigo] [numeric](18, 0) NOT NULL ,
              [horario] [numeric](18, 0) NOT NULL ,
              [fecha] [datetime] NOT NULL ,
              [nombre] [char](100) NULL ,
              [activo] [char](1) NULL ,
              [foto] [varchar](255) NULL
            )
        ON  [PRIMARY]
        ALTER TABLE [dbo].[relch_fnomina] WITH NOCHECK ADD 
        CONSTRAINT [PK_relch_fnomina] PRIMARY KEY  CLUSTERED 
        (
        [empresa],
        [codigo],
        [horario],
        [fecha]
        )  ON [PRIMARY] 
    END

GO

IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'[dbo].[relch_msgper]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE [dbo].[relch_msgper]
            (
              [empresa] [numeric](18, 0) NOT NULL ,
              [codigo] [numeric](18, 0) NOT NULL ,
              [mensaje] [char](50) NULL ,
              [desde] [datetime] NULL ,
              [hasta] [datetime] NULL ,
              [imagen] [char](500) NULL ,
              [c] [char](1) NULL ,
              [s] [char](1) NULL ,
              [menc] [char](50) NULL ,
              [mens] [char](50) NULL ,
              [imagens] [char](500) NULL ,
              [imagenc] [char](500) NULL
            )
        ON  [PRIMARY]
    END
Go
IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'[dbo].[relch_paramet]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE [dbo].[relch_paramet]
            (
              [empresa] [numeric](18, 0) NOT NULL ,
              [otrorel] [char](1) NULL ,
              [validar] [char](1) NULL ,
              [comedor] [char](1) NULL ,
              [mincomedor] [numeric](18, 0) NULL ,
              [min_tmp_extra] [numeric](18, 0) NULL ,
              [media_hora] [char](1) NULL ,
              [comedor11] [char](8) NULL ,
              [comedor12] [char](8) NULL ,
              [comedor21] [char](8) NULL ,
              [comedor22] [char](8) NULL ,
              [comedor31] [char](8) NULL ,
              [comedor32] [char](8) NULL ,
              [tolera] [numeric](18, 0) NULL ,
              [tmp_ant_ent] [char](1) NULL ,
              [ret_comedor] [char](1) NULL
            )
        ON  [PRIMARY]
        ALTER TABLE [dbo].[relch_paramet] WITH NOCHECK ADD 
        CONSTRAINT [PK_relch_paramet] PRIMARY KEY  CLUSTERED 
        (
        [empresa]
        )  ON [PRIMARY] 

    END
GO

IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'[dbo].[relch_registro]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE [dbo].[relch_registro]
            (
              [empresa] [numeric](18, 0) NOT NULL ,
              [codigo] [numeric](18, 0) NOT NULL ,
              [serial] [numeric](18, 0) NOT NULL ,
              [checada] [varchar](10) NULL ,
              [fecha] [datetime] NOT NULL ,
              [clave] [numeric](18, 0) NULL ,
              [num_conc] [numeric](18, 0) NULL ,
              [obs] [char](60) NULL ,
              [incapacidad] [char](1) NULL ,
              [no_inc] [char](8) NULL ,
              [importe] [numeric](18, 2) NULL ,
              [tiempo] [numeric](18, 2) NULL ,
              [alerta] [char](30) NULL ,
              [eliminado] [char](1) NULL ,
              [marcafalta] [char](1) NULL ,
              [dias] [numeric](18, 0) NULL ,
              [comedor] [char](1) NULL ,
              [dosdias] [char](1) NULL ,
              [EoS] [char](1) NULL
            )
        ON  [PRIMARY]
        ALTER TABLE [dbo].[relch_registro] ADD 
        CONSTRAINT [DF_relch_registro_num_conc] DEFAULT (0) FOR [num_conc],
        CONSTRAINT [DF_relch_registro_dias] DEFAULT (0) FOR [dias]
        CREATE  CLUSTERED  INDEX [indice] ON [dbo].[relch_registro]([empresa], [codigo], [fecha], [checada]) WITH  FILLFACTOR = 80 ON [PRIMARY]
    END
--drop table tmp_relch_registro 

GO
IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'[dbo].[relch_reporte]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE [dbo].[relch_reporte]
            (
              [empresa] [numeric](8, 0) NOT NULL ,
              [codigo] [numeric](8, 0) NOT NULL ,
              [fecha] [datetime] NOT NULL ,
              [sec] [numeric](3, 0) NOT NULL ,
              [tiempo] [numeric](10, 2) NULL ,
              [num_conc] [numeric](4, 0) NOT NULL ,
              [obs] [char](15) NULL ,
              [checada] [char](15) NULL ,
              [supervisor] [numeric](5, 0) NOT NULL ,
              [centro] [char](15) NULL ,
              [hrsturno] [numeric](10, 2) NULL ,
              [hrstrab] [numeric](10, 2) NULL ,
              [hrsret] [numeric](10, 2) NULL ,
              [hrsext] [numeric](10, 2) NULL ,
              [orden] [VARCHAR](15) NULL
            )
        ON  [PRIMARY]
    END
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'orden'
                        AND sysobjects.name = 'relch_reporte' ) 
    ALTER TABLE relch_reporte ADD orden VARCHAR(15) NULL 
go


IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'tiponom'
                        AND sysobjects.name = 'relch_registro' ) 
    ALTER TABLE relch_registro ADD tiponom INT NULL 
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'centro'
                        AND sysobjects.name = 'relch_registro' ) 
    ALTER TABLE relch_registro ADD centro VARCHAR(15) NULL 
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'horario'
                        AND sysobjects.name = 'relch_registro' ) 
    ALTER TABLE relch_registro ADD horario INT NULL 
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'cuota'
                        AND sysobjects.name = 'relch_paramet' ) 
    ALTER TABLE relch_paramet ADD cuota NUMERIC(18, 2) NULL 
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'h1'
                        AND sysobjects.name = 'relch_paramet' ) 
    ALTER TABLE relch_paramet ADD h1 CHAR(2) NULL 
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'h2'
                        AND sysobjects.name = 'relch_paramet' ) 
    ALTER TABLE relch_paramet ADD h2 CHAR(2) NULL 
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'h3'
                        AND sysobjects.name = 'relch_paramet' ) 
    ALTER TABLE relch_paramet ADD h3 CHAR(2) NULL 
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'periodo'
                        AND sysobjects.name = 'relch_registro' ) 
    ALTER TABLE relch_registro ADD periodo NUMERIC(18, 0) NULL 
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'ayo'
                        AND sysobjects.name = 'relch_registro' ) 
    ALTER TABLE relch_registro ADD ayo NUMERIC(18, 0) NULL 
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'sub'
                        AND sysobjects.name = 'relch_registro' ) 
    ALTER TABLE relch_registro ADD sub NUMERIC(18, 0) NULL 
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'linea'
                        AND sysobjects.name = 'llaves' ) 
    ALTER TABLE llaves ADD linea NUMERIC(18, 0) NULL DEFAULT ((0))
GO


IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'id'
                        AND sysobjects.name = 'relch_registro' ) 
    ALTER TABLE relch_registro ADD id INT IDENTITY(1,1) NOT NULL

GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'hind'
                        AND sysobjects.name = 'relch_paramet' ) 
    ALTER TABLE relch_paramet ADD hind CHAR(1) NULL 
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'credenciales'
                        AND sysobjects.name = 'relch_paramet' ) 
    ALTER TABLE relch_paramet ADD credenciales CHAR(1) NULL 
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'chor'
                        AND sysobjects.name = 'empleados' ) 
    ALTER TABLE empleados ADD chor CHAR(1) NULL DEFAULT ('N')
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'rutamasivo'
                        AND sysobjects.name = 'relch_paramet' ) 
    ALTER TABLE relch_paramet ADD rutamasivo VARCHAR(255) NULL 
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'rutarespaldo'
                        AND sysobjects.name = 'relch_paramet' ) 
    ALTER TABLE relch_paramet ADD rutarespaldo VARCHAR(255) NULL 
GO

IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'[dbo].[relch_comidas]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE [dbo].[relch_comidas]
            (
              [empresa] [numeric](18, 0) NOT NULL ,
              [fecha] [datetime] NOT NULL ,
              [comidas] [numeric](18, 0) NULL ,
              [importe] [decimal](18, 0) NULL
            )
        ON  [PRIMARY]

        ALTER TABLE [dbo].[relch_comidas] WITH NOCHECK ADD 
        CONSTRAINT [PK_relch_comidas] PRIMARY KEY  CLUSTERED 
        (
        [empresa],
        [fecha]
        )  ON [PRIMARY] 
    END
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'terminal'
                        AND sysobjects.name = 'relch_registro' ) 
    ALTER TABLE relch_registro ADD terminal INT NULL DEFAULT ((0))
GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'horario'
                        AND sysobjects.name = 'empleados' ) 
    ALTER TABLE empleados ADD horario NUMERIC(5,0) NULL DEFAULT ((0))

GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'crf'
                        AND sysobjects.name = 'relch_registro' ) 
    ALTER TABLE relch_registro ADD crf VARCHAR(50) NULL
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'crf2'
                        AND sysobjects.name = 'relch_registro' ) 
    ALTER TABLE relch_registro ADD crf2 VARCHAR(50) NULL
GO

IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'[dbo].[relch_terminales]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE [dbo].[relch_terminales]
            (
              [empresa] [numeric](4, 0) NOT NULL ,
              [terminal] [numeric](18, 0) NOT NULL ,
              [referencia] [varchar](50) NULL ,
              CONSTRAINT [PK_relch_terminales] PRIMARY KEY CLUSTERED
                ( [empresa] ASC, [terminal] ASC )
            )
        ON  [PRIMARY]

        INSERT  INTO relch_terminales
                ( empresa ,
                  terminal ,
                  referencia
                )
                SELECT  empresa ,
                        0 AS terminal ,
                        'SIN TERMINAL' AS referencia
                FROM    empresas
	
    END

GO

INSERT  INTO relch_terminales
        ( empresa ,
          terminal ,
          referencia
        )
        SELECT  a.empresa ,
                0 AS terminal ,
                'SIN TERMINAL' AS referencia
        FROM    empresas AS a
                LEFT JOIN relch_terminales AS b ON a.empresa = b.empresa
                                                   AND b.terminal = 0
        WHERE   b.empresa IS NULL


GO


IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'[dbo].[relch_credenciales]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE [dbo].[relch_credenciales]
            (
              [empresa] [numeric](4, 0) NOT NULL ,
              [credencial] [numeric](18, 0) NOT NULL ,
              [codigo] [numeric](8, 0) NOT NULL ,
              CONSTRAINT [PK_relch_credenciales] PRIMARY KEY CLUSTERED
                ( [empresa] ASC, [codigo] ASC, [credencial] ASC )
            )
        ON  [PRIMARY]

    END

GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'credencial'
                        AND sysobjects.name = 'relch_registro' ) 
    ALTER TABLE relch_registro ADD credencial NUMERIC(18, 0) NULL DEFAULT ((0))
GO


IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'[dbo].[relch_lineas]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE [dbo].[relch_lineas]
            (
              [empresa] [numeric](4, 0) NOT NULL ,
              [linea] [numeric](18, 0) NOT NULL ,
              [nombre] [char](25) NULL ,
              CONSTRAINT [PK_relch_lineas] PRIMARY KEY CLUSTERED
                ( [empresa] ASC, [linea] ASC )
            )
        ON  [PRIMARY]
	
	
    END

GO


INSERT  INTO relch_lineas
        ( empresa ,
          linea ,
          nombre
        )
        SELECT  a.empresa ,
                0 AS linea ,
                'SIN LINEA' AS nombre
        FROM    empresas AS a
                LEFT JOIN relch_lineas AS b ON a.empresa = b.empresa
                                               AND b.linea = 0
        WHERE   b.empresa IS NULL


GO

UPDATE  l
SET     linea = 0
FROM    llaves AS l
WHERE   linea IS NULL 
	
GO


IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'clin'
                        AND sysobjects.name = 'empleados' ) 
    ALTER TABLE empleados ADD clin CHAR(1) NULL DEFAULT ('N')
GO


IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'credencial'
                        AND sysobjects.name = 'empleados' ) 
    ALTER TABLE empleados ADD credencial NUMERIC(18,0) NULL DEFAULT ((0))

GO

--drop table relch_historico_checadas
--select * from relch_historico_checadas


IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'[dbo].[relch_historico_checadas]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE [dbo].[relch_historico_checadas]
            (
              [empresa] [numeric](18, 0) NOT NULL ,
              [codigo] [numeric](18, 0) NOT NULL ,
              [checada] [varchar](10) NOT NULL ,
              [fecha] [datetime] NOT NULL ,
              [terminal] [int] NULL ,
              [marca] [char](30) NOT NULL ,
              [aplicara] DATETIME NULL ,
              [id] INT IDENTITY(1, 1)
                       NOT NULL ,
              CONSTRAINT [PK_relch_historico_checadas] PRIMARY KEY CLUSTERED
                ( [empresa] ASC, [codigo] ASC, [checada] ASC, [marca] ASC, [fecha] ASC, [id] ASC )
            )
        ON  [PRIMARY]

    END
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'aplicara'
                        AND sysobjects.name = 'relch_historico_checadas' ) 
    ALTER TABLE relch_historico_checadas ADD aplicara DATETIME NULL

GO


IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'id'
                        AND sysobjects.name = 'relch_historico_checadas' ) 
    ALTER TABLE relch_historico_checadas ADD id INT IDENTITY(1,1) NOT NULL

GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'mostrar'
                        AND sysobjects.name = 'relch_paramet' ) 
    ALTER TABLE relch_paramet ADD mostrar CHAR(1) NULL 

GO 

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'hrsreales'
                        AND sysobjects.name = 'horarios_catalogo' ) 
    BEGIN
        PRINT 'Si entra'
        ALTER TABLE horarios_catalogo ADD hrsreales NUMERIC(8,2) NULL 
    END
	
GO 

UPDATE  a
SET     a.hrsreales = b.hrsturno
FROM    horarios_catalogo AS a
        INNER JOIN horarios_catalogo AS b ON b.empresa = a.empresa
                                             AND b.horario = a.horario
WHERE   a.hrsreales IS NULL

GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'rutalogo'
                        AND sysobjects.name = 'relch_paramet' ) 
    ALTER TABLE relch_paramet ADD rutalogo VARCHAR(500) NULL 

GO 

--select * from horarios_catalogo 
--
IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'[dbo].[relch_reporte_lista]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE [dbo].[relch_reporte_lista]
            (
              [empresa] [numeric](8, 0) NOT NULL ,
              [codigo] [numeric](8, 0) NOT NULL ,
              [fecha] [datetime] NOT NULL ,
              [e1] [char](10) NULL ,
              [s1] [char](10) NULL ,
              [e2] [char](10) NULL ,
              [s2] [char](10) NULL
            )
        ON  [PRIMARY]
    END
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'aplicara'
                        AND sysobjects.name = 'relch_registro' ) 
    ALTER TABLE relch_registro ADD aplicara DATETIME NULL 

GO 


UPDATE  relch_registro
SET     aplicara = fecha
WHERE   aplicara IS NULL 

GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'tipoturno'
                        AND sysobjects.name = 'horarios_catalogo' ) 
    ALTER TABLE dbo.horarios_catalogo ADD tipoturno INT NULL 

GO 

IF NOT EXISTS ( SELECT  name
                FROM    sysindexes
                WHERE   name = 'relch_fecha' ) 
    CREATE INDEX relch_fecha ON dbo.relch_registro(fecha)
GO

IF NOT EXISTS ( SELECT  name
                FROM    sysindexes
                WHERE   name = 'relch_aplicara' ) 
    CREATE INDEX relch_aplicara ON dbo.relch_registro(aplicara)
GO

IF NOT EXISTS ( SELECT  name
                FROM    sysindexes
                WHERE   name = 'relch_num_conc' ) 
    CREATE INDEX relch_num_conc ON dbo.relch_registro(num_conc)
GO

IF NOT EXISTS ( SELECT  name
                FROM    sysindexes
                WHERE   name = 'relch_codigo' ) 
    CREATE INDEX relch_codigo ON dbo.relch_registro(codigo)
GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'bloqueado'
                        AND sysobjects.name = 'empleados' ) 
    ALTER TABLE empleados ADD bloqueado INT NULL 

GO 

IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'relch_credenciales_codigos')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE relch_credenciales_codigos
            (
              [empresa] [numeric](8, 0) NOT NULL ,
              [codigo] [numeric](8, 0) NOT NULL
            )
        ON  [PRIMARY]
    END
GO


-----------------***********INSERTA LAS dbo.funciones**********-----------------------

IF NOT EXISTS ( SELECT  1
                FROM    dbo.funciones
                WHERE   sistema = 'RC' ) 
    BEGIN
        INSERT  INTO dbo.funciones
        VALUES  ( 'RC', 'A', 'Administrador del Reloj Checador' )
        INSERT  INTO dbo.funciones
        VALUES  ( 'RC', 'B', 'Reloj Checador' )
        INSERT  INTO dbo.funciones
        VALUES  ( 'RC', 'C', 'Comedor' )
        INSERT  INTO dbo.funciones
        VALUES  ( 'RC', 'D', 'Configurar Parametros' )
    END


GO


--------------*******INSERTA LAS dbo.opciones*******------------------------------------

IF NOT EXISTS ( SELECT  1
                FROM    dbo.opciones
                WHERE   sistema = 'RC' ) 
    BEGIN
        INSERT  INTO dbo.opciones
        VALUES  ( 'A1', 'RC', 'A', 'Consultar Informacin' )
        INSERT  INTO dbo.opciones
        VALUES  ( 'A2', 'RC', 'A', 'Modificar Informacin' )
        INSERT  INTO dbo.opciones
        VALUES  ( 'A3', 'RC', 'A', 'Ver Importes' )
        INSERT  INTO dbo.opciones
        VALUES  ( 'A4', 'RC', 'A', 'Parametros' )
        INSERT  INTO dbo.opciones
        VALUES  ( 'A5', 'RC', 'A', 'Importar de otro reloj' )
        INSERT  INTO dbo.opciones
        VALUES  ( 'A6', 'RC', 'A', 'Asignar Fotos' )
        INSERT  INTO dbo.opciones
        VALUES  ( 'A7', 'RC', 'A', 'Mensajes Personales' )
        INSERT  INTO dbo.opciones
        VALUES  ( 'A8', 'RC', 'A', 'Horarios' )
        INSERT  INTO dbo.opciones
        VALUES  ( 'A9', 'RC', 'A', 'Reportes' )
        INSERT  INTO dbo.opciones
        VALUES  ( 'B1', 'RC', 'B', 'Reloj' )
        INSERT  INTO dbo.opciones
        VALUES  ( 'C1', 'RC', 'C', 'Comedor' )
        INSERT  INTO dbo.opciones
        VALUES  ( 'D1', 'RC', 'D', 'Parametros' )

    END
    
GO

-----------********INSERTA LAS dbo.funciones Y dbo.opciones AL PERFIL DE ADMINISTRADOR*********-----------
IF NOT EXISTS ( SELECT  *
                FROM    dbo.perfil_funcion
                WHERE   idperfil = '5' ) 
    BEGIN
        INSERT  INTO dbo.perfil_funcion
                SELECT  Funcion ,
                        Opcion ,
                        5
                FROM    dbo.opciones
                WHERE   sistema = 'RC'
    END 

GO


IF EXISTS ( SELECT  name
            FROM    sysobjects
            WHERE   name = 'ObtenRelojValidaPassword'
                    AND type = 'P' ) 
    DROP PROCEDURE ObtenRelojValidaPassword
GO

CREATE PROCEDURE ObtenRelojValidaPassword
    (
      @username AS udtName , --sin guiones ni espacios
      @password AS udtName
    )
	----WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY
    DECLARE @recordId AS udtId
    SET XACT_ABORT ON
    DECLARE @passwordDecrypt AS udtName
    DECLARE @passwordUser AS udtName
    DECLARE @userValid AS udtName
	
	
    SET @userValid = ISNULL(( SELECT    'Found'
                              FROM      dbo.usuarios
                              WHERE     usuario = @username
                            ), 'Not')
    IF @userValid = 'Not' 
        BEGIN
            SELECT  'UserNotFound' AS cLogin
		
        END
    ELSE 
        BEGIN
	
		
		
            SET @passwordUser = ( SELECT    password
                                  FROM      dbo.usuarios
                                  WHERE     usuario = @username
                                )
		
            SELECT  CASE WHEN BINARY_CHECKSUM(@passwordUser) = BINARY_CHECKSUM(@password)
                         THEN 'LoginSuccessfully'
                         WHEN BINARY_CHECKSUM(@passwordUser) <> BINARY_CHECKSUM(@password)
                         THEN 'IncorrectPassarod'
                    END AS cLogin
		
        END 
	
GO



IF EXISTS ( SELECT  name
            FROM    sysobjects
            WHERE   name = 'ObtenRelojEmpresas'
                    AND type = 'P' ) 
    DROP PROCEDURE ObtenRelojEmpresas
GO

CREATE PROCEDURE ObtenRelojEmpresas ( @username AS udtName )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    DECLARE @cEmpresas udtStringSize255
	
    SET @debug = 0
    SET @whereClauseUsed = 0
    SET @whereClause = ''
    SET @orderByClause = ''
    SET @groupByClause = ''


    SELECT  @cEmpresas = b.empresas
    FROM    perfil_usuarios AS a
            INNER JOIN perfiles AS b ON a.idperfil = b.idperfil
    WHERE   a.usuario = @username
            AND b.sistema = 'RC'
    
    IF LEN(@cEmpresas) > 0 
        BEGIN
            SET @cEmpresas = REPLACE(@cEmpresas, '{', '(')
            SET @cEmpresas = REPLACE(@cEmpresas, '}', ')')
        END 
    ELSE 
        BEGIN
            SET @cEmpresas = '()'
        END 
	
    IF @cEmpresas <> '()' 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'empresa in' + @cEmpresas
                 
        END
	
    SET @selectClause = 'SELECT empresa,'
        + 'case when referencia is null or len(rtrim(ltrim(referencia)))<=0 then nombre_empresa else referencia end as nombre_empresa,'
        + 'nombre_empresa,' + 'registro_patronal,' + 'rfc_empresa '
    						
    SET @fromClause = 'FROM    empresas '
        
    IF @debug = 0 
        BEGIN 
            EXEC(
            @selectClause + @fromClause + @whereClause + @groupByClause + @orderByClause
            )
        END
    ELSE 
        BEGIN
            PRINT ( @selectClause + @fromClause + @whereClause
                    + @groupByClause + @orderByClause )
        END


GO

/*ObtenDatosEmpleado*/
IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojDatosEmpleado')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojDatosEmpleado
GO

CREATE PROCEDURE dbo.obtenRelojDatosEmpleado
    (
      @empresa AS udtInteger ,
      @codigo AS udtInteger
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
 
 

    SELECT  a.ap_paterno + ' ' + a.ap_materno + ' ' + a.nombre AS Nombre ,
            c.nomdepto ,
            d.actividad ,
            f.nomina ,
            e.foto
    FROM    dbo.empleados AS a
            INNER JOIN dbo.Llaves AS b ON a.empresa = b.empresa
                                          AND a.codigo = b.codigo
            INNER JOIN dbo.centros AS c ON c.empresa = b.empresa
                                           AND c.centro = b.centro
            INNER JOIN dbo.tabulador AS d ON d.empresa = b.empresa
                                             AND d.ocupacion = b.ocupacion
            INNER JOIN dbo.datosemps AS e ON e.empresa = b.empresa
                                             AND e.codigo = b.codigo
            INNER JOIN dbo.nominas AS f ON f.empresa = b.empresa
                                           AND f.tiponom = b.tiponom
    WHERE   a.empresa = @empresa
            AND a.codigo = @codigo  
                

GO


IF OBJECT_ID('dbo.FunGetElapsedTime') IS NOT NULL 
    DROP FUNCTION dbo.FunGetElapsedTime
Go


CREATE FUNCTION dbo.FunGetElapsedTime
    (
      @dFecha1 udtDateTime ,
      @cHora1 udtName ,
      @dFecha2 udtDateTime ,
      @cHora2 udtName
    )
RETURNS @ElapsedTime TABLE
    (
      dias INT NOT NULL ,
      horas INT NOT NULL ,
      minutos INT NOT NULL ,
      segundo INT NOT NULL
    )
    WITH ENCRYPTION
AS 
    BEGIN 

        DECLARE @datetime1 DATETIME
        DECLARE @datetime2 DATETIME        
        DECLARE @date_only DATETIME
        DECLARE @time_only DATETIME
        DECLARE @date_plus_time DATETIME
        DECLARE @elapsed_time DATETIME
        DECLARE @elapsed_days INT
        DECLARE @elapsed_hours INT
        DECLARE @elapsed_minutes INT
        DECLARE @elapsed_seconds INT
        DECLARE @elapsed_milliseconds INT
        
        IF LEN(RTRIM(@cHora1)) > 0 
            BEGIN 
                IF LEN(RTRIM(@cHora1)) < 5 
                    SET @cHora1 = SUBSTRING(@cHora1, 1, 2) + ':'
                        + SUBSTRING(@cHora1, 3, 2)
           
                SET @dateTime1 = CONVERT(DATETIME, ( CONVERT(CHAR(12), @dFecha1)
                                                     + @cHora1 ))
            END                                      
        ELSE 
            SET @dateTime1 = @dFecha1
           
        IF LEN(RTRIM(@cHora2)) > 0 
            BEGIN 
                IF LEN(RTRIM(@cHora2)) < 5 
                    SET @cHora2 = SUBSTRING(@cHora2, 1, 2) + ':'
                        + SUBSTRING(@cHora2, 3, 2)
        
                SET @dateTime2 = CONVERT(DATETIME, ( CONVERT(CHAR(12), @dFecha2)
                                                     + @cHora2 ))
            END                                                  
        ELSE 
            SET @dateTime2 = @dFecha2
           
           
        -- Get date only from datetime using DATEAADD/DATEDIFF functions
        SET @date_only = DATEADD(day, DATEDIFF(day, 0, @datetime1), 0)

        -- Get time only from datetime by subtracting date only
        SET @time_only = @datetime2 - DATEADD(day,
                                              DATEDIFF(day, 0, @datetime2), 0)

        -- Add date only and time only together
        SET @date_plus_time = @date_only + @time_only

        -- Get elapsed time as the difference between 2 datetimes
        SET @elapsed_time = @datetime2 - @datetime1

        -- Get elapsed time parts as time since 1900-01-01 00:00:00.000
        SET @elapsed_days = DATEDIFF(day, 0, @elapsed_time)
        SET @elapsed_hours = DATEPART(hour, @elapsed_time)
        SET @elapsed_minutes = DATEPART(minute, @elapsed_time)
        SET @elapsed_seconds = DATEPART(second, @elapsed_time)
        SET @elapsed_milliseconds = DATEPART(millisecond, @elapsed_time)

        INSERT  @ElapsedTime
        VALUES  ( @elapsed_days, @elapsed_hours, @elapsed_minutes,
                  @elapsed_seconds ) 
        
        RETURN

    END

GO

PRINT 'GO'

GO                                                


IF OBJECT_ID('dbo.GetAnalisisRelojObserva') IS NOT NULL 
    DROP FUNCTION dbo.GetAnalisisRelojObserva
Go


CREATE FUNCTION dbo.GetAnalisisRelojObserva
    (
      @dInicio udtDateTime ,
      @cChecada udtDateTime ,
      @nHorario udtInteger ,
      @nEmpresa udtInteger ,
      @nDia_Semana udtInteger ,
      @nRegresa udtInteger  -- 0 = Observacion, 1 = Horas
    )
RETURNS VARCHAR(100)
    WITH ENCRYPTION
AS 
    BEGIN


        DECLARE @dFecha DATETIME
        DECLARE @cEntra1 AS VARCHAR(4)
        DECLARE @cSale1 AS VARCHAR(4)
        DECLARE @cEntra2 AS VARCHAR(4)
        DECLARE @cSale2 AS VARCHAR(4)
        DECLARE @dEntra1 AS DATETIME
        DECLARE @dSale1 AS DATETIME
        DECLARE @dSale1Nocturno AS DATETIME
        DECLARE @dEntra2 AS DATETIME
        DECLARE @dSale2 AS DATETIME
        DECLARE @nObserva AS FLOAT
        
        DECLARE @datetime1 DATETIME
        DECLARE @datetime2 DATETIME        
        DECLARE @datetime3 DATETIME        
        DECLARE @date_only DATETIME
        DECLARE @time_only DATETIME
        DECLARE @date_plus_time DATETIME
        DECLARE @elapsed_time DATETIME
        DECLARE @elapsed_days INT
        DECLARE @elapsed_hours INT
        DECLARE @elapsed_minutes INT
        DECLARE @elapsed_seconds INT
        DECLARE @elapsed_milliseconds INT
        DECLARE @dOriginal AS DATETIME        
        
        DECLARE @ElapsedTime TABLE
            (
              dias INT NOT NULL ,
              horas INT NOT NULL ,
              minutos INT NOT NULL ,
              segundo INT NOT NULL
            )
        

        SET @dOriginal = CONVERT(DATETIME, ( CONVERT(CHAR(12), @dInicio)
                                             + @cChecada ))
        
        SET @dFecha = @dInicio
        SET @dEntra1 = @dInicio
        SET @dSale1 = @dInicio
        SET @dEntra2 = @dInicio
        SET @dSale2 = @dInicio
        SET @nObserva = 0
        

        SELECT  @cEntra1 = entra1 ,
                @cSale1 = sale1 ,
                @cEntra2 = entra2 ,
                @cSale2 = sale2
        FROM    Detalle_Horarios
        WHERE   Horario = @nHorario
                AND Dia_Semana = @nDia_Semana--DATEPART(DW, @dFecha)
                AND Empresa = @nEmpresa
                
        
        IF @cEntra1 = ''
            AND @cSale1 = '' 
            BEGIN
                SELECT  @cEntra1 = entra1 ,
                        @cSale1 = sale1 ,
                        @cEntra2 = entra2 ,
                        @cSale2 = sale2
                FROM    Detalle_Horarios
                WHERE   Horario = @nHorario
                        AND Dia_Semana = @nDia_Semana--DATEPART(DW, @dFecha - 1)
                        AND Empresa = @nEmpresa
          
            END
            
        IF @cEntra1 = '' 
            SET @cEntra1 = '0000'
        IF @cSale1 = '' 
            SET @cSale1 = '0000'
            
        /*
        Horario Normal
        */         
        DECLARE @dSigDia AS DATETIME       
        SET @dSigDia = @dFecha - 1
      
        IF @cSale1 > @cEntra1 
            BEGIN
      
                SET @dEntra1 = CONVERT(DATETIME, ( CONVERT(CHAR(12), @dFecha)
                                                   + SUBSTRING(@cEntra1, 1, 2)
                                                   + ':' + SUBSTRING(@cEntra1,
                                                              3, 2) ))
                SET @dSale1 = CONVERT(DATETIME, ( CONVERT(CHAR(12), @dFecha)
                                                  + SUBSTRING(@cSale1, 1, 2)
                                                  + ':' + SUBSTRING(@cSale1, 3,
                                                              2) ))
                SET @dSale1Nocturno = CONVERT(DATETIME, ( CONVERT(CHAR(12), @dSigDia)
                                                          + SUBSTRING(@cSale1,
                                                              1, 2) + ':'
                                                          + SUBSTRING(@cSale1,
                                                              3, 2) ))
                                                              
            END                                  
        ELSE 
            BEGIN
                SET @dEntra1 = CONVERT(DATETIME, ( CONVERT(CHAR(12), @dFecha)
                                                   + SUBSTRING(@cEntra1, 1, 2)
                                                   + ':' + SUBSTRING(@cEntra1,
                                                              3, 2) ))
                SET @dSale1 = CONVERT(DATETIME, ( CONVERT(CHAR(12), @dFecha)
                                                  + SUBSTRING(@cSale1, 1, 2)
                                                  + ':' + SUBSTRING(@cSale1, 3,
                                                              2) ))
                                                              
                SET @dSale1Nocturno = CONVERT(DATETIME, ( CONVERT(CHAR(12), @dSigDia)
                                                          + SUBSTRING(@cSale1,
                                                              1, 2) + ':'
                                                          + SUBSTRING(@cSale1,
                                                              3, 2) ))
          
            END    
            
        IF @cEntra2 <> ''
            AND @cSale2 <> '' 
            IF @cSale2 > @cEntra2 
                BEGIN 
                    SET @dEntra2 = CONVERT(DATETIME, ( CONVERT(CHAR(12), @dFecha)
                                                       + SUBSTRING(@cEntra2, 1,
                                                              2) + ':'
                                                       + SUBSTRING(@cEntra2, 3,
                                                              2) ))
                    SET @dSale2 = CONVERT(DATETIME, ( CONVERT(CHAR(12), @dFecha)
                                                      + SUBSTRING(@cSale2, 1,
                                                              2) + ':'
                                                      + SUBSTRING(@cSale2, 3,
                                                              2) ))
                END                                              

        /*
        Entradas
        */
        DECLARE @nTolerancia AS INT
        DECLARE @nTiempoExtra AS INT
        
        DECLARE @dEntradaAnticipada AS DATETIME
        DECLARE @dEntradaNormal AS DATETIME
        DECLARE @dEntradaRetardo AS DATETIME
        DECLARE @dSalidaAnticipada AS DATETIME
        DECLARE @dSalidaNormal AS DATETIME
        DECLARE @dTiempoExtra AS DATETIME
        DECLARE @dSalidaAnticipadaNocturno AS DATETIME
        DECLARE @dSalidaNormalNocturno AS DATETIME
        DECLARE @dTiempoExtraNocturno AS DATETIME
        DECLARE @nHorasCalculadas AS FLOAT
        DECLARE @nIncidencia AS INTEGER
        /*
        Valores de incidencia
        1 = Entrada Anticipada
        2 = Entrada
        3 = Retardo
        4 = Salida Anticipada
        5 = Salida
        6 = Tiempo extra
        100 = Checada fuera de horario
        */
        
        --SET @nTolerancia = 10
        --SET @nTiempoExtra = 30
        DECLARE @hourSal1 udtName
        --SET @hourSal1 =
        SELECT  @nTolerancia = tolera ,
                @nTiempoExtra = min_tmp_extra
        FROM    relch_paramet
        WHERE   empresa = @nempresa
        
        SET @nIncidencia = 0
        
        SET @dEntradaAnticipada = DATEADD(minute, -89, @dEntra1)
        SET @dEntradaNormal = DATEADD(minute, @nTolerancia, @dEntra1)
        SET @dEntradaRetardo = DATEADD(hour, 4, @dEntra1)
        
        DECLARE @salidaComedor DATETIME
        DECLARE @entrarComedor DATETIME
        
        
        IF LEN(@cEntra2) <= 0 
            BEGIN
                SET @dSalidaAnticipada = DATEADD(hour, @nTolerancia, @dSale1)
                SET @dSalidaNormal = DATEADD(minute, @nTiempoExtra, @dSale1)
                SET @dTiempoExtra = DATEADD(hour, 8, @dSale1)
	        
                SET @dSalidaAnticipadaNocturno = DATEADD(hour, -4,
                                                         @dSale1Nocturno)
                SET @dSalidaNormalNocturno = DATEADD(minute, @nTiempoExtra,
                                                     @dSale1Nocturno)
                SET @dTiempoExtraNocturno = DATEADD(hour, 8, @dSale1Nocturno)
            END
        ELSE 
            BEGIN
                SET @dSalidaAnticipada = DATEADD(minute, -120, @dSale2)
                SET @dSalidaNormal = DATEADD(minute, @nTiempoExtra, @dSale2)
                SET @dTiempoExtra = DATEADD(hour, 8, @dSale2)
	        
                SET @dSalidaAnticipadaNocturno = DATEADD(hour, -4,
                                                         @dSale1Nocturno)
                SET @dSalidaNormalNocturno = DATEADD(minute, @nTiempoExtra,
                                                     @dSale1Nocturno)
                SET @dTiempoExtraNocturno = DATEADD(hour, 8, @dSale1Nocturno)
			
                SET @salidaComedor = DATEADD(minute, 30, @dSale1)
                SET @entrarComedor = DATEADD(minute, 30, @dEntra2)
            END
		
		/*
        Regresa el analisis en observacion
        */               
        SET @nIncidencia = CASE WHEN @dOriginal BETWEEN @dEntradaAnticipada
                                                AND     @dEntra1 THEN 1
                                WHEN @dOriginal BETWEEN @dEntra1 AND @dEntradaNormal
                                THEN 2
                                WHEN @dOriginal BETWEEN @dEntra1 AND @dEntradaRetardo
                                THEN 3
                                WHEN @dOriginal BETWEEN @dSalidaAnticipada
                                                AND     CASE WHEN LEN(@dEntra2) > 0
                                                             THEN DATEADD(minute,
                                                              -1, @dSale2)
                                                             ELSE DATEADD(minute,
                                                              -1, @dSale1)
                                                        END THEN 4
                                WHEN @dOriginal BETWEEN CASE WHEN LEN(@dEntra2) > 0
                                                             THEN @dSale2
                                                             ELSE @dSale1
                                                        END
                                                AND     @dSalidaNormal THEN 5
                                WHEN @dOriginal BETWEEN @dSalidaNormal
                                                AND     @dTiempoExtra THEN 6
                                WHEN @dOriginal BETWEEN @dSalidaAnticipadaNocturno
                                                AND     @dSale1Nocturno THEN 4
                                WHEN @dOriginal BETWEEN @dSale1Nocturno
                                                AND     @dSalidaNormalNocturno
                                THEN 5
                                WHEN @dOriginal BETWEEN @dSalidaNormalNocturno
                                                AND     @dTiempoExtraNocturno
                                THEN 6
                                WHEN LEN(@dEntra2) > 0
                                     AND @dOriginal BETWEEN @dSale1 AND @salidaComedor
                                THEN 8
                                WHEN LEN(@dEntra2) > 0
                                     AND @dOriginal BETWEEN @dEntra2 AND @entrarComedor
                                THEN 9
                                ELSE 100
                           END
        IF @nRegresa = 0 
            BEGIN               
            
                SET @nObserva = CASE WHEN @nIncidencia = 1 THEN 1--'Entrada A'
                                     WHEN @nIncidencia = 2 THEN 2--'Entrada'
                                     WHEN @nIncidencia = 3 THEN 3--'Retardo'
                                     WHEN @nIncidencia = 4 THEN 4--'Salida Anticipada'
                                     WHEN @nIncidencia = 5 THEN 5--'Salida'
                                     WHEN @nIncidencia = 6 THEN 6--'Tiempo extra'
                                     WHEN @nIncidencia = 8 THEN 8--'Tiempo extra'
                                     WHEN @nIncidencia = 9 THEN 9--'Tiempo extra'
                                     ELSE 0--'Checada fuera de horario'
                                END
            END                     
        ELSE 
            BEGIN
                IF @nIncidencia = 1 
                    BEGIN 
                        INSERT  INTO @ElapsedTime
                                SELECT  *
                                FROM    dbo.FunGetElapsedTime(@dOriginal, '',
                                                              @dEntra1, '')
                    END    
                    
                IF @nIncidencia = 2 
                    BEGIN 
                        INSERT  INTO @ElapsedTime
                                SELECT  *
                                FROM    dbo.FunGetElapsedTime(@dEntra1, '',
                                                              @dEntra1, '')
                    END  
               
                IF @nIncidencia = 3 
                    BEGIN 
                        INSERT  INTO @ElapsedTime
                                SELECT  *
                                FROM    dbo.FunGetElapsedTime(@dEntra1, '',
                                                              @dOriginal, '')               
                    END  
               
                IF @nIncidencia = 4 
                    BEGIN 
                        INSERT  INTO @ElapsedTime
                                SELECT  *
                                FROM    dbo.FunGetElapsedTime(@dOriginal, '',
                                                              @dSale1, '')
                    END  
               
                IF @nIncidencia = 5 
                    BEGIN 
                        INSERT  INTO @ElapsedTime
                                SELECT  *
                                FROM    dbo.FunGetElapsedTime(@dSale1, '',
                                                              @dSale1, '')               
                    END  
                IF @nIncidencia = 6 
                    BEGIN 
                        INSERT  INTO @ElapsedTime
                                SELECT  *
                                FROM    dbo.FunGetElapsedTime(@dSale1, '',
                                                              @dOriginal, '')
                    END  
                IF @nIncidencia > 6 
                    BEGIN 
                        INSERT  INTO @ElapsedTime
                                SELECT  *
                                FROM    dbo.FunGetElapsedTime(@dEntra1, '',
                                                              @dSale1, '')
                    END
               
                SELECT  @nHorasCalculadas = horas + CONVERT(FLOAT, minutos)
                        / 100
                FROM    @ElapsedTime
                                    
                DELETE  @ElapsedTime
               
                SET @nObserva = @nHorasCalculadas--CONVERT(VARCHAR(100),@nHorasCalculadas)
            END	    
           
        DECLARE @cSale1Noc AS CHAR(20) 
        SET @cSale1Noc = CONVERT(VARCHAR(20), @dSale1Nocturno)
        
        
        --SET @nObserva = @nObserva + ' [' + @cEntra1 + ' - ' + @cSale1 + ']  ' 
        
        RETURN( @nObserva )
    END

GO

       
IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'ObtenRelojInterpretaChecadas')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojInterpretaChecadas

GO


CREATE PROCEDURE dbo.ObtenRelojInterpretaChecadas
    (
      @Empresa udtInteger ,
      @hora udtName ,
      @codigo udtInteger ,
      @fecha udtDateTime ,
      @terminal udtInteger ,
      @row1 udtName ,
      @row2 udtName ,
      @comedor udtName
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    
    DECLARE @H CHAR(1) ,
        @EoS CHAR(1) ,
        @Obs VARCHAR(60) ,
        @num_conc INT ,
        @mins FLOAT ,
        @alerta CHAR(30) ,
        @horario INT ,
        @periodo INT ,
        @ayo INT ,
        @centro VARCHAR(15) ,
        @tiponom INT ,
        @aplicara DATETIME ,
        @tipoturno INT
    DECLARE @NewCheck VARCHAR ,
        @extra_red CHAR(1)
    SET @Obs = '' 
    SET @num_conc = 0 
    SET @mins = 0
    SET @alerta = ''
    SET @EoS = ''
    SET @Centro = ''
    SET @ayo = YEAR(@fecha)
    SET @aplicara = @fecha
--Set @NewCheck = convert(datetime,convert(date,@fecha)+@hora)
--print extract(minute from @fecha+@hora + DATEPART(MINUTE, 5)
--print @NewCheck



    SELECT  @H = ISNULL(hind, 'F') ,
            @extra_red = ISNULL(media_hora, 'F')
    FROM    relch_paramet
    WHERE   empresa = @empresa

    PRINT @h + ' Horarios Independientes a la nomina'

    SELECT  @periodo = p.periodo ,
            @tiponom = a.tiponom ,
            @centro = a.centro ,
            @tipoturno = ISNULL(h.tipoturno, 1)
    FROM    empleados AS e
            INNER JOIN llaves AS a ON a.empresa = e.empresa
                                      AND a.codigo = e.codigo
            INNER JOIN periodos AS p ON a.empresa = p.empresa
                                        AND a.tiponom = p.tiponom
                                        AND ( @fecha >= p.inicio
                                              AND @fecha <= p.cierre
                                            )
            INNER JOIN horarios_catalogo AS h ON a.empresa = h.empresa
                                                 AND a.horario = CASE
                                                              WHEN @h = 'T'
                                                              AND e.horario IS NULL
                                                              THEN a.horario
                                                              WHEN @h = 'F'
                                                              THEN a.horario
                                                              WHEN @h = 'T'
                                                              AND NOT e.horario IS NULL
                                                              THEN e.horario
                                                              END
    WHERE   a.codigo = @codigo
            AND a.empresa = @empresa

    DECLARE @nSetdatefirst INT ,
        @ChecaH INT ,
        @ChecaM INT


    SELECT  @nSetdatefirst = @@DATEFIRST --Primer Dia de la Semana Lunes
    SET DATEFIRST 1

    DECLARE @TurnoN CHAR(1) ,
        @Descanso CHAR(1) ,
        @FactorA NUMERIC(8, 2) ,
        @EntH1 INT ,
        @EntH2 INT ,
        @EntM1 INT ,
        @EntM2 INT ,
        @SalH1 INT ,
        @SalH2 INT ,
        @SalM1 INT ,
        @SalM2 INT ,
        @Dia_S INT ,
        @Turno INT ,
        @SalAn INT ,
        @borra CHAR(1) ,
        @DesAn CHAR(1)

    SET @Dia_S = CASE WHEN DATENAME(dw, @Fecha) = 'Lunes'
                           OR DATENAME(dw, @Fecha) = 'Monday' THEN 1
                      WHEN DATENAME(dw, @Fecha) = 'Martes'
                           OR DATENAME(dw, @Fecha) = 'Tuesday' THEN 2
                      WHEN DATENAME(dw, @Fecha) = 'Mircoles'
                           OR DATENAME(dw, @Fecha) = 'Wednesday' THEN 3
                      WHEN DATENAME(dw, @Fecha) = 'Jueves'
                           OR DATENAME(dw, @Fecha) = 'Thursday' THEN 4
                      WHEN DATENAME(dw, @Fecha) = 'Viernes'
                           OR DATENAME(dw, @Fecha) = 'Friday' THEN 5
                      WHEN DATENAME(dw, @Fecha) = 'Sbado'
                           OR DATENAME(dw, @Fecha) = 'Saturday ' THEN 6
                      WHEN DATENAME(dw, @Fecha) = 'Domingo'
                           OR DATENAME(dw, @Fecha) = 'Sunday ' THEN 7
                 END
--DATEPART(dw,@Fecha)
    PRINT 'Dia Original ' + CAST(@Dia_S AS CHAR(15))
    SELECT  @SalAn = CAST(SUBSTRING(b.sale1, 1, 2) AS INT) ,
            @DesAn = b.descanso
    FROM    llaves AS a
            INNER JOIN empleados AS e ON e.empresa = a.empresa
                                         AND e.codigo = a.codigo
            INNER JOIN detalle_horarios AS b ON b.empresa = a.empresa
                                                AND b.horario = CASE
                                                              WHEN @h = 'T'
                                                              AND e.horario IS NULL
                                                              THEN a.horario
                                                              WHEN @h = 'F'
                                                              THEN a.horario
                                                              WHEN @h = 'T'
                                                              AND NOT e.horario IS NULL
                                                              THEN e.horario
                                                              END
                                                AND b.dia_semana = @Dia_S - 1
            INNER JOIN horarios_catalogo AS h ON h.empresa = b.empresa
                                                 AND h.horario = b.horario
    WHERE   a.empresa = @empresa
            AND a.codigo = @codigo

    SET @SalAn = CASE WHEN @SalAn IS NULL
                           OR @DesAn = 'T' THEN 9999
                      ELSE @SalAn
                 END
    PRINT CAST(@DesAn AS CHAR(15)) + ' Descan Dia anterior'
    PRINT CAST(@SalAn AS CHAR(15)) + ' Salida Dia anterior'

    SELECT  @Dia_S = CASE WHEN b.descanso = 'F'
                               AND @SalAn >= 12 THEN @Dia_S
                          WHEN ( b.descanso = 'T'
                                 OR ( @ChecaH < 12
                                      AND b.descanso = 'F'
                                    )
                               )
                               AND @SalAn < 12
                               AND @ChecaH < 12 THEN @Dia_S - 1
                          WHEN b.descanso = 'T'
                               AND @SalAn < 12
                               AND @ChecaH >= 12 THEN @Dia_S
                          WHEN b.descanso = 'T'
                               AND @SalAn > 12 THEN @Dia_S
                          WHEN @SalAn = 9999 THEN @Dia_S
                          ELSE @Dia_S
                     END ,
            @borra = CASE WHEN b.descanso = 'F'
                               AND @SalAn >= 12 THEN 'S'
                          WHEN ( b.descanso = 'T'
                                 OR ( @ChecaH < 12
                                      AND b.descanso = 'F'
                                    )
                               ) THEN 'N'
                          WHEN b.descanso = 'T'
                               AND @SalAn < 12
                               AND @ChecaH < 12 THEN 'N'
                          WHEN b.descanso = 'T'
                               AND @SalAn < 12
                               AND @ChecaH >= 12 THEN 'S'
                          WHEN b.descanso = 'T'
                               AND @SalAn > 12 THEN 'S'
                          WHEN @SalAn = 9999 THEN 'S'
                          ELSE 'S'
                     END
    FROM    llaves AS a
            INNER JOIN empleados AS e ON e.empresa = a.empresa
                                         AND e.codigo = a.codigo
            INNER JOIN detalle_horarios AS b ON b.empresa = a.empresa
                                                AND b.horario = CASE
                                                              WHEN @h = 'T'
                                                              AND e.horario IS NULL
                                                              THEN a.horario
                                                              WHEN @h = 'F'
                                                              THEN a.horario
                                                              WHEN @h = 'T'
                                                              AND NOT e.horario IS NULL
                                                              THEN e.horario
                                                              END
                                                AND b.dia_semana = @Dia_S
            INNER JOIN horarios_catalogo AS h ON h.empresa = b.empresa
                                                 AND h.horario = b.horario
    WHERE   a.empresa = @empresa
            AND a.codigo = @codigo

    PRINT 'Dia a Revisar ' + CAST(@Dia_S AS CHAR(15))

    IF @borra = 'S' 
        BEGIN
            DELETE  relch_registro
            WHERE   fecha = @fecha
                    AND empresa = empresa
                    AND codigo = @codigo
                    AND num_conc = 108
                    OR obs = 'Descanso'--checada=@hora
        END

    SELECT  @TurnoN = b.turno_noc ,
            @Descanso = b.descanso ,
            @FactorA = b.factor_aus ,
            @EntH1 = CAST(SUBSTRING(b.entra1, 1, 2) AS INT) ,--case when Cast(SubString(b.entra1,1,2) as int)=0 then 24 else Cast(SubString(b.entra1,1,2) as int) end,
            @EntM1 = CAST(SUBSTRING(b.entra1, 3, 2) AS INT) ,
            @EntH2 = CASE WHEN SUBSTRING(b.entra2, 1, 2) = ''
                               OR SUBSTRING(b.entra2, 1, 2) IS NULL THEN -1
                          ELSE CAST(SUBSTRING(b.entra2, 1, 2) AS INT)
                     END ,--case when cast(SubString(b.entra2,1,2)as int)=0 then 24 else cast(SubString(b.entra2,1,2) as int) end end		
            @EntM2 = CASE WHEN SUBSTRING(b.entra2, 3, 2) = ''
                               OR SUBSTRING(b.entra2, 3, 2) IS NULL THEN -1
                          ELSE CAST(SUBSTRING(b.entra2, 3, 2) AS INT)
                     END ,
            @SalH1 = CAST(SUBSTRING(b.sale1, 1, 2) AS INT) ,--case when cast(SubString(b.sale1,1,2) as int)=0 then 24 else cast(SubString(b.sale1,1,2) as int) end,
            @SalM1 = CAST(SUBSTRING(b.sale1, 3, 2) AS INT) ,
            @SalH2 = CASE WHEN SUBSTRING(b.sale2, 1, 2) = ''
                               OR SUBSTRING(b.sale2, 1, 2) IS NULL THEN -1
                          ELSE CAST(SUBSTRING(b.sale2, 1, 2) AS INT)
                     END ,--case when cast(SubString(b.sale2,1,2) as int)=0 then 24 else cast(SubString(b.sale2,1,2) as int) end end,		
            @SalM2 = CASE WHEN SUBSTRING(b.sale2, 3, 2) = ''
                               OR SUBSTRING(b.sale2, 3, 2) IS NULL THEN -1
                          ELSE CAST(SUBSTRING(b.sale2, 3, 2) AS INT)
                     END ,
            @Turno = h.turno ,
            @horario = b.horario
    FROM    llaves AS a
            INNER JOIN empleados AS e ON e.empresa = a.empresa
                                         AND e.codigo = a.codigo
            INNER JOIN detalle_horarios AS b ON b.empresa = a.empresa
                                                AND b.horario = CASE
                                                              WHEN @h = 'T'
                                                              AND e.horario IS NULL
                                                              THEN a.horario
                                                              WHEN @h = 'F'
                                                              THEN a.horario
                                                              WHEN @h = 'T'
                                                              AND NOT e.horario IS NULL
                                                              THEN e.horario
                                                              END
                                                AND b.dia_semana = @Dia_S
            INNER JOIN horarios_catalogo AS h ON h.empresa = b.empresa
                                                 AND h.horario = b.horario
    WHERE   a.empresa = @empresa
            AND a.codigo = @codigo

    PRINT CAST(@SalH1 AS CHAR(10)) + ' Hora de salida' 

    PRINT CAST(@horario AS CHAR(5)) + ' horario'

    SET DATEFIRST @nSetdatefirst --Regresa Primer Dia a original del sistema

    DECLARE @D CHAR(1)
	
    IF @comedor = 'C' 
        BEGIN
			
            INSERT  INTO relch_registro
                    ( empresa ,
                      codigo ,
                      serial ,
                      checada ,
                      fecha ,
                      num_conc ,
                      obs ,
                      importe ,
                      tiempo ,
                      comedor ,
                      EoS ,
                      periodo ,
                      ayo ,
                      terminal ,
                      tiponom ,
                      centro ,
                      horario ,
                      aplicara ,
                      crf ,
                      crf2
                    )
            VALUES  ( @empresa ,
                      @codigo ,
                      0 ,
                      @hora ,
                      @fecha ,
                      0 ,
                      'REGISTRO DE COMEDOR' ,
                      0 ,
                      0 ,
                      'T' ,
                      '1' ,
                      @periodo ,
                      @ayo ,
                      @terminal ,
                      @tiponom ,
                      @centro ,
                      @horario ,
                      @aplicara ,
                      @row1 ,
                      @row2
                    )
			
            DECLARE @totalcomidas INTEGER
            SET @totalcomidas = ISNULL(( SELECT comidas
                                         FROM   dbo.relch_comidas
                                         WHERE  empresa = @empresa
                                                AND fecha = @fecha
                                       ), 0)
            IF @totalcomidas > 0 
                BEGIN
                    UPDATE  dbo.relch_comidas
                    SET     comidas = @totalcomidas + 1
                    WHERE   empresa = @empresa
                            AND fecha = @fecha
                END
            ELSE 
                BEGIN
                    INSERT  INTO dbo.relch_comidas
                            ( empresa, fecha, comidas, importe )
                    VALUES  ( @empresa, -- empresa - numeric
                              @fecha, -- fecha - datetime
                              1, -- comidas - numeric
                              0  -- importe - decimal
                              )                    
                END 
        END	
    ELSE 
        BEGIN
            PRINT 'Descanso Ant ' + @Descanso
            IF @Descanso = 'T' 
                BEGIN 
                    PRINT 'Descanso Laborado'
                    DECLARE @checad CHAR(8)
			
                    DELETE dbo.relch_registro WHERE empresa = @empresa
                            AND codigo = @codigo
                            AND fecha = @fecha
                            AND num_conc<>10
                            
                            
                    SET @D = ISNULL(( SELECT    MAX('F')
                                      FROM      relch_registro
                                      WHERE     empresa = @empresa
                                                AND codigo = @codigo
                                                AND fecha = @fecha
                                    ), 'T')-- and num_conc=10
                    PRINT @d
                    SELECT  @checad = checada
                    FROM    relch_registro
                    WHERE   empresa = @empresa
                            AND codigo = @codigo
                            AND fecha = @fecha
                            AND obs = 'Entrada DESC LAB'
                                               
                    SET @Obs = CASE WHEN @d = 'T' THEN 'Entrada DESC LAB'
                                    ELSE 'Salida DESC LAB'
                               END 
                    SET @num_conc = 10
                    IF @Obs = 'Salida DESC LAB' 
                        BEGIN
                            SET @EoS = 'S'
                            SET @ChecaH = CAST(SUBSTRING(@hora, 1, 2) AS INT)
                            SET @ChecaM = CAST(SUBSTRING(@hora, 4, 2) AS INT)
                            
                            DECLARE @mins1hora udtInteger
                            DECLARE @minshoraslabs udtInteger

                            SELECT  @mins1hora = CASE WHEN CAST(SUBSTRING(@checad,
                                                              4, 2) AS INT) > 0
                                                      THEN 60
                                                           - CAST(SUBSTRING(@checad,
                                                              4, 2) AS INT)
                                                      ELSE 0
                                                 END 
                            SELECT  @minshoraslabs = CASE WHEN @mins1hora > 0
                                                          THEN @ChecaH
                                                              - ( CAST(SUBSTRING(@checad,
                                                              1, 2) AS INT)
                                                              + 1 )
                                                          ELSE @ChecaH
                                                              - ( CAST(SUBSTRING(@checad,
                                                              1, 2) AS INT)
                                                              + 1 )
                                                     END * 60
                            
                            PRINT 'Begin'
                            PRINT @ChecaH
                            PRINT 'ChecaH'
                            PRINT @ChecaM
                            PRINT 'ChecaM'
                            PRINT @checad
                            PRINT 'Checad'
                            PRINT @mins1hora
                            PRINT '@mins1hora'
                            PRINT @minshoraslabs
                            PRINT '@minshoraslabs'
                            PRINT 'End'
                            SELECT  @mins = CAST(CAST(( @mins1hora
                                                        + @minshoraslabs
                                                        + ( @checaM ) ) AS NUMERIC(10,
                                                              2)) / 60 AS NUMERIC(10,
                                                              2))
                        END
                    IF @Obs = 'Entrada DESC LAB' 
                        BEGIN
                            SET @EoS = 'E'
                        END
                    INSERT  INTO relch_registro
                            ( empresa ,
                              codigo ,
                              serial ,
                              checada ,
                              fecha ,
                              num_conc ,
                              obs ,
                              importe ,
                              tiempo ,
                              comedor ,
                              EoS ,
                              periodo ,
                              ayo ,
                              terminal ,
                              tiponom ,
                              centro ,
                              horario ,
                              aplicara ,
                              crf ,
                              crf2
                            )
                    VALUES  ( @empresa ,
                              @codigo ,
                              0 ,
                              @hora ,
                              @fecha ,
                              @num_conc ,
                              @obs ,
                              0 ,
                              @mins ,
                              'F' ,
                              @EoS ,
                              @periodo ,
                              @ayo ,
                              @terminal ,
                              @tiponom ,
                              @centro ,
                              @horario ,
                              @aplicara ,
                              @row1 ,
                              @row2
                            )
                END

            SET @Descanso = CASE WHEN @Descanso = 'T'
                                      AND @Dia_S <> 7 THEN 'T'
                                 WHEN @Descanso = 'T'
                                      AND @Dia_S = 7
                                      AND @ChecaH < 12 THEN 'T'
                                 WHEN @Descanso = 'T'
                                      AND @Dia_S = 7
                                      AND @ChecaH >= 13 THEN 'F'
                                 WHEN @Descanso = 'F' THEN 'F'
                            END 
            PRINT 'Descanso ' + @Descanso

            IF @Descanso <> 'T' 
                BEGIN
                    PRINT 'Dia Laboral'
                    DECLARE @NCheck CHAR(1) ,
                        @Tarde CHAR(1) ,
                        @MinTar NUMERIC(8, 0) ,
                        @CHora CHAR(1) ,
                        @NTEx CHAR(1)

                    SELECT  @NCheck = ISNULL(b.nochecar, 'F') ,
                            @Tarde = ISNULL(b.tarde, 'F') ,
                            @MinTar = ISNULL(b.mintarde, 0) ,
                            @CHora = ISNULL(b.chora, 'F') ,
                            @NTEx = ISNULL(b.notmp_extra, 'F')
                    FROM    empleados AS a
                            LEFT JOIN relch_exep AS b ON a.empresa = b.empresa
                                                         AND a.codigo = b.codigo
                    WHERE   a.empresa = @empresa
                            AND a.codigo = @Codigo
                    PRINT @NCheck
                    PRINT @Tarde
                    PRINT @MinTar
                    PRINT @CHora
	
                    IF ( @NCheck = 'F'
                         AND @Tarde = 'F'
                         AND @CHora = 'F'
                       )
                        OR ( @NCheck IS NULL
                             AND @Tarde IS NULL
                             AND @CHora IS NULL
                           )--Revisa Exepciones
                        PRINT 'Sin Exepcion'
                    ELSE 
                        PRINT 'Con Exepcion'
	
                    IF @CHora = 'T'
                        OR @NCheck = 'T' 
                        BEGIN
		
                            PRINT 'Inserta con exepcion Checar a cualquier hora o pude no checar'
                            IF NOT EXISTS(SELECT codigo FROM dbo.relch_registro WHERE empresa=@empresa AND codigo=@codigo AND fecha=@fecha AND checada=@hora)
                            BEGIN
                            INSERT  INTO relch_registro
                                    ( empresa ,
                                      codigo ,
                                      serial ,
                                      checada ,
                                      fecha ,
                                      num_conc ,
                                      obs ,
                                      importe ,
                                      tiempo ,
                                      comedor ,
                                      EoS ,
                                      periodo ,
                                      ayo ,
                                      terminal ,
                                      tiponom ,
                                      centro ,
                                      horario ,
                                      aplicara ,
                                      crf ,
                                      crf2
                                    )
                            VALUES  ( @empresa ,
                                      @codigo ,
                                      0 ,
                                      @hora ,
                                      @fecha ,
                                      0 ,
                                      'Checada' ,
                                      0 ,
                                      0 ,
                                      'F' ,
                                      NULL ,
                                      @periodo ,
                                      @ayo ,
                                      @terminal ,
                                      @tiponom ,
                                      @centro ,
                                      @horario ,
                                      @fecha ,
                                      @row1 ,
                                      @row2
                                    )
                            END
                        END
                    ELSE 
                        BEGIN
                            DECLARE @nn AS FLOAT
                            SELECT  @nn = dbo.GetAnalisisRelojObserva(@Fecha,
                                                              @hora, @horario,
                                                              @empresa, @Dia_S,
                                                              0)
                            SET @obs = CASE WHEN @nn = 1 THEN 'Entrada'--'Entrada A'
                                            WHEN @nn = 2 THEN 'Entrada'
                                            WHEN @nn = 3 THEN 'Retardo'
                                            WHEN @nn = 4
                                            THEN 'Salida Anticipada'
                                            WHEN @nn = 5 THEN 'Salida'
                                            WHEN @nn = 6 THEN 'Tiempo extra'
                                            WHEN @nn = 8 THEN 'Salida C'
                                            WHEN @nn = 6 THEN 'Entrada C'
                                            ELSE 'Checada fuera de horario'
                                       END
		
                            SELECT  @mins = ISNULL(dbo.GetAnalisisRelojObserva(@Fecha,
                                                              @hora, @horario,
                                                              @empresa, @Dia_S,
                                                              1), 0)
		
                            SET @num_conc = CASE WHEN @nn = 1 THEN 0
                                                 WHEN @nn = 2 THEN 0
                                                 WHEN @nn = 3 THEN 120
                                                 WHEN @nn = 4 THEN 120
                                                 WHEN @nn = 5 THEN 0
                                                 WHEN @nn = 6 THEN 11
                                                 ELSE 0
                                            END
		
                            SET @mins = CASE WHEN @extra_red = 'T'
                                                  AND @num_conc = 11
                                             THEN ROUND(@mins, 0, 1)
                                                  + CASE WHEN @mins
                                                              - ROUND(@mins, 0,
                                                              1) >= .3 THEN .3
                                                         WHEN @mins
                                                              - ROUND(@mins, 0,
                                                              1) <= .2 THEN .0
                                                         ELSE 0
                                                    END
                                             ELSE @mins
                                        END 
		
		
                            SET @EoS = CASE WHEN @nn = 1 THEN 'E'
                                            WHEN @nn = 2 THEN 'E'
                                            WHEN @nn = 3 THEN 'E'
                                            WHEN @nn = 4 THEN 'S'
                                            WHEN @nn = 5 THEN 'S'
                                            WHEN @nn = 6 THEN 'S'
                                            ELSE 'E'
                                       END
		--@dInicio DATETIME ,
		--@cChecada DATETIME ,
		--@nHorario INT ,
		--@nEmpresa INT ,
		--@nRegresa AS INT
                            DECLARE @Revisa CHAR(1) ,
                                @Muestra VARCHAR(15)
                            PRINT @eos + ' EoS' 
                            SELECT  @Revisa = CASE WHEN MAX(checada) IS NULL
                                                   THEN 'S'
                                                   ELSE 'N'
                                              END--@Revisa=case when checada is null then 'S' else 'N' end
                            FROM    relch_registro
                            WHERE   empresa = @empresa
                                    AND codigo = @codigo
                                    AND fecha = @fecha
                                    AND eos = @EoS
		
		--Set @Muestra = isnull((select 'T' from relch_registro where empresa=@empresa and codigo=@codigo and fecha=@fecha and (convert(int,substring(checada,1,2))=@ChecaH and convert(int,substring(checada,4,2))=@Checam) group by empresa,codigo,substring(checada,1,2)+':'+substring(checada,4,2)),'F')
                            SET @Muestra = ISNULL(( SELECT  'T'
                                                    FROM    relch_registro
                                                    WHERE   empresa = @empresa
                                                            AND codigo = @codigo
                                                            AND fecha = @fecha
                                                            AND eos = @EoS
                                                  ), 'F')
                            PRINT @Muestra

                            PRINT @revisa
                            PRINT ( ( @ChecaH * 60 ) + @Checam ) - ( ( @SalH1
                                                              * 60 ) + @SalM1 )
                            PRINT 'Concepto'
                            PRINT @num_conc
                            SET @obs = @obs
                                + CASE WHEN @num_conc = 120
                                            OR @num_conc = 11
                                       THEN ' '
                                            + RTRIM(LTRIM(CAST(@MINS AS VARCHAR(20))))
                                            + ' hrs.'
                                       ELSE ''
                                  END
		--Print 'Observacion: ' + @obs + CAST(@MINS AS VARCHAR(20))
                            PRINT @obs 
                            PRINT 'Observacion'
                            IF @Dia_S = 7
                                AND ( @obs = 'Entrada A'
                                      OR @obs = 'Entrada'
                                    ) --and @descanso='T'--Inserta Prima Dominical solo si es entrada y Domingo 
                                BEGIN
                                    PRINT 'Prima Dominical'
                                    INSERT  INTO relch_registro
                                            ( empresa ,
                                              codigo ,
                                              serial ,
                                              checada ,
                                              fecha ,
                                              num_conc ,
                                              obs ,
                                              importe ,
                                              tiempo ,
                                              comedor ,
                                              EoS ,
                                              periodo ,
                                              ayo ,
                                              terminal ,
                                              tiponom ,
                                              centro ,
                                              horario ,
                                              aplicara ,
                                              crf ,
                                              crf2
                                            )
                                    VALUES  ( @empresa ,
                                              @codigo ,
                                              0 ,
                                              '00:00:00' ,
                                              @fecha ,
                                              9 ,
                                              'Prima Dominical' ,
                                              0 ,
                                              0 ,
                                              'F' ,
                                              '' ,
                                              @periodo ,
                                              @ayo ,
                                              0 ,
                                              @tiponom ,
                                              @centro ,
                                              @horario ,
                                              @aplicara ,
                                              @row1 ,
                                              @row2
                                            )
                                END
		
                            IF @Muestra = 'F' 
                                BEGIN
                                    PRINT 'Inserta'
                                    INSERT  INTO relch_registro
                                            ( empresa ,
                                              codigo ,
                                              serial ,
                                              checada ,
                                              fecha ,
                                              num_conc ,
                                              obs ,
                                              importe ,
                                              tiempo ,
                                              comedor ,
                                              EoS ,
                                              periodo ,
                                              ayo ,
                                              terminal ,
                                              tiponom ,
                                              centro ,
                                              horario ,
                                              aplicara ,
                                              crf ,
                                              crf2
                                            )
                                    VALUES  ( @empresa ,
                                              @codigo ,
                                              0 ,
                                              @hora ,
                                              @fecha ,
                                              @num_conc ,
                                              @obs ,
                                              0 ,
                                              @mins ,
                                              'F' ,
                                              @EoS ,
                                              @periodo ,
                                              @ayo ,
                                              @terminal ,
                                              @tiponom ,
                                              @centro ,
                                              @horario ,
                                              @aplicara ,
                                              @row1 ,
                                              @row2
                                            )
                                END
                            ELSE 
                                BEGIN 
                                    PRINT 'Checada repetida'
                                END
		
                        END
	
		
                END
            ELSE 
                PRINT 'Descanso laborado'			
			
			
        END			



GO 

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'ObtenRelojDatosEmps')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE ObtenRelojDatosEmps

GO
	

CREATE PROCEDURE dbo.ObtenRelojDatosEmps
    (
      @empresa udtLong ,
      @codigo udtLong ,
      @fecha udtDateTime ,
      @hora udtName ,
      @comedor udtName ,
      @row1 udtName ,
      @row2 udtName
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    
    DECLARE @codigoCred udtLong ,
        @creds udtName,
        @periodo udtInteger,
        @tiponom udtInteger
    
    SET @creds = CASE WHEN @empresa = 0
                      THEN ISNULL(( SELECT  MAX(a.credenciales)
                                    FROM    dbo.relch_paramet AS a
                                  ), 'F')
                      ELSE ISNULL(( SELECT  MAX(a.credenciales)
                                    FROM    dbo.relch_paramet AS a
                                    WHERE   a.empresa = @empresa
                                  ), 'F')
                 END



    SET @codigoCred = CASE WHEN @creds = 'F' THEN @codigo
                           ELSE ISNULL(( SELECT MAX(codigo)
                                         FROM   dbo.empleados
                                         WHERE  credencial = @codigo
                                       ), @codigo)
                      END
	
    DECLARE @empresa_ter INT ,
        @m INT ,
        @cod INT ,
        @bloq udtLong
    SET @bloq = 0        
	
    SET @m = CASE WHEN NOT ( SELECT MAX(codigo)
                             FROM   empleados
                             WHERE  codigo = @codigoCred
                           ) IS NULL THEN 1
                  WHEN NOT ( SELECT MAX(codigo)
                             FROM   relch_fnomina
                             WHERE  codigo = @codigoCred
                           ) IS NULL THEN 2
                  ELSE 0
             END
	
    IF @m <> 0 
        BEGIN 
            SET @cod = @codigoCred
            IF @m = 1 
                BEGIN
                    SELECT  @empresa_ter = CASE WHEN @empresa IS NULL
                                                     OR @empresa = 0
                                                THEN MAX(empresa)
                                                ELSE @empresa
                                           END ,
                            @bloq = ISNULL(MAX(bloqueado), 0)
                    FROM    dbo.empleados
                    WHERE   codigo = @codigoCred
                            AND CASE WHEN ultmov <> 'B'
                                          AND activo = 'S' THEN 'S'
                                     WHEN ultmov = 'B'
                                          AND ultfchmov > @fecha THEN 'S'
                                     WHEN ultmov = 'B'
                                          AND ultfchmov <= @fecha THEN 'N'
                                     WHEN activo = 'N' THEN 'N'
                                END = 'S'
                END
            ELSE 
                BEGIN
                    SELECT  @empresa_ter = CASE WHEN @empresa IS NULL
                                                     OR @empresa = 0
                                                THEN MAX(empresa)
                                                ELSE @empresa
                                           END
                    FROM    dbo.relch_fnomina
                    WHERE   codigo = @codigoCred
                            AND activo = 'A' 
                END
        END
    ELSE 
        BEGIN
            SET @cod = 0
        END
	
    IF @cod = 0 
        BEGIN
            SELECT  '' AS nombre ,
                    '' AS centro ,
                    '' AS ocupa ,
                    0 AS horario ,
                    'Cdigo Incorrecto' AS mensaje ,
                    '' AS imagen ,
                    '' AS foto ,
                    0 AS codigo
        END
        
    ELSE 
        IF ( @cod > 0
             AND ISNULL(@empresa_ter, 0) = 0
           )
            OR @bloq = 1 
            BEGIN
                SELECT  '' AS nombre ,
                        '' AS centro ,
                        '' AS ocupa ,
                        0 AS horario ,
                        CASE WHEN @bloq = 1 THEN 'Trabajador Bloqueado'
                             ELSE 'Trabajador Dado de Baja'
                        END AS mensaje ,
                        '' AS imagen ,
                        '' AS foto ,
                        0 AS codigo
            END
        ELSE 
            BEGIN
                IF @comedor = 'C' 
                    BEGIN
                        PRINT 'comedor'
                        EXEC dbo.ObtenRelojInterpretaChecadas @empresa_ter,
                            @hora, @codigoCred, @fecha, 0, @row1, @row2, 'C'
                        SELECT  RTRIM(E.nombre) + ' ' + RTRIM(e.ap_paterno)
                                + ' ' + RTRIM(e.ap_materno) AS nombre ,
                                RTRIM(c.centro) + ' ' + RTRIM(c.nomdepto) AS centro ,
                                RTRIM(t.ocupacion) + ' ' + RTRIM(t.actividad) AS ocupa ,
                                l.horario ,
                                CASE WHEN ( SELECT  mensaje
                                            FROM    relch_msgper
                                            WHERE   empresa = @empresa_ter
                                                    AND ( codigo = @codigoCred )
                                                    AND ( @fecha BETWEEN desde AND hasta )
                                          ) IS NULL
                                          AND ( SELECT  mensaje
                                                FROM    relch_msgper
                                                WHERE   empresa = @empresa_ter
                                                        AND ( codigo = 0 )
                                                        AND ( @fecha BETWEEN desde AND hasta )
                                              ) IS NULL
                                     THEN CASE WHEN MONTH(e.fchnac) = MONTH(@fecha)
                                                    AND DAY(e.fchnac) = DAY(@fecha)
                                               THEN 'FELIZ CUMPLE AOS!!!!'
                                               WHEN CAST(SUBSTRING(@hora, 1, 2) AS INT) < 12
                                               THEN 'BUENOS DIAS'
                                               WHEN CAST(SUBSTRING(@hora, 1, 2) AS INT) >= 12
                                               THEN 'BUENAS TARDES'
                                          END
                                     WHEN ( SELECT  mensaje
                                            FROM    relch_msgper
                                            WHERE   empresa = @empresa_ter
                                                    AND ( codigo = @codigoCred )
                                                    AND ( @fecha BETWEEN desde AND hasta )
                                          ) <> ''
                                     THEN ( SELECT  mensaje
                                            FROM    relch_msgper
                                            WHERE   empresa = @empresa_ter
                                                    AND ( codigo = @codigoCred )
                                                    AND ( @fecha BETWEEN desde AND hasta )
                                          )
                                     WHEN ( SELECT  mensaje
                                            FROM    relch_msgper
                                            WHERE   empresa = @empresa_ter
                                                    AND ( codigo = 0 )
                                                    AND ( @fecha BETWEEN desde AND hasta )
                                          ) <> ''
                                     THEN ( SELECT  mensaje
                                            FROM    relch_msgper
                                            WHERE   empresa = @empresa_ter
                                                    AND ( codigo = 0 )
                                                    AND ( @fecha BETWEEN desde AND hasta )
                                          )
                                END AS mensaje ,
                                ( SELECT    imagen
                                  FROM      relch_msgper
                                  WHERE     empresa = @empresa_ter
                                            AND ( codigo = @codigoCred
                                                  OR codigo = 0
                                                )
                                            AND ( @fecha BETWEEN desde AND hasta )
                                ) AS imagen ,
                                d.foto ,
                                e.codigo
                        FROM    empleados AS e
                                LEFT JOIN llaves AS l ON e.empresa = l.empresa
                                                         AND e.codigo = l.codigo
                                INNER JOIN datosemps AS d ON d.empresa = l.empresa
                                                             AND d.codigo = l.codigo
                                LEFT JOIN centros AS c ON l.empresa = c.empresa
                                                          AND l.centro = c.centro
                                LEFT JOIN tabulador AS t ON l.empresa = t.empresa
                                                            AND l.ocupacion = t.ocupacion
                        WHERE   e.empresa = @empresa_ter
                                AND e.codigo = @codigoCred
                    END
                ELSE 
                    BEGIN
		
                        IF @m = 1 
                            BEGIN 
                                EXEC dbo.ObtenRelojInterpretaChecadas @empresa_ter,
                                    @hora, @codigoCred, @fecha, 0, @row1,
                                    @row2, ''
                            END
                        ELSE 
                            BEGIN
								
								SET @tiponom = (SELECT tiponom FROM dbo.Llaves WHERE empresa=@empresa AND codigo=@codigo)
								SET @periodo = (SELECT MAX(periodo) FROM dbo.Periodos WHERE  empresa=@empresa AND tiponom=@tiponom AND @fecha BETWEEN inicio AND cierre)

                                INSERT  INTO relch_registro
                                        ( empresa ,
                                          codigo ,
                                          serial ,
                                          checada ,
                                          fecha ,
                                          num_conc ,
                                          obs ,
                                          importe ,
                                          tiempo ,
                                          comedor ,
                                          EoS ,
                                          periodo ,
                                          ayo ,
                                          terminal ,
                                          tiponom ,
                                          centro ,
                                          horario ,
                                          aplicara ,
                                          crf ,
                                          crf2
                                        )
                                VALUES  ( @empresa_ter ,
                                          @cod ,
                                          0 ,
                                          @hora ,
                                          @fecha ,
                                          0 ,
                                          'Checada' ,
                                          0 ,
                                          0 ,
                                          'F' ,
                                          '' ,
                                          @periodo,
                                          YEAR(@fecha) ,
                                          0 ,
                                          @tiponom ,
                                          '' ,
                                          0 ,
                                          @fecha ,
                                          @row1 ,
                                          @row2
                                        )
                            END
                        IF @m = 1 
                            BEGIN
                                SELECT  RTRIM(E.nombre) + ' '
                                        + RTRIM(e.ap_paterno) + ' '
                                        + RTRIM(e.ap_materno) AS nombre ,
                                        RTRIM(c.centro) + ' '
                                        + RTRIM(c.nomdepto) AS centro ,
                                        RTRIM(t.ocupacion) + ' '
                                        + RTRIM(t.actividad) AS ocupa ,
                                        l.horario ,
                                        CASE WHEN ( SELECT  mensaje
                                                    FROM    relch_msgper
                                                    WHERE   empresa = @empresa_ter
                                                            AND ( codigo = @codigoCred )
                                                            AND ( @fecha BETWEEN desde AND hasta )
                                                  ) IS NULL
                                                  AND ( SELECT
                                                              mensaje
                                                        FROM  relch_msgper
                                                        WHERE empresa = @empresa_ter
                                                              AND ( codigo = 0 )
                                                              AND ( @fecha BETWEEN desde AND hasta )
                                                      ) IS NULL
                                             THEN CASE WHEN MONTH(e.fchnac) = MONTH(@fecha)
                                                            AND DAY(e.fchnac) = DAY(@fecha)
                                                       THEN 'FELIZ CUMPLE AOS!!!!'
                                                       WHEN CAST(SUBSTRING(@hora,
                                                              1, 2) AS INT) < 12
                                                       THEN 'BUENOS DIAS'
                                                       WHEN CAST(SUBSTRING(@hora,
                                                              1, 2) AS INT) >= 12
                                                       THEN 'BUENAS TARDES'
                                                  END
                                             WHEN ( SELECT  mensaje
                                                    FROM    relch_msgper
                                                    WHERE   empresa = @empresa_ter
                                                            AND ( codigo = @codigoCred )
                                                            AND ( @fecha BETWEEN desde AND hasta )
                                                  ) <> ''
                                             THEN ( SELECT  mensaje
                                                    FROM    relch_msgper
                                                    WHERE   empresa = @empresa_ter
                                                            AND ( codigo = @codigoCred )
                                                            AND ( @fecha BETWEEN desde AND hasta )
                                                  )
                                             WHEN ( SELECT  mensaje
                                                    FROM    relch_msgper
                                                    WHERE   empresa = @empresa_ter
                                                            AND ( codigo = 0 )
                                                            AND ( @fecha BETWEEN desde AND hasta )
                                                  ) <> ''
                                             THEN ( SELECT  mensaje
                                                    FROM    relch_msgper
                                                    WHERE   empresa = @empresa_ter
                                                            AND ( codigo = 0 )
                                                            AND ( @fecha BETWEEN desde AND hasta )
                                                  )
                                        END AS mensaje ,
                                        CASE WHEN ( SELECT  imagen
                                                    FROM    relch_msgper
                                                    WHERE   empresa = @empresa_ter
                                                            AND ( codigo = @codigoCred )
                                                            AND ( @fecha BETWEEN desde AND hasta )
                                                  ) IS NULL
                                                  AND ( SELECT
                                                              imagen
                                                        FROM  relch_msgper
                                                        WHERE empresa = @empresa_ter
                                                              AND ( codigo = 0 )
                                                              AND ( @fecha BETWEEN desde AND hasta )
                                                      ) IS NULL THEN NULL
                                             WHEN ( SELECT  imagen
                                                    FROM    relch_msgper
                                                    WHERE   empresa = @empresa_ter
                                                            AND ( codigo = @codigoCred )
                                                            AND ( @fecha BETWEEN desde AND hasta )
                                                  ) <> ''
                                             THEN ( SELECT  imagen
                                                    FROM    relch_msgper
                                                    WHERE   empresa = @empresa_ter
                                                            AND ( codigo = @codigoCred )
                                                            AND ( @fecha BETWEEN desde AND hasta )
                                                  )
                                             WHEN ( SELECT  imagen
                                                    FROM    relch_msgper
                                                    WHERE   empresa = @empresa_ter
                                                            AND ( codigo = 0 )
                                                            AND ( @fecha BETWEEN desde AND hasta )
                                                  ) <> ''
                                             THEN ( SELECT  imagen
                                                    FROM    relch_msgper
                                                    WHERE   empresa = @empresa_ter
                                                            AND ( codigo = 0 )
                                                            AND ( @fecha BETWEEN desde AND hasta )
                                                  )
                                        END AS imagen ,
                                        d.foto ,
                                        e.codigo
                                FROM    empleados AS e
                                        LEFT JOIN llaves AS l ON e.empresa = l.empresa
                                                              AND e.codigo = l.codigo
                                        INNER JOIN datosemps AS d ON d.empresa = l.empresa
                                                              AND d.codigo = l.codigo
                                        LEFT JOIN centros AS c ON l.empresa = c.empresa
                                                              AND l.centro = c.centro
                                        LEFT JOIN tabulador AS t ON l.empresa = t.empresa
                                                              AND l.ocupacion = t.ocupacion
                                WHERE   e.empresa = @empresa_ter
                                        AND e.codigo = @codigoCred
                            END
                        ELSE 
                            BEGIN
				--select * from relch_fnomina
                                SELECT  e.nombre ,
                                        '' AS centro ,
                                        '' AS ocupa ,
                                        e.horario ,
                                        CASE WHEN CAST(SUBSTRING(@hora, 1, 2) AS INT) < 12
                                             THEN 'BUENOS DIAS'
                                             WHEN CAST(SUBSTRING(@hora, 1, 2) AS INT) >= 12
                                             THEN 'BUENAS TARDES'
                                        END AS mensaje ,
                                        '' AS imagen ,
                                        e.foto ,
                                        e.codigo
                                FROM    relch_fnomina AS e
                                WHERE   e.empresa = @empresa_ter
                                        AND e.codigo = @codigoCred
                            END
                    END 
            END	
	
		
	
GO



IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojReportesListadoCentros')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojReportesListadoCentros
GO

CREATE PROCEDURE dbo.obtenRelojReportesListadoCentros
    (
      @empresa AS udtInteger 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    SELECT DISTINCT
            ( l.centro ) ,
            c.nomdepto AS depto
    FROM    dbo.empleados AS e
            INNER JOIN dbo.llaves AS l ON e.empresa = l.empresa
                                          AND e.codigo = l.codigo
            INNER JOIN dbo.centros AS c ON l.centro = c.centro
                                           AND l.empresa = c.empresa
    WHERE   e.activo = 'S'
            AND e.ultmov <> 'B'
            AND l.centro <> ' '
            AND l.empresa = @empresa
        
        
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojReportesListadoSupervisores')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojReportesListadoSupervisores
GO

CREATE PROCEDURE dbo.obtenRelojReportesListadoSupervisores
    (
      @empresa AS udtInteger 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    SELECT DISTINCT
            ( l.SUPERVISOR ) ,
            s.nombre
    FROM    dbo.empleados AS e
            INNER JOIN dbo.llaves AS l ON e.empresa = l.empresa
                                          AND e.codigo = l.codigo
            INNER JOIN dbo.supervisores AS s ON l.empresa = s.empresa
                                                AND l.supervisor = s.supervisor
    WHERE   e.activo = 'S'
            AND e.ultmov <> 'B'
            AND l.centro <> ' '
            AND l.empresa = @empresa
        
        
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojReportesListadoLinea')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojReportesListadoLinea
GO

CREATE PROCEDURE dbo.obtenRelojReportesListadoLinea
    (
      @empresa AS udtInteger 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    SELECT	DISTINCT
            ( l.linea ) ,
            li.nombre AS linea
    FROM    empleados AS e
            INNER JOIN llaves AS l ON e.empresa = l.empresa
                                      AND e.codigo = l.codigo
            INNER JOIN relch_lineas AS li ON l.empresa = li.empresa
                                             AND l.linea = li.linea
    WHERE   e.activo = 'S'
            AND e.ultmov <> 'B'
            AND l.empresa = @empresa
        
        
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojReportesListadoHorarios')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojReportesListadoHorarios
GO

CREATE PROCEDURE dbo.obtenRelojReportesListadoHorarios
    (
      @empresa AS udtInteger 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    SELECT	DISTINCT
            ( l.horario ) ,
            h.nombre
    FROM    empleados AS e
            INNER JOIN llaves AS l ON e.empresa = l.empresa
                                      AND e.codigo = l.codigo
            INNER JOIN dbo.horarios_catalogo AS h ON l.empresa = h.empresa
                                                     AND l.horario = h.horario
    WHERE   e.activo = 'S'
            AND e.ultmov <> 'B'
            AND l.empresa = @empresa
        
        
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojReportesListadoNominas')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojReportesListadoNominas
GO

CREATE PROCEDURE dbo.obtenRelojReportesListadoNominas
    (
      @empresa AS udtInteger 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    SELECT	DISTINCT
            ( l.tiponom ) ,
            n.nomina AS nomina
    FROM    empleados AS e
            INNER JOIN llaves AS l ON e.empresa = l.empresa
                                      AND e.codigo = l.codigo
            INNER JOIN dbo.Nominas AS n ON l.empresa = n.empresa
                                           AND l.tiponom = n.tiponom
    WHERE   e.activo = 'S'
            AND e.ultmov <> 'B'
            AND e.empresa = @empresa
        
        
GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojListadoFotos')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojListadoFotos
GO

CREATE PROCEDURE dbo.obtenRelojListadoFotos
    (
      @empresa AS udtInteger 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    ( SELECT    a.codigo ,
                RTRIM(a.nombre) + ' ' + RTRIM(a.ap_paterno) + ' '
                + RTRIM(a.ap_materno) AS nombre ,
                '' AS condicion ,
                ISNULL(f.foto, '') AS foto
      FROM      dbo.empleados AS a
                LEFT JOIN dbo.datosemps AS f ON a.empresa = f.empresa
                                                AND a.codigo = f.codigo
      WHERE     a.empresa = @empresa
                AND a.activo = 'S'
    )
    UNION
    ( SELECT    codigo ,
                nombre ,
                'F' AS condicion ,
                ISNULL(foto, '') AS foto
      FROM      dbo.relch_fnomina
      WHERE     empresa = @empresa
                AND activo = 'A'
    )


GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.modificaRelojFoto')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.modificaRelojFoto
GO

CREATE PROCEDURE dbo.modificaRelojFoto
    (
      @empresa AS udtInteger ,
      @codigo AS udtInteger ,
      @file AS udtStringSize4096
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    
    UPDATE  dbo.datosemps
    SET     foto = @file
    WHERE   empresa = @empresa
            AND codigo = @codigo
    
GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojReporte001')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojReporte001
GO

CREATE PROCEDURE dbo.obtenRelojReporte001
    (
      @empresa udtInteger ,
      @fecha1 udtDateTime ,
      @fecha2 udtDateTime ,
      @tiponom udtInteger ,
      @filtroPor udtStringSize128 ,
      @filtroValor udtStringSize128 ,
      @grupo udtName ,
      @codigos udtName
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY
    DECLARE @recordId AS udtId

    DECLARE @endDate udtDateTime
    DECLARE @date udtDateTime
    DECLARE @stringEntrada1 udtStringSize1024 
    DECLARE @stringSalida1 udtStringSize1024 
    DECLARE @stringEntrada2 udtStringSize1024 
    DECLARE @stringSalida2 udtStringSize1024 
    DECLARE @stringObs udtStringSize1024  
    DECLARE @string udtStringSize1024  
    DECLARE @whereClause udtStringSize1024  

    SET @stringEntrada1 = '''En'' as Tipo,'
    SET @stringSalida1 = '''Sa'' as Tipo,'
    SET @stringEntrada2 = '''En'' as Tipo,'
    SET @stringSalida2 = '''Sa'' as Tipo,'
    SET @stringObs = '''Ob'' as Tipo,'
    SET @string = ''
    SET @whereClause = ''
	
    SET @date = @fecha1
	
    WHILE @date <= @fecha2 
        BEGIN 
            SET @stringEntrada1 = @stringEntrada1 + '['
                + CONVERT(VARCHAR(30), @date, 103) + '],'
            SET @stringEntrada2 = @stringEntrada2 + '['
                + CONVERT(VARCHAR(30), @date, 103) + '],'
            SET @stringSalida1 = @stringSalida1 + '['
                + CONVERT(VARCHAR(30), @date, 103) + '],'
            SET @stringSalida2 = @stringSalida2 + '['
                + CONVERT(VARCHAR(30), @date, 103) + '],'
            SET @stringObs = @stringObs + '[' + CONVERT(VARCHAR(30), @date, 103)
                + '],'
            SET @string = @string + '[' + CONVERT(VARCHAR(30), @date, 103)
                + '],'--convert(varchar(30),@date,103)
            SET @date = @date + 1 
        END 
        
--PRINT @stringEntrada1

    DECLARE @n1 INT ,
        @n2 INT ,
        @n3 INT ,
        @n4 INT ,
        @n5 INT ,
        @n6 INT
    IF @tiponom = 0 
        BEGIN
            SET @n1 = 1
            SET @n2 = 2
            SET @n3 = 3
            SET @n4 = 4
            SET @n5 = 5
            SET @n6 = 6
        END
    ELSE 
        BEGIN
            SET @n1 = @tiponom
            SET @n2 = 0
            SET @n3 = 0
            SET @n4 = 0
            SET @n5 = 0
            SET @n6 = 0
        END

--select * from relch_reportes

    DELETE  dbo.relch_reporte

    DECLARE @nSetdatefirst INT

    SELECT  @nSetdatefirst = @@DATEFIRST --Primer Dia de la Semana Lunes
    SET DATEFIRST 1

    INSERT  INTO dbo.relch_reporte
            ( empresa ,
              codigo ,
              fecha ,
              checada ,
              obs ,
              sec ,
              tiempo ,
              num_conc ,
              supervisor ,
              centro ,
              hrsturno ,
              orden
            )
            SELECT  a.empresa ,
                    a.codigo ,
                    a.aplicara ,
                    a.checada ,
                    ( CASE WHEN ( a.eos = '1'
                                  AND a.num_conc = 120
                                )
                           THEN 'Ret.' + ' '
                                + ISNULL(LTRIM(RTRIM(CONVERT(VARCHAR(20), a.tiempo))),
                                         '')
                           WHEN ( a.eos = '1'
                                  AND a.num_conc = 0
                                ) THEN 'Ent.'
                           WHEN ( a.eos = '1'
                                  AND a.num_conc = 10
                                ) THEN 'Ent.'
                           WHEN ( a.eos = '1'
                                  AND a.num_conc = 11
                                )
                           THEN 'T.E.A.' + ' '
                                + ISNULL(LTRIM(RTRIM(CONVERT(VARCHAR(20), a.tiempo))),
                                         '')
                           WHEN ( a.eos = '2'
                                  AND a.num_conc = 120
                                )
                           THEN 'Sal. Ant.' + ' '
                                + ISNULL(LTRIM(RTRIM(CONVERT(VARCHAR(20), a.tiempo))),
                                         '')
                           WHEN ( a.eos = '2'
                                  AND a.num_conc = 0
                                ) THEN 'Sal.'
                           WHEN ( a.eos = '3'
                                  AND a.num_conc = 120
                                )
                           THEN 'Ret.' + ' '
                                + ISNULL(LTRIM(RTRIM(CONVERT(VARCHAR(20), a.tiempo))),
                                         '')
                           WHEN ( a.eos = '3'
                                  AND a.num_conc = 0
                                ) THEN 'Ent.'
                           WHEN ( a.eos = '4'
                                  AND a.num_conc = 120
                                )
                           THEN 'Sal. Ant' + ' '
                                + ISNULL(LTRIM(RTRIM(CONVERT(VARCHAR(20), a.tiempo))),
                                         '')
                           WHEN ( a.eos = '4'
                                  AND a.num_conc = 0
                                ) THEN 'Sal.'
                           WHEN ( a.eos = '4'
                                  AND a.num_conc = 10
                                )
                           THEN 'L.D.' + ' '
                                + ISNULL(LTRIM(RTRIM(CONVERT(VARCHAR(20), a.tiempo))),
                                         '')
                           WHEN ( a.eos = '4'
                                  AND a.num_conc = 11
                                )
                           THEN 'T.E.' + ' '
                                + ISNULL(LTRIM(RTRIM(CONVERT(VARCHAR(20), a.tiempo))),
                                         '')
                           WHEN ( a.eos = 'E'
                                  AND a.num_conc = 120
                                )
                           THEN 'Ret.' + ' '
                                + ISNULL(LTRIM(RTRIM(CONVERT(VARCHAR(20), a.tiempo))),
                                         '')
                           WHEN ( a.eos = 'E'
                                  AND a.num_conc = 0
                                ) THEN 'Ent.'
                           WHEN ( a.eos = 'E'
                                  AND a.num_conc = 10
                                )
                           THEN 'L.D.' + ' '
                                + ISNULL(LTRIM(RTRIM(CONVERT(VARCHAR(20), a.tiempo))),
                                         '')
                           WHEN ( a.eos = 'E'
                                  AND a.num_conc = 11
                                )
                           THEN 'T.E.A.' + ' '
                                + ISNULL(LTRIM(RTRIM(CONVERT(VARCHAR(20), a.tiempo))),
                                         '')
                           WHEN ( a.eos = 'S'
                                  AND a.num_conc = 120
                                )
                           THEN 'Sal. Ant' + ' '
                                + ISNULL(LTRIM(RTRIM(CONVERT(VARCHAR(20), a.tiempo))),
                                         '')
                           WHEN ( a.eos = 'S'
                                  AND a.num_conc = 0
                                ) THEN 'Sal.'
                           WHEN ( a.eos = 'S'
                                  AND a.num_conc = 10
                                )
                           THEN 'L.D.' + ' '
                                + ISNULL(LTRIM(RTRIM(CONVERT(VARCHAR(20), a.tiempo))),
                                         '')
                           WHEN ( a.eos = 'S'
                                  AND a.num_conc = 11
                                )
                           THEN 'T.E.' + ' '
                                + ISNULL(LTRIM(RTRIM(CONVERT(VARCHAR(20), a.tiempo))),
                                         '')
                           WHEN a.eos = '' THEN 'Checada'
                           WHEN a.num_conc = 108 THEN 'Aus'
                           WHEN a.num_conc = 30 THEN 'VAC'
                           WHEN a.num_conc IN ( 109, 110, 111 ) THEN 'Inc'
                           WHEN a.obs = 'Descanso' THEN 'Desc.'
                           WHEN a.obs = 'Checada fuera de horario'
                           THEN 'F. H.'
                           WHEN a.obs IS NULL
                                AND a.eos = 'E' THEN 'Ent.'
                           WHEN a.obs IS NULL
                                AND a.eos = 'S' THEN 'Sal.'
                      END ) AS Obs ,
                    ( CASE WHEN a.eos = '1' THEN 1
                           WHEN a.eos = '2' THEN 2
                           WHEN a.eos = '3' THEN 3
                           WHEN a.eos = '4' THEN 4
                           WHEN a.eos = 'E' THEN 1
                           WHEN a.eos = 'S' THEN 2
                           WHEN a.num_conc = 108 THEN 1
                           WHEN a.num_conc = 108 THEN 1
                           WHEN a.num_conc IN ( 109, 110, 111 ) THEN 1
                           WHEN a.obs = 'Descanso' THEN 1
                           WHEN a.num_conc = 30 THEN 1
                           WHEN a.eos = '' THEN 1
                           WHEN a.obs = 'Checada fuera de horario' THEN 1
                           WHEN a.Obs IS NULL
                                AND a.eos = 'E' THEN 1
                           WHEN a.Obs IS NULL
                                AND a.eos = 'S' THEN 2
                           ELSE 1
                      END ) AS sec ,
--(case when a.conc=120 then sum(a.tiempo) end)as ret,
                    ISNULL(ABS(a.tiempo / 60), 0) ,
                    a.num_conc ,
                    l.supervisor ,
                    l.centro ,
                    ( h.minutos - h.pausa ) / 60 ,
                    CASE WHEN @grupo = ''
                         THEN REPLICATE('0',
                                        15 - LEN(LTRIM(RTRIM(STR(L.codigo)))))
                              + LTRIM(RTRIM(STR(L.codigo)))
                         WHEN @grupo = 'S'
                         THEN REPLICATE('0',
                                        15 - LEN(LTRIM(RTRIM(STR(L.supervisor)))))
                              + LTRIM(RTRIM(STR(L.supervisor)))
                         WHEN @grupo = 'L'
                         THEN REPLICATE('0',
                                        15 - LEN(LTRIM(RTRIM(STR(L.linea)))))
                              + LTRIM(RTRIM(STR(L.linea)))
                         WHEN @grupo = 'H'
                         THEN REPLICATE('0',
                                        15 - LEN(LTRIM(RTRIM(STR(L.horario)))))
                              + LTRIM(RTRIM(STR(L.horario)))
                         WHEN @grupo = 'D'
                         THEN REPLICATE('0', 15 - LEN(LTRIM(RTRIM(L.centro))))
                              + LTRIM(RTRIM(L.centro))
                    END AS orden
            FROM    --llaves as l
                    dbo.relch_registro AS a --on l.empresa=a.empresa and l.codigo=a.codigo
                    INNER JOIN dbo.llaves AS l ON l.empresa = a.empresa
                                                  AND l.codigo = a.codigo
                    LEFT JOIN dbo.detalle_horarios AS h ON l.empresa = a.empresa
                                                            AND a.horario = h.horario
                                                            AND h.dia_semana = DATEPART(dw,
                                                              a.aplicara)
            WHERE   ( a.comedor = 'F'
                      OR a.comedor IS NULL
                    )
                    AND ( a.aplicara >= @fecha1
                          AND a.aplicara <= @fecha2
                        )
                    AND a.tiponom IN ( @n1, @n2, @n3, @n4, @n5, @n6 )
                    AND a.empresa = @empresa
                    AND 
     --(a.eos in('1','2','3','4') or a.num_conc in(30,108,109,110,111) or a.obs='Descanso') and 
                    ( a.alerta IS NULL
                      OR a.alerta = ''
                    ) --and h.turno<>2 --and a.num_conc=11
ORDER BY            a.codigo ASC ,
                    a.aplicara ASC ,
                    sec ASC
--SELECT * FROM dbo.relch_reporte
    UPDATE  a
    SET     hrstrab = ( CASE WHEN a.num_conc IN ( 30, 108, 109, 110, 111 )
                             THEN 0
                             ELSE a.hrsturno
                        END ) - ISNULL(( SELECT SUM(tiempo) / 60
                                         FROM   relch_registro
                                         WHERE  empresa = a.empresa
                                                AND codigo = a.codigo
                                                AND aplicara = a.fecha
                                                AND num_conc = 120
                                       ), 0)
    FROM    relch_reporte AS a
    WHERE   a.empresa = @empresa
            AND a.sec = ( SELECT    MAX(sec)
                          FROM      relch_reporte
                          WHERE     empresa = a.empresa
                                    AND codigo = a.codigo
                                    AND fecha = a.fecha
                        )
		
--SELECT * FROM relch_reporte


    SET @stringEntrada1 = 'empresa,codigo,nombre,' + @stringEntrada1
        + '1 as serial,orden'
    SET @stringSalida1 = 'empresa,codigo,nombre,' + @stringSalida1
        + '2 as serial,orden'
    SET @stringEntrada2 = 'empresa,codigo,nombre,' + @stringEntrada2
        + '3 as serial,orden'
    SET @stringSalida2 = 'empresa,codigo,nombre,' + @stringSalida2
        + '4 as serial,orden'
    SET @stringObs = 'empresa,codigo,nombre,' + @stringObs
        + '5 as serial,orden'
    SET @string = SUBSTRING(@string, 1, LEN(@string) - 1)
    SET @whereClause = ' where a.empresa=' + STR(@empresa)
        + CASE WHEN LEN(@filtroPor) > 0
               THEN ' AND '
                    + CASE WHEN @filtroPor = 'S'
                           THEN ' l.supervisor = ' + @filtroValor
                           WHEN @filtroPor = 'D'
                           THEN ' l.centro = ' + '''' + @filtroValor + ''''
                           WHEN @filtroPor = 'L'
                           THEN ' l.linea = ' + @filtroValor
                           WHEN @filtroPor = 'H'
                           THEN ' l.horario = ' + @filtroValor
                           ELSE ' '
                      END
               ELSE ''
          END + CASE WHEN LEN(@codigos) > 0
                     THEN ' AND a.codigo BETWEEN ' + @codigos
                     ELSE ' '
                END
       -- + ' and a.TipoNom=' + RTRIM(LTRIM(STR(@payrollType)))
       -- + ' and a.Periodo=' + RTRIM(LTRIM(STR(@periodId)))
       -- + ' and a.Ayo_Operacion=' + RTRIM(LTRIM(STR(@yearId))) + ' '

    EXEC(
    '(SELECT '+@stringEntrada1+'
    FROM
    (SELECT a.empresa,a.codigo,rtrim(b.ap_paterno)+'' ''+ rtrim(b.ap_materno) +'' ''+ rtrim(b.nombre) as nombre,convert(varchar(30),a.fecha,103) as fecha,CASE WHEN len(ltrim(rtrim(checada)))>0 THEN  a.checada ELSE checada END as checada,a.orden 
    FROM dbo.relch_reporte as a
    INNER join dbo.empleados as b on a.empresa=b.empresa and a.codigo=b.codigo 
    INNER join dbo.llaves as l on l.empresa=b.empresa and l.codigo=b.codigo ' + 
    @whereClause +'		
    and a.sec=1
    ) AS relch_reporte 
    PIVOT
    (
    max(checada)
    FOR fecha IN ('+@string+')
    ) AS PivotTable) ' +
    'Union 
    (SELECT '+@stringSalida1+'
    FROM
    (SELECT a.empresa,a.codigo,rtrim(b.ap_paterno)+'' ''+ rtrim(b.ap_materno) +'' ''+ rtrim(b.nombre) as nombre,convert(varchar(30),a.fecha,103) as fecha,CASE WHEN len(ltrim(rtrim(checada)))>0 THEN  a.checada ELSE checada END as checada,a.orden 
    FROM dbo.relch_reporte as a
    INNER join dbo.empleados as b on a.empresa=b.empresa and a.codigo=b.codigo  
    INNER join dbo.llaves as l on l.empresa=b.empresa and l.codigo=b.codigo ' + 
    @whereClause +'		
    and a.sec=2
    ) AS relch_reporte 
    PIVOT
    (
    max(checada)
    FOR fecha IN ('+@string+')
    ) AS PivotTable) ' +
    'Union 
    (SELECT '+@stringEntrada2+'
    FROM
    (SELECT a.empresa,a.codigo,rtrim(b.ap_paterno)+'' ''+ rtrim(b.ap_materno) +'' ''+ rtrim(b.nombre) as nombre,convert(varchar(30),a.fecha,103) as fecha,CASE WHEN len(ltrim(rtrim(checada)))>0 THEN  a.checada ELSE checada END as checada,a.orden 
    FROM dbo.relch_reporte as a
    INNER join dbo.empleados as b on a.empresa=b.empresa and a.codigo=b.codigo 
    INNER join dbo.llaves as l on l.empresa=b.empresa and l.codigo=b.codigo ' + 
    @whereClause +'		
    and a.sec=3
    ) AS relch_reporte 
    PIVOT
    (
    max(checada)
    FOR fecha IN ('+@string+')
    ) AS PivotTable) ' +
    'Union 
    (SELECT '+@stringSalida2+'
    FROM
    (SELECT a.empresa,a.codigo,rtrim(b.ap_paterno)+'' ''+ rtrim(b.ap_materno) +'' ''+ rtrim(b.nombre) as nombre,convert(varchar(30),a.fecha,103) as fecha,CASE WHEN len(ltrim(rtrim(checada)))>0 THEN  a.checada ELSE checada END as checada,a.orden 
    FROM dbo.relch_reporte as a
    INNER join dbo.empleados as b on a.empresa=b.empresa and a.codigo=b.codigo 
    INNER join dbo.llaves as l on l.empresa=b.empresa and l.codigo=b.codigo ' + 
    @whereClause +'		
    and a.sec=4
    ) AS relch_reporte 
    PIVOT
    (
    max(checada)
    FOR fecha IN ('+@string+')
    ) AS PivotTable) ' +
    'Union 
    (SELECT '+@stringObs+'
    FROM
    (SELECT a.empresa,a.codigo,rtrim(b.ap_paterno)+'' ''+ rtrim(b.ap_materno) +'' ''+ rtrim(b.nombre) as nombre,convert(varchar(30),a.fecha,103) as fecha,a.obs,a.orden 
    FROM dbo.relch_reporte as a 
    INNER join dbo.empleados as b on a.empresa=b.empresa and a.codigo=b.codigo 
    INNER join dbo.llaves as l on l.empresa=b.empresa and l.codigo=b.codigo ' + 
    @whereClause +'			
    ) AS Detalle_Rec 
    PIVOT
    (
    max(obs)
    FOR fecha IN ('+@string+') 
    ) AS PivotTable) '
    
    + ' Order by orden,codigo,serial'
    )

    SET DATEFIRST @nSetdatefirst

GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'[dbo].[obtenRelojReporte002]')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojReporte002
GO

CREATE PROCEDURE obtenRelojReporte002
    @empresa udtInteger ,
    @fechaInicio udtDateTime ,
    @fechaTermino udtDateTime ,
    @num_conc udtInteger ,
    @tiponom udtInteger ,
    @filtroPor udtStringSize128 ,
    @filtroValor udtStringSize128 ,
    @grupo udtName ,
    @comedor udtName ,
    @codigos udtName
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    SET DATEFORMAT DMY
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger
	
    SET @selectClause = ''
    SET @fromClause = ''
    SET @whereClause = ''
    SET @whereClauseUsed = 0
    SET @groupByClause = ''
    SET @orderByClause = ''
	
		
    SET @debug = 0
	    
    DECLARE @agrupadoPor udtStringSize4096
    DECLARE @filtradoPor udtStringSize4096
    SET @agrupadoPor = CASE WHEN @grupo = 'D' THEN 'rtrim(case when isnull(r.centro,'''')='''' then  rtrim(l.centro) else rtrim(r.Centro) end) + '' '' + (select cn.nomdepto from centros as cn where cn.empresa=r.empresa and cn.centro= case when isnull(r.centro,'''')='''' then  rtrim(l.centro) else rtrim(r.Centro) end) '
                            WHEN @grupo = 'S'
                            THEN 'replicate(''0'', 15 -len(rtrim(ltrim(str(l.supervisor))))) + rtrim(ltrim(str(l.supervisor))) '
                            WHEN @grupo = 'L'
                            THEN 'replicate(''0'', 15 -len(rtrim(ltrim(str(l.linea))))) + rtrim(ltrim(str(l.linea))) '
                            WHEN @grupo = 'H'
                            THEN 'replicate(''0'', 15 -len(rtrim(ltrim(str(r.horario))))) + rtrim(ltrim(str(r.horario))) '
                            ELSE ''''''
                       END
	SET @orderByClause = case when @agrupadoPor='''''' then ' ORDER BY r.empresa ' else  ' ORDER BY ' + @agrupadoPor end 
    SET @filtradoPor = CASE WHEN @filtroPor = 'D' THEN 'r.centro = '
                            WHEN @filtroPor = 'S' THEN 'l.supervisor = '
                            WHEN @filtroPor = 'L' THEN 'l.linea = '
                            WHEN @filtroPor = 'H' THEN 'r.horario = '
                            ELSE 'r.empresa = '
                       END
	
    IF @empresa > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'r.empresa = '
                + LTRIM(RTRIM(STR(@empresa)))
                 
        END
    IF ( @fechaInicio <> NULL
         OR @fechaInicio <> ''
       )
        AND ( @fechaTermino <> NULL
              OR @fechaTermino <> ''
            ) 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + ' r.fecha BETWEEN '''
                + CONVERT(NVARCHAR(30), @fechaInicio, 112) + ''' AND '''
                + CONVERT(NVARCHAR(30), @fechaTermino, 112) + ''''
                 
        END
    IF @num_conc > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'r.num_conc = '
                + LTRIM(RTRIM(STR(@num_conc)))
                 
        END

    IF @tiponom > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'r.tiponom = '
                + LTRIM(RTRIM(STR(@tiponom)))
                 
        END
	
    IF @filtroPor <> '' 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + @filtradoPor + ''''
                + @filtroValor + ''''
                 
        END
        
    IF NOT @comedor IS NULL 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause
                + CASE WHEN @comedor = 'C' THEN 'r.comedor = ''T'' '
                       ELSE '(r.comedor <>''T'' OR r.comedor IS NULL) '
                  END 
                 
        END
    IF @codigos <> '' 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + ' r.codigo BETWEEN ' + @codigos
                 
        END   
    SET @selectClause = 'SELECT  r.codigo ,'
        + 'rtrim(e.ap_paterno) +'' '' + rtrim(e.ap_materno) + '' '' + rtrim(e.nombre) as Nombre,'
        + 'r.checada ,' + 'r.obs ,' + 'r.tiempo ,' + 'r.fecha, '
        + @agrupadoPor + 'AS Grupo '
    SET @fromClause = 'FROM    dbo.relch_registro AS r '
        + 'INNER JOIN dbo.EMPLEADOS AS e ON e.empresa=r.empresa and e.codigo=r.codigo '
        + 'INNER JOIN dbo.llaves AS l ON l.empresa=r.empresa and l.codigo=r.codigo ' 
    
    SET @groupByClause = @agrupadoPor + ',r.codigo ,'
        + 'rtrim(e.ap_paterno) +'' '' + rtrim(e.ap_materno) + '' '' + rtrim(e.nombre) as Nombre,'
        + 'r.checada ,' + 'r.obs ,' + 'r.tiempo ,' + 'r.fecha'
							
    IF @debug = 0 
        BEGIN
            EXEC
            ( @selectClause + @fromClause + @whereClause
            + @orderByClause
            )
        END
    ELSE 
        BEGIN
            PRINT ( @selectClause + @fromClause + @whereClause
                    + @orderByClause )
        END

GO



IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojParametroPrincipales')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojParametroPrincipales
GO

CREATE PROCEDURE dbo.obtenRelojParametroPrincipales ( @empresa udtInteger )

    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON


    SELECT  a.empresa AS empresa_01 ,
            ISNULL(b.otrorel, 'F') AS otrorel_02 ,
            ISNULL(b.validar, 'F') AS validar_03 ,
            ISNULL(b.comedor, 'F') AS comedor_04 ,
            ISNULL(b.mincomedor, 0) AS mincomedor_05 ,
            ISNULL(b.min_tmp_extra, 0) AS min_tmp_extra_06 ,
            ISNULL(b.media_hora, 'F') AS media_hora_07 ,
            ISNULL(b.comedor11, '00:00:00') AS comedor11_08 ,
            ISNULL(b.comedor12, '00:00:00') AS comedor12_09 ,
            ISNULL(b.comedor21, '00:00:00') AS comedor21_10 ,
            ISNULL(b.comedor22, '00:00:00') AS comedor22_11 ,
            ISNULL(b.comedor31, '00:00:00') AS comedor31_12 ,
            ISNULL(b.comedor32, '00:00:00') AS comedor32_13 ,
            ISNULL(b.tolera, 0.00) AS tolera_14 ,
            ISNULL(b.tmp_ant_ent, 'F') AS tmp_ant_ent_15 ,
            ISNULL(b.ret_comedor, 'F') AS ret_comedor_16 ,
            ISNULL(b.cuota, 0.00) AS cuota_17 ,
            ISNULL(b.media_hora, 'F') AS media_hora_18 ,
            ISNULL(b.hind, 'F') AS hind_19 ,
            ISNULL(b.credenciales, 'F') AS credenciales_20 ,
            ISNULL(b.mostrar, 'F') AS mostrar_21 ,
            rutalogo AS rutalogo_22
    FROM    dbo.empresas AS a
            LEFT JOIN dbo.relch_paramet AS b ON a.empresa = b.empresa
    WHERE   a.empresa = @empresa


GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.[modificaRelojParametros]')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.[modificaRelojParametros]
GO

CREATE PROCEDURE [dbo].[modificaRelojParametros]
    (
      @empresa udtInteger ,
      @otrorel udtName ,
      @hind udtName ,
      @credenciales udtName ,
      @mostrar udtName ,
      @tolera udtInteger ,
      @min_tmp_extra udtInteger ,
      @media_hora udtName ,
      @tmp_ant_ent udtName ,
      @cuota udtNumeric10_2 ,
      @mincomedor udtInteger ,
      @comedor udtName ,
      @comedor11 udtName ,
      @comedor12 udtName ,
      @comedor21 udtName ,
      @comedor22 udtName ,
      @comedor31 udtName ,
      @comedor32 udtName ,
      @ret_comedor udtName ,
      @rutalogo udtName
    )
AS 
    IF ( SELECT COUNT(1)
         FROM   dbo.relch_paramet
         WHERE  empresa = @empresa
       ) <= 0 
        BEGIN			

            INSERT  INTO dbo.relch_paramet
                    ( empresa ,
                      otrorel ,
                      comedor ,
                      mincomedor ,
                      min_tmp_extra ,
                      media_hora ,
                      comedor11 ,
                      comedor12 ,
                      comedor21 ,
                      comedor22 ,
                      comedor31 ,
                      comedor32 ,
                      tolera ,
                      tmp_ant_ent ,
                      ret_comedor ,
                      cuota ,
                      hind ,
                      credenciales ,
                      mostrar ,
                      validar ,
                      rutalogo
                    )
            VALUES  ( @empresa ,
                      @otrorel ,
                      @comedor ,
                      @mincomedor ,
                      @min_tmp_extra ,
                      @media_hora ,
                      @comedor11 ,
                      @comedor12 ,
                      @comedor21 ,
                      @comedor22 ,
                      @comedor31 ,
                      @comedor32 ,
                      @tolera ,
                      @tmp_ant_ent ,
                      @ret_comedor ,
                      @cuota ,
                      @hind ,
                      @credenciales ,
                      @mostrar ,
                      'T' ,
                      @rutalogo 
                    )
        END
    ELSE 
        BEGIN

            UPDATE  dbo.relch_paramet
            SET     otrorel = @otrorel ,
                    comedor = @comedor ,
                    mincomedor = @mincomedor ,
                    min_tmp_extra = @min_tmp_extra ,
                    media_hora = @media_hora ,
                    comedor11 = @comedor11 ,
                    comedor12 = @comedor12 ,
                    comedor21 = @comedor21 ,
                    comedor22 = @comedor22 ,
                    comedor31 = @comedor31 ,
                    comedor32 = @comedor32 ,
                    tolera = @tolera ,
                    tmp_ant_ent = @tmp_ant_ent ,
                    ret_comedor = @ret_comedor ,
                    cuota = @cuota ,
                    hind = @hind ,
                    credenciales = @credenciales ,
                    mostrar = @mostrar ,
                    rutalogo = @rutalogo ,
                    validar = 'T'
            WHERE   empresa = @empresa
        END


GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojEmpleadosFNomina')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojEmpleadosFNomina
GO

CREATE PROCEDURE dbo.obtenRelojEmpleadosFNomina ( @empresa udtInteger )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
    SELECT  codigo ,
            nombre ,
            CONVERT(NVARCHAR(30), fecha, 103) AS Alta ,
            horario ,
            activo
    FROM    dbo.relch_fnomina
    WHERE   empresa = @empresa

GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojHorariosFNomina')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojHorariosFNomina
GO

CREATE PROCEDURE dbo.obtenRelojHorariosFNomina ( @empresa udtInteger )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
    SELECT  RTRIM(LTRIM(STR(horario))) + ' ' + RTRIM(nombre) AS horario
    FROM    dbo.horarios_catalogo
    WHERE   empresa = @empresa

GO

 
IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojUltimoCodigoFNomina')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojUltimoCodigoFNomina
GO

CREATE PROCEDURE dbo.obtenRelojUltimoCodigoFNomina ( @empresa udtInteger )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
    DECLARE @codigoMin udtInteger
    DECLARE @codigoMax udtInteger
    SET @codigoMin = 99990000
    SET @codigoMax = 99999999
    
    SELECT  ISNULL(MAX(codigo), @codigoMin) + 1 AS codigo
    FROM    dbo.relch_fnomina
    WHERE   empresa = @empresa
            AND codigo BETWEEN @codigoMin AND @codigoMax

GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.agregaRelojFNomina')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.agregaRelojFNomina
GO

CREATE PROCEDURE dbo.agregaRelojFNomina
    (
      @empresa udtInteger ,
      @codigo udtInteger ,
      @horario udtInteger ,
      @fecha udtDateTime ,
      @nombre udtName ,
      @activo udtName
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
   
    
    INSERT  INTO dbo.relch_fnomina
            ( empresa ,
              codigo ,
              horario ,
              fecha ,
              nombre ,
              activo 
            )
    VALUES  ( @empresa ,
              @codigo ,
              @horario ,
              @fecha ,
              @nombre ,
              @activo 
            )

GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenDatosEmpleadoFNomina')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenDatosEmpleadoFNomina
GO

CREATE PROCEDURE dbo.obtenDatosEmpleadoFNomina
    (
      @empresa udtInteger ,
      @codigo udtInteger 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
    SELECT  a.codigo ,
            a.activo ,
            a.fecha ,
            a.nombre ,
            RTRIM(LTRIM(STR(h.horario))) + ' ' + RTRIM(h.nombre) AS horario
    FROM    dbo.relch_fnomina AS a
            INNER JOIN dbo.horarios_catalogo AS h ON a.empresa = h.empresa
                                                     AND a.horario = h.horario
    WHERE   a.empresa = @empresa
            AND a.codigo = @codigo

GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.modificaRelojFNomina')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.modificaRelojFNomina
GO

CREATE PROCEDURE dbo.modificaRelojFNomina
    (
      @empresa udtInteger ,
      @codigo udtInteger ,
      @horario udtInteger ,
      @fecha udtDateTime ,
      @nombre udtName ,
      @activo udtName
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
   
    
    UPDATE  dbo.relch_fnomina
    SET     horario = @horario ,
            fecha = @fecha ,
            nombre = @nombre ,
            activo = @activo
    WHERE   empresa = @empresa
            AND codigo = @codigo
				

GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojEmpleadosActivos')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojEmpleadosActivos
GO

CREATE PROCEDURE dbo.obtenRelojEmpleadosActivos
    (
      @empresa AS udtInteger 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    ( SELECT    a.codigo ,
                RTRIM(a.ap_paterno) + ' ' + RTRIM(a.ap_materno) + ' '
                + RTRIM(a.nombre) AS nombre ,
                '' AS Blank ,
                'F' AS Sel
      FROM      dbo.empleados AS a
      WHERE     a.empresa = @empresa
                AND a.activo = 'S'
                AND a.ultmov <> 'B'
    )
    UNION
    ( SELECT    codigo ,
                nombre ,
                '' AS Blank ,
                'F' AS Sel
      FROM      dbo.relch_fnomina
      WHERE     activo = 'S'
                AND empresa = @empresa
    )


GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojDetalleExcepiones')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojDetalleExcepiones
GO

CREATE PROCEDURE dbo.obtenRelojDetalleExcepiones
    (
      @empresa AS udtInteger ,
      @codigo AS udtInteger 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    ( SELECT    ISNULL(b.nochecar, 'F') AS nochecar ,
                ISNULL(b.tarde, 'F') AS tarde ,
                ISNULL(b.mintarde, 0) AS mintarde ,
                ISNULL(b.chora, 'F') AS chora ,
                ISNULL(b.aus, 'F') AS aus ,
                ISNULL(b.notmp_extra, 'F') AS notmp_extra
      FROM      dbo.empleados AS a
                LEFT JOIN dbo.relch_exep AS b ON a.empresa = b.empresa
                                                 AND a.codigo = b.codigo
      WHERE     a.empresa = @empresa
                AND a.codigo = @codigo
    )
    UNION
    ( SELECT    ISNULL(b.nochecar, 'F') AS nochecar ,
                ISNULL(b.tarde, 'F') AS tarde ,
                ISNULL(b.mintarde, 0) AS mintarde ,
                ISNULL(b.chora, 'F') AS chora ,
                ISNULL(b.aus, 'F') AS aus ,
                ISNULL(b.notmp_extra, 'F') AS notmp_extra
      FROM      dbo.relch_fnomina AS a
                LEFT JOIN dbo.relch_exep AS b ON a.empresa = b.empresa
                                                 AND a.codigo = b.codigo
      WHERE     a.empresa = @empresa
                AND a.codigo = @codigo
    )


GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojGuardaCambiosExcep')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojGuardaCambiosExcep
GO

CREATE PROCEDURE dbo.obtenRelojGuardaCambiosExcep
    (
      @empresa udtInteger ,
      @codigo udtInteger ,
      @nochecar udtName ,
      @tarde udtName ,
      @mintarde udtInteger ,
      @chora udtName ,
      @aus udtName ,
      @notmp_extra udtName 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    IF NOT EXISTS ( SELECT  codigo
                    FROM    dbo.relch_exep
                    WHERE   codigo = @codigo
                            AND empresa = @empresa ) 
        BEGIN	
            INSERT  INTO dbo.relch_exep
                    ( empresa ,
                      codigo ,
                      nochecar ,
                      tarde ,
                      mintarde ,
                      chora ,
                      aus ,
                      notmp_extra
		        )
            VALUES  ( @empresa ,
                      @codigo ,
                      @nochecar ,
                      @tarde ,
                      @mintarde ,
                      @chora ,
                      @aus ,
                      @notmp_extra
		        )
		        
        END
    ELSE 
        BEGIN
            UPDATE  dbo.relch_exep
            SET     nochecar = @nochecar ,
                    tarde = @tarde ,
                    mintarde = @mintarde ,
                    chora = @chora ,
                    aus = @aus ,
                    notmp_extra = @notmp_extra
            WHERE   empresa = @empresa
                    AND codigo = @codigo 
                      
        END
		


GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojListadoHorarios')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojListadoHorarios
GO

CREATE PROCEDURE dbo.obtenRelojListadoHorarios
    (
      @empresa AS udtInteger 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    SELECT  horario ,
            nombre ,
            CASE WHEN tipoturno = 1 THEN 'ORDINARIO'
                 WHEN tipoturno = 2 THEN 'SEGUNDO'
                 WHEN tipoturno = 3 THEN 'TERCERO'
                 WHEN tipoturno IS NULL THEN 'ORDINARIO'
            END AS tipo
    FROM    horarios_catalogo AS a
    WHERE   empresa = @empresa
    ORDER BY horario ,
            nombre


GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojTrabajadoresHorario')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojTrabajadoresHorario
GO

CREATE PROCEDURE dbo.obtenRelojTrabajadoresHorario
    (
      @empresa AS udtInteger ,
      @horario AS udtInteger 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    SELECT  e.codigo ,
            RTRIM(e.nombre) + ' ' + RTRIM(e.ap_paterno) + ' '
            + RTRIM(e.ap_materno) AS nombre ,
            '' AS seleccion ,
            ISNULL(e.chor, 'N') AS sel
    FROM    llaves AS l
            INNER JOIN empleados AS e ON e.empresa = l.empresa
                                         AND e.codigo = l.codigo
    WHERE   e.ultmov <> 'B'
            AND e.activo = 'S'
            AND e.empresa = @empresa
            AND CASE WHEN e.horario IS NULL
                          OR e.horario = 0 THEN l.horario
                     ELSE e.horario
                END = @horario
    ORDER BY l.codigo


GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojListadoTerminales')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojListadoTerminales
GO

CREATE PROCEDURE dbo.obtenRelojListadoTerminales
    (
      @empresa AS udtInteger 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    SELECT  terminal ,
            referencia
    FROM    dbo.relch_terminales
    WHERE   empresa = @empresa


GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojNumeroTerminal')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojNumeroTerminal
GO

CREATE PROCEDURE dbo.obtenRelojNumeroTerminal
    (
      @empresa AS udtInteger 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    SELECT  ISNULL(MAX(terminal), 0) + 1
    FROM    dbo.relch_terminales
    WHERE   empresa = @empresa


GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.AgregaRelojTerminal')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.AgregaRelojTerminal
GO

CREATE PROCEDURE dbo.AgregaRelojTerminal
    (
      @empresa AS udtInteger ,
      @terminal AS udtInteger ,
      @nombre AS udtName
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    INSERT  INTO dbo.relch_terminales
            ( empresa, terminal, referencia )
    VALUES  ( @empresa, @terminal, @nombre )


GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojBuscaTerminal')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojBuscaTerminal
GO

CREATE PROCEDURE dbo.obtenRelojBuscaTerminal
    (
      @empresa AS udtInteger ,
      @terminal AS udtInteger
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    SELECT  terminal ,
            referencia
    FROM    dbo.relch_terminales
    WHERE   empresa = @empresa
            AND terminal = @terminal


GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ModificaRelojTerminal')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ModificaRelojTerminal
GO

CREATE PROCEDURE dbo.ModificaRelojTerminal
    (
      @empresa AS udtInteger ,
      @terminal AS udtInteger ,
      @nombre AS udtName
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    UPDATE  dbo.relch_terminales
    SET     referencia = @nombre
    WHERE   empresa = @empresa
            AND terminal = @terminal


GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojCredenciales')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojCredenciales
GO

CREATE PROCEDURE dbo.obtenRelojCredenciales
    (
      @empresa AS udtInteger 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    SELECT  a.codigo ,
            RTRIM(a.nombre) + ' ' + RTRIM(a.ap_paterno) + ' '
            + RTRIM(a.ap_materno) AS nombre ,
            ISNULL(a.credencial, 0) AS Credencial
    FROM    empleados AS a
    WHERE   a.empresa = @empresa


GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojBuscaCredencial')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojBuscaCredencial
GO

CREATE PROCEDURE dbo.obtenRelojBuscaCredencial
    (
      @empresa udtInteger ,
      @credencial udtLong 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    SELECT  1 AS existe
    FROM    empleados AS a
    WHERE   a.empresa = @empresa
            AND a.credencial = @credencial


GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ModificaRelojCredencial')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ModificaRelojCredencial
GO

CREATE PROCEDURE dbo.ModificaRelojCredencial
    (
      @empresa AS udtInteger ,
      @codigo AS udtInteger ,
      @credencial AS udtLong
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    UPDATE  dbo.empleados
    SET     credencial = @credencial
    WHERE   empresa = @empresa
            AND codigo = @codigo


GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenRelojBloqueoTrabajador')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojBloqueoTrabajador
GO

CREATE PROCEDURE dbo.ObtenRelojBloqueoTrabajador ( @empresa udtInteger )

    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    SELECT  codigo ,
            RTRIM(LTRIM(ap_paterno)) + ' ' + RTRIM(LTRIM(ap_materno)) + ' '
            + RTRIM(LTRIM(nombre)) AS nombre ,
            '' AS marca ,
            ISNULL(bloqueado, 0) AS bloqueado
    FROM    dbo.empleados
    WHERE   empresa = @empresa
    ORDER BY codigo


GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ModificaRelojBloqueaTrabajador')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ModificaRelojBloqueaTrabajador
GO

CREATE PROCEDURE dbo.ModificaRelojBloqueaTrabajador
    (
      @empresa AS udtInteger ,
      @codigo AS udtInteger ,
      @bloqueado AS udtLong
      
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    UPDATE  dbo.empleados
    SET     bloqueado = @bloqueado
    WHERE   empresa = @empresa
            AND codigo = @codigo


GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenRelojLineas')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojLineas
GO

CREATE PROCEDURE dbo.ObtenRelojLineas
    (
      @empresa AS udtInteger 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    SELECT  linea ,
            nombre
    FROM    dbo.relch_lineas AS a
    WHERE   empresa = @empresa
    ORDER BY linea ,
            nombre


GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenRelojBuscaNumLinea')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojBuscaNumLinea
GO

CREATE PROCEDURE dbo.ObtenRelojBuscaNumLinea ( @empresa udtInteger )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    SELECT  ISNULL(MAX(linea), 0) + 1 AS siguiente
    FROM    dbo.relch_lineas
    WHERE   empresa = @empresa


GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenRelojInfoLineas')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojInfoLineas
GO

CREATE PROCEDURE dbo.ObtenRelojInfoLineas
    (
      @empresa udtInteger ,
      @linea udtInteger
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    SELECT  linea ,
            nombre
    FROM    dbo.relch_lineas
    WHERE   empresa = @empresa
            AND linea = @linea


GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.AgregaRelojLinea')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.AgregaRelojLinea
GO

CREATE PROCEDURE dbo.AgregaRelojLinea
    (
      @empresa udtInteger ,
      @linea udtInteger ,
      @nombre udtName 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    INSERT  INTO dbo.relch_lineas
            ( empresa, linea, nombre )
    VALUES  ( @empresa, -- empresa - numeric
              @linea, -- linea - numeric
              @nombre  -- nombre - char(25)
              )


GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ModificaRelojLinea')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ModificaRelojLinea
GO

CREATE PROCEDURE dbo.ModificaRelojLinea
    (
      @empresa udtInteger ,
      @linea udtInteger ,
      @nombre udtName 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    UPDATE  dbo.relch_lineas
    SET     nombre = @nombre
    WHERE   empresa = @empresa
            AND linea = @linea

GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenRelojTrabajadoresLineas')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojTrabajadoresLineas
GO

CREATE PROCEDURE dbo.ObtenRelojTrabajadoresLineas
    (
      @empresa udtInteger ,
      @linea udtInteger
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

    SELECT  l.codigo ,
            RTRIM(e.nombre) + ' ' + RTRIM(e.ap_paterno) + ' '
            + RTRIM(e.ap_materno) AS nombre ,
            '' AS vacio ,
            ISNULL(e.clin, 'N') AS clin
    FROM    dbo.llaves AS l
            INNER JOIN dbo.empleados AS e ON e.empresa = l.empresa
                                             AND e.codigo = l.codigo
    WHERE   l.empresa = @empresa
            AND l.linea = @linea
    ORDER BY l.codigo


GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ModificaRelojTrabajadoresLineas')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ModificaRelojTrabajadoresLineas
GO

CREATE PROCEDURE dbo.ModificaRelojTrabajadoresLineas
    (
      @empresa udtInteger ,
      @linea udtInteger ,
      @codigos udtStringSize8000
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
	
    DECLARE @cSQL udtStringSize8000
	
    SET @cSQL = 'UPDATE  dbo.Llaves ' + 'SET     linea = '
        + RTRIM(LTRIM(STR(@linea))) + ' WHERE   empresa = '
        + RTRIM(LTRIM(STR(@empresa))) + ' AND codigo IN('
        + RTRIM(LTRIM(@codigos)) + ')'
				
    EXEC(@cSQL)

GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenRelojParametHInd')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojParametHInd
GO

CREATE PROCEDURE dbo.ObtenRelojParametHInd ( @empresa udtInteger )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
	
    SELECT  ISNULL(hind, 'F') AS hInd
    FROM    dbo.relch_paramet
    WHERE   empresa = @empresa

GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenRelojCatalogoHorarios')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojCatalogoHorarios
GO

CREATE PROCEDURE dbo.ObtenRelojCatalogoHorarios ( @empresa udtInteger )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
	
    SELECT  REPLICATE('0', 5 - LEN(RTRIM(LTRIM(STR(horario)))))
            + RTRIM(LTRIM(STR(horario))) + ' ' + RTRIM(LTRIM(nombre)) AS horario
    FROM    dbo.horarios_catalogo
    WHERE   empresa = @empresa

GO

IF EXISTS ( SELECT  name
            FROM    sysobjects
            WHERE   name = 'ObtenRelojEmpleadosAgregaChecadas'
                    AND type = 'P' ) 
    DROP PROCEDURE ObtenRelojEmpleadosAgregaChecadas
GO

CREATE PROCEDURE ObtenRelojEmpleadosAgregaChecadas
    (
      @empresa udtInteger ,
      @filtro udtName ,
      @hind udtName ,
      @typeFilter udtName
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    SET @debug = 0
    SET @whereClauseUsed = 0
    SET @whereClause = ''
    SET @orderByClause = ''
    SET @fromClause = ''
    SET @groupByClause = ''
    PRINT @filtro


    IF @empresa > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
            SET @whereClause = @whereClause + 'a.empresa = '
                + LTRIM(RTRIM(STR(@Empresa)))
                 
        END
    IF @filtro <> ''
        AND SUBSTRING(@filtro, 1, 5) <> '00000'
        AND @filtro <> '0' 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
            IF @typeFilter = 'H' 
                BEGIN
                    SET @whereClause = @whereClause + 'case when ''' + @hind
                        + '''=''T'' and a.horario is null then b.horario 
																				   when '''
                        + @hind
                        + '''=''F'' then b.horario
																				   when '''
                        + @hind
                        + '''=''T'' and not a.horario is null then a.horario end = '
                        + @filtro
                END
            ELSE 
                IF @typeFilter = 'D' 
                    BEGIN
                        SET @whereClause = @whereClause + ' b.centro = '''
                            + SUBSTRING(@filtro, 1,
                                        CASE WHEN CHARINDEX(' ', @filtro, 1) > 15
                                             THEN 15
                                             ELSE CHARINDEX(' ', @filtro, 1)
                                        END) + ''''
				
                    END
				
                 
        END
        
    IF @whereClauseUsed = 0 
        BEGIN
	       
            SET @whereClause = @whereClause + 'WHERE '
            SET @whereClauseUsed = 1

        END
    ELSE 
        SET @whereClause = @whereClause + ' AND '
    SET @whereClause = @whereClause
        + '(a.ultmov<>''B'' and a.fch_baja is null) AND a.activo=''S'' '
            
            
    SET @selectClause = 'Select a.codigo,rtrim(a.nombre) + '' ''+ rtrim(a.ap_paterno) + '' ''+ rtrim(a.ap_materno) as nombre,'''' as Sel1,''NO'' as Sel2 '
    						
    SET @fromClause = 'FROM    dbo.empleados as a '
        + ' INNER JOIN dbo.llaves as b on a.empresa=b.empresa and a.codigo=b.codigo '
        
    IF @debug = 0 
        BEGIN 
            EXEC(
            @selectClause + @fromClause + @whereClause + @groupByClause + @orderByClause
            )
        END
    ELSE 
        BEGIN
            PRINT ( @selectClause + @fromClause + @whereClause
                    + @groupByClause + @orderByClause )
        END


GO

IF EXISTS ( SELECT  name
            FROM    sysobjects
            WHERE   name = 'ObtenRelojDepTipHor'
                    AND type = 'P' ) 
    DROP PROCEDURE ObtenRelojDepTipHor
GO

CREATE PROCEDURE ObtenRelojDepTipHor
    (
      @empresa udtInteger ,
      @codigo udtInteger ,
      @hind udtName
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    SET @debug = 0
    SET @whereClauseUsed = 0
    SET @whereClause = ''
    SET @orderByClause = ''
    SET @fromClause = ''
    SET @groupByClause = ''


    IF @empresa > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
            SET @whereClause = @whereClause + 'a.empresa = '
                + LTRIM(RTRIM(STR(@Empresa)))
                 
        END
    IF @codigo > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
            SET @whereClause = @whereClause + 'a.codigo = '
                + LTRIM(RTRIM(STR(@codigo)))
                 
        END           
            
    SET @selectClause = 'SELECT  b.tiponom , b.centro , CASE WHEN ''' + @hind
        + ''' = ''T'' AND a.horario IS NULL THEN b.horario WHEN ''' + @hind
        + ''' = ''F'' THEN b.horario WHEN ''' + @hind
        + ''' = ''T'' AND NOT a.horario IS NULL THEN a.horario END as Horario '
    						
    SET @fromClause = 'FROM    dbo.empleados as a '
        + ' INNER JOIN dbo.llaves as b on a.empresa=b.empresa and a.codigo=b.codigo '
        
    IF @debug = 0 
        BEGIN 
            EXEC(
            @selectClause + @fromClause + @whereClause + @groupByClause + @orderByClause
            )
        END
    ELSE 
        BEGIN
            PRINT ( @selectClause + @fromClause + @whereClause
                    + @groupByClause + @orderByClause )
        END


GO


IF EXISTS ( SELECT  name
            FROM    sysobjects
            WHERE   name = 'ObtenRelojPeriodoChecada'
                    AND type = 'P' ) 
    DROP PROCEDURE ObtenRelojPeriodoChecada
GO

CREATE PROCEDURE ObtenRelojPeriodoChecada
    (
      @empresa udtInteger ,
      @codigo udtInteger ,
      @tiponom udtInteger ,
      @fecha udtDateTime
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    SET @debug = 0
    SET @whereClauseUsed = 0
    SET @whereClause = ''
    SET @orderByClause = ''
    SET @fromClause = ''
    SET @groupByClause = ''


    IF @empresa > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
            SET @whereClause = @whereClause + 'a.empresa = '
                + LTRIM(RTRIM(STR(@Empresa)))
                 
        END
    IF @codigo > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
            SET @whereClause = @whereClause + 'a.codigo = '
                + LTRIM(RTRIM(STR(@codigo)))
                 
        END           
            
    IF @tiponom > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
            SET @whereClause = @whereClause + 'p.tiponom = '
                + LTRIM(RTRIM(STR(@tiponom)))
                 
        END           
    IF @whereClauseUsed = 0 
        BEGIN
	       
            SET @whereClause = @whereClause + 'WHERE '
            SET @whereClauseUsed = 1

        END
    ELSE 
        SET @whereClause = @whereClause + ' AND '
    SET @whereClause = @whereClause + '( ''' + CONVERT(NVARCHAR(20), @fecha, 112)
        + ''' >= p.inicio AND ''' + CONVERT(NVARCHAR(20), @fecha, 112)
        + ''' <= p.cierre )'
        
    SET @selectClause = 'SELECT  p.periodo , p.ayo_operacion '
    						
    SET @fromClause = 'FROM    llaves AS a '
        + 'INNER JOIN periodos AS p ON a.empresa = p.empresa '
        
    IF @debug = 0 
        BEGIN 
            EXEC(
            @selectClause + @fromClause + @whereClause + @groupByClause + @orderByClause
            )
        END
    ELSE 
        BEGIN
            PRINT ( @selectClause + @fromClause + @whereClause
                    + @groupByClause + @orderByClause )
        END


GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.AgregaRelojChecada')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.AgregaRelojChecada
GO

CREATE PROCEDURE dbo.AgregaRelojChecada
    (
      @empresa udtInteger ,
      @codigo udtInteger ,
      @fecha udtDateTime ,
      @checada udtName ,
      @obs udtName ,
      @num_conc udtInteger ,
      @tiempo udtNumeric10_2 ,
      @tiponom udtInteger ,
      @centro udtName ,
      @horario udtInteger ,
      @serial udtLong ,
      @periodo udtInteger ,
      @ayo udtInteger ,
      @crf udtName ,
      @crf2 udtName
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
   
    
    INSERT  INTO relch_registro
            ( empresa ,
              codigo ,
              fecha ,
              checada ,
              obs ,
              num_conc ,
              tiempo ,
              tiponom ,
              centro ,
              horario ,
              serial ,
              periodo ,
              ayo ,
              crf ,
              crf2 ,
              aplicara
            )
            SELECT  @empresa ,
                    @codigo ,
                    @fecha ,
                    @checada ,
                    @obs ,
                    @num_conc ,
                    @tiempo ,
                    @tiponom ,
                    @centro ,
                    CASE WHEN c.hind = 'T' THEN ISNULL(a.horario, b.horario)
                         ELSE b.horario
                    END ,
                    @serial ,
                    @periodo ,
                    @ayo ,
                    @crf ,
                    @crf2 ,
                    @fecha
            FROM    dbo.empleados AS a
                    INNER JOIN dbo.Llaves AS b ON a.empresa = b.empresa
                                                  AND a.codigo = b.codigo
                    INNER JOIN dbo.relch_paramet AS c ON b.empresa = c.empresa
            WHERE   a.empresa = @empresa
                    AND a.codigo = @codigo 

GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.EliminaRelojChecadaFalta')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.EliminaRelojChecadaFalta
GO

CREATE PROCEDURE dbo.EliminaRelojChecadaFalta
    (
      @empresa udtInteger ,
      @codigo udtInteger ,
      @fecha udtDateTime 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
   
    
    DELETE  relch_registro
    WHERE   fecha = @fecha
            AND ( num_conc = 108
                  OR obs = 'Descanso'
                )
            AND empresa = @empresa
            AND codigo = @codigo

GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ModificaRelojEos')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ModificaRelojEos
GO

CREATE PROCEDURE dbo.ModificaRelojEos
    (
      @empresa INT ,
      @Fecha1 DATETIME ,
      @Fecha2 DATETIME
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
    
    UPDATE  a
    SET     Eos = CAST(( SELECT COUNT(1)
                         FROM   relch_registro
                         WHERE  empresa = a.empresa
                                AND codigo = a.codigo
                                AND fecha = a.fecha
                                AND id <= a.id
                                AND num_conc <> 9
                       ) AS CHAR(2))
    FROM    relch_registro AS a
    WHERE   ( a.eos IS NULL
              OR a.eos = ''
            )
            AND a.num_conc <> 9
            AND a.empresa = @empresa
            AND ( a.fecha >= @Fecha1
                  AND a.fecha <= @fecha2
                )

GO
	
IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenRelojRegistros')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojRegistros
GO

CREATE PROCEDURE dbo.ObtenRelojRegistros
    (
      @empresa INT ,
      @fecha1 DATETIME ,
      @fecha2 DATETIME ,
      @dia NUMERIC ,
      @tiponom INT                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
    SET DATEFORMAT DMY
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    
    DECLARE @n1 INT ,
        @n2 INT ,
        @n3 INT ,
        @n4 INT ,
        @n5 INT ,
        @n6 INT 
    
 
    IF @tiponom = 0 
        BEGIN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               
            SET @n1 = 1                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        
            SET @n2 = 2                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        
            SET @n3 = 3                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        
            SET @n4 = 4                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        
            SET @n5 = 5                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        
            SET @n6 = 6                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        
        END                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    
    IF @tiponom > 0 
        BEGIN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               
            SET @n1 = @tiponom                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 
            SET @n2 = 0                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        
            SET @n3 = 0                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        
            SET @n4 = 0                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        
            SET @n5 = 0                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        
            SET @n6 = 0                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        
        END                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    
    DECLARE @empresas AS TABLE ( empresa INT )
    IF @empresa = 0 
        BEGIN
            INSERT  INTO @empresas
                    ( empresa )
                    SELECT  empresa
                    FROM    dbo.empresas
        END
    ELSE 
        BEGIN
            INSERT  INTO @empresas
                    ( empresa 
                    )
                    SELECT @empresa
        END


	--select a.empresa,
	--	a.codigo,
	--	(select p.periodo from Periodos as p where p.empresa=a.empresa and p.tiponom = b.tiponom and a.fecha>=p.inicio and a.fecha<=p.cierre),
	--	a.periodo,
	--	a.num_conc
	update a set periodo = (select p.periodo from Periodos as p where p.empresa=a.empresa and p.tiponom = b.tiponom and a.fecha>=p.inicio and a.fecha<=p.cierre),
			tiponom = b.tiponom
	from relch_registro as a
	inner join llaves as b on a.empresa=b.empresa and a.codigo=b.codigo
	where a.empresa in (select empresa from @empresas)   and a.periodo is null
			and a.fecha between @fecha1 and @fecha2
	--group by a.empresa,a.codigo,a.fecha
	
    ( SELECT    '' AS clave ,
                REPLICATE('0', 8 - LEN(RTRIM(LTRIM(STR(A.CODIGO)))))
                + RTRIM(LTRIM(STR(A.CODIGO))) AS codigo ,
                RTRIM(a.nombre) + ' ' + RTRIM(a.ap_paterno) + ' '
                + RTRIM(a.ap_materno) AS nombre ,
                ISNULL(r.obs, '') AS obs ,
                ISNULL(r.checada, 'No hay') AS chec ,
                LTRIM(RTRIM(c.centro)) + ' ' + c.nomdepto AS centro ,
                CONVERT(VARCHAR(15), ISNULL(r.importe, 0)) AS importe ,
                RTRIM(LTRIM(STR(r.num_conc))) AS num_conc ,
                CONVERT(VARCHAR(10), r.fecha, 103) AS fecha ,
                CONVERT(VARCHAR(15), CASE WHEN r.horario IS NULL THEN 0
                                          ELSE r.horario
                                     END) AS horario ,
                ISNULL(r.serial, 0) AS serial ,
                r.id ,
                CASE WHEN d.foto IS NULL
                          OR d.foto = '' THEN 'c:\0.jpg'
                     ELSE d.foto
                END AS foto ,
                RTRIM(LTRIM(STR(t.ocupacion))) + ' ' + RTRIM(t.actividad) AS ocupa ,
                RTRIM(LTRIM(STR(n.tiponom))) + ' ' + RTRIM(n.nomina) AS nomina
      FROM      dbo.empleados AS a
                INNER JOIN dbo.llaves AS l ON a.empresa = l.empresa
                                              AND a.codigo = l.codigo
                INNER JOIN dbo.relch_registro AS r ON l.empresa = r.empresa
                                                      AND l.codigo = r.codigo
                                                      AND r.fecha BETWEEN @fecha1 AND @fecha2 
                                                      AND r.tiponom IN ( @n1, @n2, @n3, @n4, @n5, @n6 )
                INNER JOIN dbo.datosemps AS d ON r.empresa = d.empresa
                                                 AND r.codigo = d.codigo
                INNER JOIN dbo.centros AS c ON r.empresa = c.empresa
                                               AND ISNULL(r.centro, l.centro) = c.centro
                INNER JOIN dbo.detalle_horarios AS h ON h.empresa = r.empresa
                                                        AND h.horario = r.horario
                                                        AND h.dia_semana = @dia
                INNER JOIN dbo.tabulador AS t ON r.empresa = t.empresa
                                                 AND l.ocupacion = t.ocupacion
                INNER JOIN dbo.Nominas AS n ON r.empresa = n.empresa
                                               AND l.tiponom = n.tiponom
      WHERE     r.empresa IN ( SELECT   empresa
                               FROM     @empresas )
                AND a.activo = 'S'
                AND ( r.eliminado <> 'T'
                      OR r.eliminado IS NULL
                    )
                AND ( a.fchalta <= @fecha1
                      OR a.fchalta <= @fecha2
                    )
    )
    UNION
    ( SELECT    '' AS clave ,
                REPLICATE('0', 8 - LEN(RTRIM(LTRIM(STR(A.CODIGO)))))
                + RTRIM(LTRIM(STR(A.CODIGO))) AS codigo ,
                RTRIM(a.nombre) AS nombre ,
                ISNULL(r.obs, '') AS obs ,
                ISNULL(r.checada, 'No hay') AS chec ,
                '' AS centro ,
                CONVERT(VARCHAR(15), ISNULL(r.importe, 0)) AS importe ,
                RTRIM(LTRIM(STR(r.num_conc))) AS num_conc ,
                CONVERT(VARCHAR(10), r.fecha, 103) AS fecha ,
                a.horario ,
                ISNULL(r.serial, 0) AS serial ,
                r.id ,
                CASE WHEN a.foto IS NULL
                          OR a.foto = '' THEN 'c:\0.jpg'
                     ELSE a.foto
                END AS foto ,
                '  ' AS ocupa ,
                '  ' AS nomina
      FROM      dbo.relch_fnomina AS a
                INNER JOIN dbo.relch_registro AS r ON a.empresa = r.empresa
                                                      AND a.codigo = r.codigo
                                                      AND r.fecha BETWEEN @fecha1 AND @fecha2
                                                      AND r.tiponom IN ( @n1, @n2, @n3, @n4, @n5, @n6 )
      WHERE     a.empresa IN ( SELECT   empresa
                               FROM     @empresas )
                AND a.activo = 'A'
    )
    ORDER BY REPLICATE('0', 8 - LEN(RTRIM(LTRIM(STR(A.CODIGO)))))
            + RTRIM(LTRIM(STR(A.CODIGO))) ,
            CONVERT(VARCHAR(10), r.fecha, 103)                                                                                                                                                                                                                                                                                                                                                                                          

GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenSiguienteHorario')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenSiguienteHorario

GO

CREATE PROCEDURE dbo.ObtenSiguienteHorario ( @empresa udtInteger )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON
	
    DECLARE @suguiente_horario udtInteger
	
	
    SELECT  @suguiente_horario = MAX(ISNULL(horario, 0)) + 1
    FROM    horarios_catalogo
    WHERE   empresa = @empresa
    
    SELECT  ISNULL(@suguiente_horario, 1) AS suguiente_horario

GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenDetalleHorario')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenDetalleHorario

GO

CREATE PROCEDURE dbo.ObtenDetalleHorario
    (
      @empresa udtInteger ,
      @horario udtInteger 
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON

    SELECT  a.horario ,
            a.nombre ,
            b.dia_semana ,
            RTRIM(b.entra1) AS e1 ,
            RTRIM(b.sale1) AS s1 ,
            RTRIM(b.entra2) AS e2 ,
            RTRIM(b.sale2) AS s2 ,
            b.descanso ,
            b.minutos ,
            b.pausa ,
            CASE WHEN b.factor >= 100 THEN b.factor - 100
                 ELSE b.factor
            END AS factor ,
            b.factor_aus ,
            a.fac_aus_personal ,
            a.hrsturno ,
            ISNULL(b.sdoxhor, 0) AS sdoxhor ,
            a.semana_red AS jornada
    FROM    horarios_catalogo AS a
            LEFT JOIN detalle_horarios AS b ON a.empresa = b.empresa
                                               AND a.horario = b.horario
    WHERE   a.empresa = @empresa
            AND a.horario = @horario
    ORDER BY a.empresa ,
            a.horario ,
            b.dia_semana
        
        
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ModificaHorario')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ModificaHorario

GO

CREATE PROCEDURE dbo.ModificaHorario
    (
      @empresa udtInteger ,
      @horario udtInteger ,
      @nombre udtName ,
      @jornada udtInteger ,
      @turno udtInteger ,
      @descanso udtInteger ,
      @diasSem udtName ,
      @semanaRed udtName ,
      @hrsTurno udtNumeric10_2 ,
      @fac_aus_personal udtName
       
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    
    UPDATE  horarios_catalogo
    SET     nombre = @nombre ,
            jornada = @jornada ,
            turno = @turno ,
            descanso = @descanso ,
            dias_sem = @diasSem ,
            semana_red = @semanaRed ,
            hrsturno = @hrsTurno ,
            fac_aus_personal = @fac_aus_personal
    WHERE   empresa = @empresa
            AND horario = @horario
   
GO
   
IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.AgregaHorario')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.AgregaHorario

GO

CREATE PROCEDURE dbo.AgregaHorario
    (
      @empresa udtInteger ,
      @horario udtInteger ,
      @nombre udtName ,
      @jornada udtInteger ,
      @turno udtInteger ,
      @descanso udtInteger ,
      @diasSem udtName ,
      @semanaRed udtName ,
      @hrsTurno udtNumeric10_2 ,
      @fac_aus_personal udtName
       
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    
    INSERT  INTO dbo.horarios_catalogo
            ( empresa ,
              horario ,
              nombre ,
              jornada ,
              tolerancia ,
              tol_tpoextra ,
              rolar ,
              turno ,
              descanso ,
              dias_sem ,
              semana_red ,
              hrsturno ,
              fac_aus_personal ,
              hrsreales ,
              tipoturno
            )
    VALUES  ( @empresa ,
              @horario ,
              @nombre ,
              @jornada ,
              0 , -- tolerancia - int
              0 , -- tol_tpoextra - int
              '' , -- rolar - char(1)
              @turno ,
              @descanso ,
              @diasSem ,
              @semanaRed ,
              @hrsTurno ,
              @fac_aus_personal ,
              @hrsTurno ,
              1
            )

GO
   
   
IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ModificaDetalleHorarios')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ModificaDetalleHorarios

GO

CREATE PROCEDURE dbo.ModificaDetalleHorarios
    (
      @empresa udtInteger ,
      @horario udtInteger ,
      @dia_semana udtInteger ,
      @nombre_dia udtName ,
      @entra1 udtName ,
      @entra2 udtName ,
      @sale1 udtName ,
      @sale2 udtName ,
      @minutos udtNumeric10_2 ,
      @pausa udtInteger ,
      @descanso udtName ,
      @factor udtNumeric10_2 ,
      @factor_aus udtNumeric10_2 ,
      @sdoxhor udtNumeric10_2 ,
      @turno_noc udtName
          
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON

    UPDATE  detalle_horarios
    SET     entra1 = @entra1 ,
            entra2 = @entra2 ,
            sale1 = @sale1 ,
            sale2 = @sale2 ,
            minutos = @minutos ,
            pausa = @pausa ,
            descanso = @descanso ,
            nombre_dia = @nombre_dia ,
            factor = @factor ,
            factor_aus = @factor_aus ,
            sdoxhor = @sdoxhor ,
            turno_noc = @turno_noc
    WHERE   empresa = @empresa
            AND horario = @horario
            AND dia_Semana = @dia_semana

GO
   
IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.AgregaDetalleHorarios')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.AgregaDetalleHorarios

GO

CREATE PROCEDURE dbo.AgregaDetalleHorarios
    (
      @empresa udtInteger ,
      @horario udtInteger ,
      @dia_semana udtInteger ,
      @nombre_dia udtName ,
      @entra1 udtName ,
      @entra2 udtName ,
      @sale1 udtName ,
      @sale2 udtName ,
      @minutos udtInteger ,
      @pausa udtInteger ,
      @descanso udtName ,
      @factor udtNumeric10_2 ,
      @factor_aus udtNumeric10_2 ,
      @sdoxhor udtNumeric10_2 ,
      @turno_noc udtName
          
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON
	
    INSERT  INTO dbo.detalle_horarios
            ( empresa ,
              horario ,
              dia_Semana ,
              nombre_dia ,
              entra1 ,
              entra2 ,
              sale1 ,
              sale2 ,
              minutos ,
              pausa ,
              descanso ,
              factor ,
              factor_aus ,
              turno_noc ,
              sdoxhor 
	        
            )
    VALUES  ( @empresa ,
              @horario ,
              @dia_semana ,
              @nombre_dia ,
              @entra1 ,
              @entra2 ,
              @sale1 ,
              @sale2 ,
              @minutos ,
              @pausa ,
              @descanso ,
              @factor ,
              @factor_aus ,
              @turno_noc ,
              @sdoxhor
	        
            )

GO
   
IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenRelojTipoTurnoHorario')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojTipoTurnoHorario

GO

CREATE PROCEDURE dbo.ObtenRelojTipoTurnoHorario
    (
      @empresa udtInteger ,
      @horario udtInteger 
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON

    SELECT  ISNULL(TIPOTURNO, 1)
    FROM    HORARIOS_CATALOGO
    WHERE   empresa = @empresa
            AND horario = @horario
        
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ModificaRelojTipoTurnoHorario')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ModificaRelojTipoTurnoHorario

GO

CREATE PROCEDURE dbo.ModificaRelojTipoTurnoHorario
    (
      @empresa udtInteger ,
      @horario udtInteger ,
      @tipoTurno udtInteger
          
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON

    UPDATE  dbo.horarios_catalogo
    SET     TIPOTURNO = @tipoTurno
    WHERE   empresa = @empresa
            AND horario = @horario

GO
   
IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.EliminaRelojChecada')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.EliminaRelojChecada
GO

CREATE PROCEDURE dbo.EliminaRelojChecada
    (
      @empresa udtInteger ,
      @codigo udtInteger ,
      @fecha udtDateTime ,
      @num_conc udtInteger ,
      @serial udtLong ,
      @id udtLong
      
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
   
    BEGIN TRANSACTION
    BEGIN TRY
        DELETE  dbo.relch_registro
        WHERE   empresa = @empresa
                AND codigo = @codigo
                AND fecha = @fecha
                AND serial = @serial
                AND id = @id
        SELECT  'GO'
    END TRY
    BEGIN CATCH

        
        IF ( XACT_STATE() ) = -1
            OR @@TRANCOUNT > 0 
            ROLLBACK TRANSACTION

        SELECT  'ERROR'

    END CATCH
    IF @@TRANCOUNT > 0 
        COMMIT TRANSACTION

GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenRelojIniciaSeriales')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojIniciaSeriales
GO

CREATE PROCEDURE dbo.ObtenRelojIniciaSeriales ( @empresa udtInteger )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
    
    
    DBCC CHECKIDENT (relch_registro, RESEED,0)
    DBCC CHECKIDENT (relch_historico_checadas, RESEED,0)  
    
    
GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'AgregaRelojReanalizar')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.AgregaRelojReanalizar

GO


CREATE PROCEDURE dbo.AgregaRelojReanalizar
    (
      @empresa udtInteger ,
      @inicio udtDateTime ,
      @termina udtDateTime
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON


    IF OBJECT_ID('dbo.tmp_relch_registro') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_relch_registro
        END

    SELECT  r.empresa ,
            r.codigo ,
            CASE WHEN a.horario IS NULL THEN a.horario
                 ELSE a.horario
            END AS horario ,
            a.centro ,
            a.tiponom ,
            r.fecha ,
            a.linea ,
            r.terminal ,
            r.checada
    INTO    dbo.tmp_relch_registro
    FROM    dbo.relch_registro AS r
            INNER JOIN dbo.llaves AS a ON a.empresa = r.empresa
                                          AND a.codigo = r.codigo
            INNER JOIN dbo.empleados AS b ON b.empresa = a.empresa
                                             AND b.codigo = a.codigo
    WHERE   r.empresa = @empresa
            AND ( r.fecha BETWEEN @inicio AND @termina )
            AND NOT r.num_conc IN ( 108, 109, 110, 111, 30, 9 )
            AND r.obs <> 'DESCANSO'
    ORDER BY id

    DELETE  dbo.relch_registro
    WHERE   empresa = @empresa
            AND ( fecha BETWEEN @inicio AND @termina )
            AND NOT num_conc IN ( 108, 109, 110, 111, 30 )
            AND obs <> 'DESCANSO' 

    SELECT  COUNT(1)
    FROM    dbo.tmp_relch_registro

GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'ObtenRelojReanalizar')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojReanalizar

GO


CREATE PROCEDURE dbo.ObtenRelojReanalizar ( @empresa udtInteger )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    
    SELECT  *
    FROM    dbo.tmp_relch_registro
    WHERE   empresa = @empresa
    
    
GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'EliminaRelojTabla')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.EliminaRelojTabla

GO

    
CREATE PROCEDURE EliminaRelojTabla
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON


    IF OBJECT_ID('dbo.tmp_relch_registro') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_relch_registro
        END
        
        
        
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.EliminaRelojDepuraChecadas')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.EliminaRelojDepuraChecadas
GO

CREATE PROCEDURE dbo.EliminaRelojDepuraChecadas
    (
      @empresa udtInteger ,
      @fecha1 udtDateTime ,
      @fecha2 udtDateTime
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
   
    DECLARE @totalDias udtInteger
    DECLARE @finalDias udtInteger
    DECLARE @fechaInicio udtDateTime
    DECLARE @fechaTermino udtDateTime
    DECLARE @diasSumar udtInteger


    SET @totalDias = DATEDIFF(day, @fecha1, @fecha2) + 1
    SET @finalDias = 1
    SET @fechaInicio = @fecha1
    PRINT @totalDias
    PRINT 'Dias totales'
    BEGIN TRANSACTION
    BEGIN TRY

        WHILE @finalDias <= @totalDias 
            BEGIN
	--SET @fechaInicio	
            
                SET @diasSumar = 0
                SET @diasSumar = CASE WHEN @totalDias = @finalDias THEN 1
                                      WHEN ( @finalDias + 14 ) > @totalDias
                                      THEN @totalDias - @finalDias
                                      WHEN ( @finalDias + 14 ) <= @totalDias
                                      THEN 14
                                 END
                             
			--PRINT @diasSumar                             
                SET @finalDias = @finalDias + @diasSumar
                SET @fechaInicio = CASE WHEN @fechaTermino IS NULL
                                        THEN @fecha1
                                        ELSE @fechaInicio + @diasSumar
                                   END
                SET @fechaTermino = CASE WHEN @fechaTermino IS NULL
                                         THEN @fecha1 + @diasSumar
                                         ELSE @fechaTermino + @diasSumar
                                    END
									        
                SET @fechaTermino = CASE WHEN @fechaTermino > @fecha2
                                         THEN @fecha2
                                         ELSE @fechaTermino
                                    END
            
            
            
                DELETE  dbo.relch_registro
                WHERE   empresa = @empresa
                        AND fecha >= @fechaInicio
                        AND fecha <= @fechaTermino
            
                PRINT @finalDias
                PRINT @fechaInicio
                PRINT @fechaTermino
			
            END
        SELECT  'SUCCESSFULLY' AS returnTransaction
    END TRY
    BEGIN CATCH

        
        IF ( XACT_STATE() ) = -1
            OR @@TRANCOUNT > 0 
            ROLLBACK TRANSACTION

        SELECT  'ERROR' AS returnTransaction

    END CATCH
    IF @@TRANCOUNT > 0 
        COMMIT TRANSACTION


GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'ObtenRelojTiposNomina')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojTiposNomina

GO


CREATE PROCEDURE dbo.ObtenRelojTiposNomina ( @empresa udtInteger )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON


    DECLARE @rowsCount AS INT

    SET @rowsCount = ( SELECT   COUNT(1)
                       FROM     empresas AS a
                                INNER JOIN nominas AS b ON b.empresa = a.empresa
                       WHERE    b.uso = 'S'
                                AND b.tiponom > 0
                                AND a.empresa = @empresa
                     )
    IF @rowsCount > 0 
        BEGIN
            SELECT  @rowsCount AS rowsCount ,
                    b.tiponom ,
                    '0' + CONVERT(VARCHAR(10), b.tiponom) + ' ' + b.nomina AS nombre
            FROM    empresas AS a
                    INNER JOIN nominas AS b ON b.empresa = a.empresa
            WHERE   b.uso = 'S'
                    AND b.tiponom > 0
                    AND a.empresa = @empresa
        END
    ELSE 
        BEGIN
            SELECT  0 AS rowsCount 
        END


GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'ObtenRelojVacaciones')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojVacaciones

GO


CREATE PROCEDURE dbo.ObtenRelojVacaciones
    (
      @empresa udtInteger ,
      @tiponom udtInteger ,
      @row1 udtName ,
      @row2 udtName
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON

    DECLARE @H CHAR(1) ,
        @nSetdatefirst INT ,
        @inicio DATETIME ,
        @fin DATETIME ,
        @periodo INT ,
        @ayo_operacion INT ,
        @fecha DATETIME

    BEGIN TRANSACTION
    BEGIN TRY

        SELECT  @H = hind
        FROM    dbo.relch_paramet
        WHERE   empresa = @empresa

        SELECT  @inicio = inicio ,
                @fin = cierre ,
                @periodo = periodo ,
                @ayo_operacion = ayo_operacion
        FROM    dbo.periodos
        WHERE   estatus = 'A'
                AND tiponom = @tiponom
                AND empresa = @empresa
                                                                                                                                                                                                                                                                                                                                       

        SELECT  @nSetdatefirst = @@DATEFIRST
        SET DATEFIRST 1

        SET @Fecha = @inicio


        WHILE @fecha <= @fin 
            BEGIN
                PRINT @fecha
			
                DELETE  relch_registro
                FROM    dbo.kardex AS a
                        LEFT JOIN dbo.relch_registro AS r ON a.empresa = r.empresa
                                                             AND a.codigo = r.codigo
                                                             AND r.fecha = @fecha
                                                             AND ( r.checada IS NULL
                                                              OR r.num_conc = 108
                                                              )
                WHERE   ( @fecha >= a.fch_inicio
                          AND @fecha <= a.fch_cierre
                        )
                        AND r.tiponom = @Tiponom
                        AND r.num_conc = 108
                        AND a.num_conc = 30
                        AND a.empresa = @empresa
                        AND a.nomina = 'VAC'
			
			
                INSERT  INTO dbo.relch_registro
                        ( empresa ,
                          codigo ,
                          obs ,
                          checada ,
                          num_conc ,
                          importe ,
                          serial ,
                          fecha ,
                          marcafalta ,
                          dias ,
                          periodo ,
                          ayo ,
                          centro ,
                          horario ,
                          tiponom ,
                          aplicara ,
                          crf ,
                          crf2
                        )
                        SELECT  a.empresa ,
                                a.codigo ,
                                'VACACIONES' AS obs ,
                                '00:00:00' AS checada ,
                                30 ,
                                0 AS importe ,
                                1 AS serial ,
                                @fecha AS fecha ,
                                '' AS mf ,
                                1 ,
                                @periodo ,
                                @ayo_operacion ,
                                l.centro ,
                                CASE WHEN CASE WHEN @H = 'T' THEN e.horario
                                               ELSE l.horario
                                          END IS NULL THEN l.horario
                                     ELSE CASE WHEN @H = 'T' THEN e.horario
                                               ELSE l.horario
                                          END
                                END ,
                                l.tiponom ,
                                @fecha ,
                                @row1 ,
                                @row2
                        FROM    dbo.kardex AS a
                                LEFT JOIN dbo.relch_registro AS r ON a.empresa = r.empresa
                                                              AND a.codigo = r.codigo
                                                              AND r.fecha = @fecha
                                                              AND r.num_conc = 30
                                INNER JOIN dbo.empleados AS e ON e.empresa = a.empresa
                                                              AND e.codigo = a.codigo
                                INNER JOIN dbo.llaves AS l ON l.empresa = e.empresa
                                                              AND l.codigo = e.codigo
                        WHERE   ( @fecha >= a.fch_inicio
                                  AND @fecha <= a.fch_cierre
                                )
                                AND L.tiponom = @Tiponom
                                AND ( r.checada IS NULL )
                                AND a.num_conc = 30
                                AND a.empresa = @empresa
                                AND a.nomina = 'VAC'  
                SET @fecha = @fecha + 1

            END
        IF @H = 'T' 
            BEGIN
                SET @Periodo = @Periodo + 1
                SELECT  @inicio = inicio ,
                        @fin = cierre ,
                        @ayo_operacion = ayo_operacion
                FROM    dbo.periodos
                WHERE   periodo = @periodo
                        AND tiponom = @tiponom
                        AND empresa = @empresa
                SET @fecha = @inicio
                WHILE @fecha <= @fin 
                    BEGIN
                        DELETE  dbo.relch_registro
                        FROM    dbo.deducciones AS a
                                LEFT JOIN dbo.relch_registro AS r ON a.empresa = r.empresa
                                                              AND a.codigo = r.codigo
                                                              AND r.fecha = @fecha
                                                              AND ( r.checada IS NULL
                                                              OR r.num_conc = 108
                                                              )
                        WHERE   ( a.fchtermino >= @inicio
                                  AND a.fchinicio <= @fin
                                )
                                AND a.num_conc IN ( 109, 110, 111 )
                                AND a.tiponom = @Tiponom
                                AND a.empresa = @empresa
		
                        INSERT  INTO dbo.relch_registro
                                ( empresa ,
                                  codigo ,
                                  obs ,
                                  checada ,
                                  num_conc ,
                                  importe ,
                                  serial ,
                                  fecha ,
                                  marcafalta ,
                                  dias ,
                                  periodo ,
                                  ayo ,
                                  centro ,
                                  horario ,
                                  tiponom ,
                                  aplicara ,
                                  crf ,
                                  crf2
                                )
                                SELECT  a.empresa ,
                                        a.codigo ,
                                        'VACACIONES' AS obs ,
                                        '00:00:00' AS checada ,
                                        30 ,
                                        0 AS importe ,
                                        1 AS serial ,
                                        @fecha AS fecha ,
                                        '' AS mf ,
                                        1 ,
                                        @periodo ,
                                        @ayo_operacion ,
                                        l.centro ,
                                        CASE WHEN CASE WHEN @H = 'T'
                                                       THEN e.horario
                                                       ELSE l.horario
                                                  END IS NULL THEN l.horario
                                             ELSE CASE WHEN @H = 'T'
                                                       THEN e.horario
                                                       ELSE l.horario
                                                  END
                                        END ,
                                        l.tiponom ,
                                        @fecha ,
                                        @row1 ,
                                        @row2
                                FROM    dbo.kardex AS a
                                        LEFT JOIN dbo.relch_registro AS r ON a.empresa = r.empresa
                                                              AND a.codigo = r.codigo
                                                              AND r.fecha = @fecha
                                        INNER JOIN dbo.empleados AS e ON e.empresa = a.empresa
                                                              AND e.codigo = a.codigo
                                        INNER JOIN dbo.llaves AS l ON l.empresa = e.empresa
                                                              AND l.codigo = e.codigo
                                WHERE   ( @fecha >= a.fch_inicio
                                          AND @fecha <= a.fch_cierre
                                        )
                                        AND L.tiponom = @Tiponom
                                        AND ( r.checada IS NULL
                                              OR r.num_conc = 108
                                            )
                                        AND a.num_conc = 30
                                        AND a.empresa = @empresa
                                        AND a.nomina = 'VAC'  
                                            
                        SET @fecha = @fecha + 1

                    END
            END
        SET DATEFIRST @nSetdatefirst
        SELECT  'SUCCESSFULLY' AS returnTransaction
    END TRY
    BEGIN CATCH

        
        IF ( XACT_STATE() ) = -1
            OR @@TRANCOUNT > 0 
            ROLLBACK TRANSACTION

        SELECT  'ERROR' AS returnTransaction

    END CATCH
    IF @@TRANCOUNT > 0 
        COMMIT TRANSACTION
GO

IF EXISTS ( SELECT  name
                FROM    sysindexes
                WHERE   name = 'ExepEmpresaCodigo' ) 
   DROP INDEX dbo.Relch_exep.ExepEmpresaCodigo
	
GO  

CREATE NONCLUSTERED INDEX ExepEmpresaCodigo   
    ON dbo.relch_exep (Empresa,Codigo);   
GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'ObtenRelojFaltasMasivas')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojFaltasMasivas

GO


CREATE PROCEDURE dbo.ObtenRelojFaltasMasivas
    (
      @empresa udtInteger ,
      @tiponom udtInteger ,
      @row1 udtName ,
      @row2 udtName
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON
                                                                                                                                                                                                                                                                                                                                                                  

    DECLARE @H CHAR(1) ,
        @nSetdatefirst INT ,
        @inicio DATETIME ,
        @fin DATETIME ,
        @periodo INT ,
        @ayo_operacion INT ,
        @fecha DATETIME

    BEGIN TRANSACTION
    BEGIN TRY
    
    

		
        SELECT  @H = hind
        FROM    dbo.relch_paramet
        WHERE   empresa = @empresa

        SELECT  @inicio = inicio ,
                @fin = cierre ,
                @periodo = periodo ,
                @ayo_operacion = ayo_operacion
        FROM    dbo.periodos
        WHERE   estatus = 'A'
                AND tiponom = @tiponom
                AND empresa = @empresa

        SET DATEFIRST 1
        SELECT  @nSetdatefirst = @@DATEFIRST


        SET @fecha = @inicio

        WHILE @fecha <= @fin 
            BEGIN
                PRINT @fecha
                INSERT  INTO dbo.relch_registro
                        ( empresa ,
                          codigo ,
                          obs ,
                          checada ,
                          num_conc ,
                          importe ,
                          serial ,
                          fecha ,
                          marcafalta ,
                          dias ,
                          periodo ,
                          ayo ,
                          centro ,
                          tiponom ,
                          horario ,
                          aplicara ,
                          crf ,
                          crf2
                        )
                        SELECT  a.empresa ,
                                a.codigo ,
                                ( CASE WHEN h.descanso = 'T' THEN 'Descanso'
                                       ELSE 'Falta injustificada'
                                  END ) ,
                                '00:00:00' ,
                                ( CASE WHEN h.descanso = 'T' THEN 0
                                       ELSE 108
                                  END ) ,
                                0 ,
                                ( CASE WHEN h.descanso = 'T' THEN 0
                                       ELSE 1
                                  END ) ,
                                @fecha ,
                                'F' ,
                                1 ,
                                @periodo ,
                                @ayo_operacion ,
                                a.centro ,
                                a.tiponom ,
                                CASE WHEN @H = 'T'
                                     THEN ISNULL(e.horario, a.horario)
                                     ELSE a.horario
                                END AS horario ,
                                @fecha ,
                                @row1 ,
                                @row2
                        FROM    dbo.empleados AS e
                                LEFT JOIN dbo.llaves AS a ON a.empresa = e.empresa
                                                             AND a.codigo = e.codigo
                                LEFT JOIN dbo.relch_registro AS b ON b.codigo = a.codigo
                                                              AND b.empresa = a.empresa
                                                              AND b.fecha = @fecha
                                LEFT JOIN dbo.detalle_horarios AS h ON h.empresa = a.empresa
                                                              AND h.horario = CASE
                                                              WHEN CASE
                                                              WHEN @H = 'T'
                                                              THEN e.horario
                                                              ELSE a.horario
                                                              END IS NULL
                                                              THEN a.horario
                                                              ELSE CASE
                                                              WHEN @H = 'T'
                                                              THEN e.horario
                                                              ELSE a.horario
                                                              END
                                                              END
                                                              AND h.dia_semana = DATEPART(dw,
                                                              @fecha)
                                LEFT JOIN dbo.relch_exep AS ex ON a.empresa = ex.empresa
                                                              AND a.codigo = ex.codigo
                        WHERE   isnull(ex.nochecar,'F') <> 'T'
                                and isnull(ex.aus,'F')<>'T'
								AND ( e.fchalta <= @fecha )
                                AND ( activo = 'S'
                                      AND ( e.ultmov <> 'B'
                                            OR e.ultmov IS NULL
                                          )
                                    )
                                AND a.empresa = @empresa
                                AND a.tiponom = @tiponom
                                AND b.checada IS NULL
                        ORDER BY e.codigo
                        
                SET @fecha = @fecha + 1
            END 	
        IF @H = 'T' 
            BEGIN

                SET @Periodo = @Periodo + 1
                SELECT  @inicio = inicio ,
                        @fin = cierre ,
                        @ayo_operacion = ayo_operacion
                FROM    dbo.periodos
                WHERE   periodo = @periodo
                        AND tiponom = @tiponom
                        AND empresa = @empresa
                SET @fecha = @inicio
                WHILE @fecha <= @fin 
                    BEGIN
                        INSERT  INTO dbo.relch_registro
                                ( empresa ,
                                  codigo ,
                                  obs ,
                                  checada ,
                                  num_conc ,
                                  importe ,
                                  serial ,
                                  fecha ,
                                  marcafalta ,
                                  dias ,
                                  periodo ,
                                  ayo ,
                                  centro ,
                                  tiponom ,
                                  horario ,
                                  aplicara ,
                                  crf ,
                                  crf2
                                )
                                SELECT  a.empresa ,
                                        a.codigo ,
                                        ( CASE WHEN h.descanso = 'T'
                                               THEN 'Descanso'
                                               ELSE 'Falta injustificada'
                                          END ) ,
                                        '00:00:00' ,
                                        ( CASE WHEN h.descanso = 'T' THEN 0
                                               ELSE 108
                                          END ) ,
                                        0 ,
                                        ( CASE WHEN h.descanso = 'T' THEN 0
                                               ELSE 1
                                          END ) ,
                                        @fecha ,
                                        'F' ,
                                        1 ,
                                        @periodo ,
                                        @ayo_operacion ,
                                        a.centro ,
                                        a.tiponom ,
                                        CASE WHEN @H = 'T'
                                             THEN ISNULL(e.horario, a.horario)
                                             ELSE a.horario
                                        END AS horario ,
                                        @fecha ,
                                        @row1 ,
                                        @row2
                                FROM    dbo.empleados AS e
                                        LEFT JOIN dbo.llaves AS a ON a.empresa = e.empresa
                                                              AND a.codigo = e.codigo
                                        LEFT JOIN dbo.relch_registro AS b ON b.codigo = a.codigo
                                                              AND b.empresa = a.empresa
                                                              AND b.fecha = @fecha
                                        LEFT JOIN dbo.detalle_horarios AS h ON h.empresa = a.empresa
                                                              AND h.horario = CASE
                                                              WHEN CASE
                                                              WHEN @H = 'T'
                                                              THEN e.horario
                                                              ELSE a.horario
                                                              END IS NULL
                                                              THEN a.horario
                                                              ELSE CASE
                                                              WHEN @H = 'T'
                                                              THEN e.horario
                                                              ELSE a.horario
                                                              END
                                                              END
                                                              AND h.dia_semana = DATEPART(dw,
                                                              @fecha)
                                        LEFT JOIN dbo.relch_exep AS ex ON a.empresa = ex.empresa
                                                              AND a.codigo = ex.codigo
                                WHERE   ( ex.nochecar <> 'T'
                                          OR ex.nochecar IS NULL
                                        )
                                        AND ( e.fchalta <= @fecha )
                                        AND ( activo = 'S'
                                              AND ( e.ultmov <> 'B'
                                                    OR e.ultmov IS NULL
                                                  )
                                            )
                                        AND a.empresa = @empresa
                                        AND a.tiponom = @tiponom
                                        AND b.checada IS NULL
                                ORDER BY e.codigo
                        SET @fecha = @fecha + 1
                    END 	

            END

        SET DATEFIRST @nSetdatefirst
        SELECT  'SUCCESSFULLY' AS returnTransaction
    END TRY
    BEGIN CATCH

        
        IF ( XACT_STATE() ) = -1
            OR @@TRANCOUNT > 0 
            ROLLBACK TRANSACTION

        SELECT  'ERROR' AS returnTransaction

    END CATCH
    IF @@TRANCOUNT > 0 
        COMMIT TRANSACTION
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'ObtenRelojIncapacidades')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojIncapacidades

GO


CREATE PROCEDURE dbo.ObtenRelojIncapacidades
    (
      @empresa udtInteger ,
      @tiponom udtInteger ,
      @row1 udtName ,
      @row2 udtName
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON


    DECLARE @H CHAR(1) ,
        @nSetdatefirst INT ,
        @inicio DATETIME ,
        @fin DATETIME ,
        @periodo INT ,
        @ayo_operacion INT ,
        @fecha DATETIME


    BEGIN TRANSACTION
    BEGIN TRY
        SELECT  @H = hind
        FROM    dbo.relch_paramet
        WHERE   empresa = @empresa

        SELECT  @inicio = inicio ,
                @fin = cierre ,
                @periodo = periodo ,
                @ayo_operacion = ayo_operacion
        FROM    dbo.periodos
        WHERE   estatus = 'A'
                AND tiponom = @tiponom
                AND empresa = @empresa
                                                                                                                                                                                                                                                                                                                                       

        SELECT  @nSetdatefirst = @@DATEFIRST
        SET DATEFIRST 1

        SET @Fecha = @inicio


        WHILE @fecha <= @fin 
            BEGIN
                PRINT @fecha
                DELETE  dbo.relch_registro
                FROM    dbo.deducciones AS a
                        LEFT JOIN dbo.relch_registro AS r ON a.empresa = r.empresa
                                                             AND a.codigo = r.codigo
                                                             AND r.fecha = @fecha
                                                             AND ( r.checada IS NULL
                                                              OR r.num_conc = 108
                                                              )
                WHERE   ( a.fchtermino >= @inicio
                          AND a.fchinicio <= @fin
                        )
                        AND a.num_conc IN ( 109, 110, 111 )
                        AND a.tiponom = @Tiponom
                        AND a.empresa = @empresa
		
                INSERT  INTO dbo.relch_registro
                        ( empresa ,
                          codigo ,
                          obs ,
                          checada ,
                          num_conc ,
                          importe ,
                          serial ,
                          fecha ,
                          marcafalta ,
                          dias ,
                          periodo ,
                          ayo ,
                          centro ,
                          horario ,
                          tiponom ,
                          aplicara ,
                          crf ,
                          crf2
                        )
                        SELECT  a.empresa ,
                                a.codigo ,
                                ( CASE WHEN a.num_conc = 109 THEN 'Inc.EyG'
                                       WHEN a.num_conc = 110 THEN 'Inc.Mat'
                                       WHEN a.num_conc = 111 THEN 'Inc.RT'
                                  END ) AS obs ,
                                '00:00:00' AS checada ,
                                a.num_conc ,
                                0 AS importe ,
                                1 AS serial ,
                                @fecha AS fecha ,
                                '' AS mf ,
                                1 ,
                                @periodo ,
                                @ayo_operacion ,
                                l.centro ,
                                CASE WHEN CASE WHEN @H = 'T' THEN e.horario
                                               ELSE l.horario
                                          END IS NULL THEN l.horario
                                     ELSE CASE WHEN @H = 'T' THEN e.horario
                                               ELSE l.horario
                                          END
                                END ,
                                l.tiponom ,
                                @fecha ,
                                @row1 ,
                                @row2
                        FROM    dbo.deducciones AS a
                                LEFT JOIN dbo.relch_registro AS r ON a.empresa = r.empresa
                                                              AND a.codigo = r.codigo
                                                              AND r.fecha = @fecha
                                INNER JOIN empleados AS e ON e.empresa = a.empresa
                                                             AND e.codigo = a.codigo
                                INNER JOIN dbo.llaves AS l ON l.empresa = e.empresa
                                                              AND l.codigo = e.codigo
                        WHERE   ( @fecha >= a.fchinicio
                                  AND @fecha <= a.fchtermino
                                )
                                AND a.num_conc IN ( 109, 110, 111 )
                                AND a.tiponom = @Tiponom
                                AND ( r.checada IS NULL
                                      OR r.num_conc = 108
                                    )
                                AND a.empresa = @empresa
                SET @fecha = @fecha + 1

            END
        IF @H = 'T' 
            BEGIN
                SET @Periodo = @Periodo + 1
                SELECT  @inicio = inicio ,
                        @fin = cierre ,
                        @ayo_operacion = ayo_operacion
                FROM    dbo.periodos
                WHERE   periodo = @periodo
                        AND tiponom = @tiponom
                        AND empresa = @empresa
                SET @fecha = @inicio
                WHILE @fecha <= @fin 
                    BEGIN
                        DELETE  dbo.relch_registro
                        FROM    dbo.deducciones AS a
                                LEFT JOIN dbo.relch_registro AS r ON a.empresa = r.empresa
                                                              AND a.codigo = r.codigo
                                                              AND r.fecha = @fecha
                                                              AND ( r.checada IS NULL
                                                              OR r.num_conc = 108
                                                              )
                        WHERE   ( a.fchtermino >= @inicio
                                  AND a.fchinicio <= @fin
                                )
                                AND a.num_conc IN ( 109, 110, 111 )
                                AND a.tiponom = @Tiponom
                                AND a.empresa = @empresa
		
                        INSERT  INTO dbo.relch_registro
                                ( empresa ,
                                  codigo ,
                                  obs ,
                                  checada ,
                                  num_conc ,
                                  importe ,
                                  serial ,
                                  fecha ,
                                  marcafalta ,
                                  dias ,
                                  periodo ,
                                  ayo ,
                                  centro ,
                                  horario ,
                                  tiponom ,
                                  aplicara ,
                                  crf ,
                                  crf2
                                )
                                SELECT  a.empresa ,
                                        a.codigo ,
                                        ( CASE WHEN a.num_conc = 109
                                               THEN 'Inc.EyG'
                                               WHEN a.num_conc = 110
                                               THEN 'Inc.Mat'
                                               WHEN a.num_conc = 111
                                               THEN 'Inc.RT'
                                          END ) AS obs ,
                                        '00:00:00' AS checada ,
                                        a.num_conc ,
                                        0 AS importe ,
                                        1 AS serial ,
                                        @fecha AS fecha ,
                                        '' AS mf ,
                                        a.dias ,
                                        @periodo ,
                                        @ayo_operacion ,
                                        l.centro ,
                                        CASE WHEN CASE WHEN @H = 'T'
                                                       THEN e.horario
                                                       ELSE l.horario
                                                  END IS NULL THEN l.horario
                                             ELSE CASE WHEN @H = 'T'
                                                       THEN e.horario
                                                       ELSE l.horario
                                                  END
                                        END ,
                                        l.tiponom ,
                                        @fecha ,
                                        @row1 ,
                                        @row2
                                FROM    dbo.deducciones AS a
                                        LEFT JOIN dbo.relch_registro AS r ON a.empresa = r.empresa
                                                              AND a.codigo = r.codigo
                                                              AND r.fecha = @fecha
                                        INNER JOIN dbo.empleados AS e ON e.empresa = a.empresa
                                                              AND e.codigo = a.codigo
                                        INNER JOIN dbo.llaves AS l ON l.empresa = e.empresa
                                                              AND l.codigo = e.codigo
                                WHERE   ( @fecha >= a.fchinicio
                                          AND @fecha <= a.fchtermino
                                        )
                                        AND a.num_conc IN ( 109, 110, 111 )
                                        AND a.tiponom = @Tiponom
                                        AND ( r.checada IS NULL
                                              OR r.num_conc = 108
                                            )
                                        AND a.empresa = @empresa
                        SET @fecha = @fecha + 1

                    END
            END
        SET DATEFIRST @nSetdatefirst
        SELECT  'SUCCESSFULLY' AS returnTransaction
    END TRY
    BEGIN CATCH

        
        IF ( XACT_STATE() ) = -1
            OR @@TRANCOUNT > 0 
            ROLLBACK TRANSACTION

        SELECT  'ERROR' AS returnTransaction

    END CATCH
    IF @@TRANCOUNT > 0 
        COMMIT TRANSACTION
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'ObtenRelojPrimaDominical')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojPrimaDominical

GO


CREATE PROCEDURE dbo.ObtenRelojPrimaDominical
    (
      @empresa udtInteger ,
      @tiponom udtInteger ,
      @row1 udtName ,
      @row2 udtName
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON

    DECLARE @nSetdatefirst INT

    DECLARE @H CHAR(1) ,
        @horario INT ,
        @periodo INT ,
        @ayo INT ,
        @inicio DATETIME ,
        @cierre DATETIME

    BEGIN TRANSACTION
    BEGIN TRY
        SELECT  @nSetdatefirst = @@DATEFIRST --Primer Dia de la Semana Lunes

        SET DATEFIRST 1

        SELECT  @H = ISNULL(hind, 'F')
        FROM    relch_paramet
        WHERE   empresa = @empresa 


        PRINT 'Prima Dominical'

        SELECT  @inicio = inicio ,
                @cierre = cierre ,
                @periodo = periodo ,
                @ayo = ayo_operacion
        FROM    dbo.periodos
        WHERE   empresa = @empresa
                AND tiponom = @tiponom
                AND estatus = 'A'


        DELETE  dbo.relch_registro
        WHERE   empresa = @empresa
				AND DATEPART(dw, aplicara) = 7
                AND num_conc = 9
                AND tiponom = @tiponom
                AND ( aplicara >= @inicio
                      AND aplicara <= @cierre
                    )
        INSERT  INTO dbo.relch_registro
                ( empresa ,
                  codigo ,
                  serial ,
                  checada ,
                  fecha ,
                  num_conc ,
                  obs ,
                  importe ,
                  tiempo ,
                  comedor ,
                  EoS ,
                  periodo ,
                  ayo ,
                  terminal ,
                  tiponom ,
                  centro ,
                  horario ,
                  aplicara ,
                  crf ,
                  crf2
                )
                SELECT  r.empresa ,
                        r.codigo ,
                        99 AS serial ,
                        '00:00:00' ,
                        r.aplicara ,
                        9 AS num_conc ,
                        'Prima Dominical' AS obs ,
                        0.00 AS importe ,
                        0 AS tiempo ,
                        'N' ascomedor ,
                        'E' AS obs ,
                        r.periodo ,
                        r.ayo ,
                        r.terminal ,
                        r.tiponom ,
                        r.centro ,
                        r.horario ,
                        r.aplicara ,
                        @row1 ,
                        @row2
                FROM    dbo.relch_registro AS r
                WHERE   r.empresa = @empresa
                        AND r.tiponom = @tiponom
                        AND ( r.aplicara >= @inicio
                              AND r.aplicara <= @cierre
                            )
                        AND NOT r.num_conc IN ( 108, 109, 110, 111 )
                        AND r.obs <> 'Descanso'
                        AND DATEPART(dw, r.aplicara) = 7
                GROUP BY r.empresa ,
                        r.codigo ,
                        r.aplicara ,
                        r.periodo ,
                        r.ayo ,
                        r.terminal ,
                        r.tiponom ,
                        r.centro ,
                        r.horario ,
                        r.aplicara
		
        IF @H = 'T' 
            BEGIN
				declare @nPer int = @periodo
				declare @nAyo int = @ayo
                if @periodo = 1
				begin
					set @nPer = (select max(periodo) from dbo.periodos where empresa=@empresa and tiponom=@tiponom and ayo_operacion=@ayo)
					set @nAyo = @ayo - 1 
				end
				SELECT  @inicio = inicio ,
                        @cierre = cierre
                FROM    dbo.periodos
                WHERE   empresa = @empresa
                        AND tiponom = @tiponom
                        AND periodo = @nPer
                        AND ayo_operacion = @nAyo


                DELETE  dbo.relch_registro
                WHERE   empresa = @empresa
						AND DATEPART(dw, aplicara) = 7
                        AND num_conc = 9
                        AND tiponom = @tiponom
                        AND ( aplicara >= @inicio
                              AND aplicara <= @cierre
                            )
                INSERT  INTO dbo.relch_registro
                        ( empresa ,
                          codigo ,
                          serial ,
                          checada ,
                          fecha ,
                          num_conc ,
                          obs ,
                          importe ,
                          tiempo ,
                          comedor ,
                          EoS ,
                          periodo ,
                          ayo ,
                          terminal ,
                          tiponom ,
                          centro ,
                          horario ,
                          aplicara ,
                          crf ,
                          crf2
                        )
                        SELECT  r.empresa ,
                                r.codigo ,
                                99 AS serial ,
                                '00:00:00' ,
                                r.aplicara ,
                                9 AS num_conc ,
                                'Prima Dominical' AS obs ,
                                0.00 AS importe ,
                                0 AS tiempo ,
                                'N' ascomedor ,
                                'E' AS obs ,
                                r.periodo ,
                                r.ayo ,
                                r.terminal ,
                                r.tiponom ,
                                r.centro ,
                                r.horario ,
                                r.aplicara ,
                                @row1 ,
                                @row2
                        FROM    dbo.relch_registro AS r
                        WHERE   r.empresa = @empresa
                                AND r.tiponom = @tiponom
                                AND ( r.aplicara >= @inicio
                                      AND r.aplicara <= @cierre
                                    )
                                AND NOT r.num_conc IN ( 108, 109, 110, 111 )
                                AND r.obs <> 'Descanso'
                                AND DATEPART(dw, r.aplicara) = 7
                        GROUP BY r.empresa ,
                                r.codigo ,
                                r.aplicara ,
                                r.periodo ,
                                r.ayo ,
                                r.terminal ,
                                r.tiponom ,
                                r.centro ,
                                r.horario ,
                                r.aplicara

            END

        SET DATEFIRST @nSetdatefirst
        SELECT  'SUCCESSFULLY' AS returnTransaction
    END TRY
    BEGIN CATCH

        
        IF ( XACT_STATE() ) = -1
            OR @@TRANCOUNT > 0 
            ROLLBACK TRANSACTION

        SELECT  'ERROR' AS returnTransaction

    END CATCH
    IF @@TRANCOUNT > 0 
        COMMIT TRANSACTION
GO



IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'ObtenRelojHorario')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojHorario

GO


CREATE PROCEDURE dbo.ObtenRelojHorario
    (
      @Empresa udtInteger ,
      @Codigo udtInteger ,
      @horario udtInteger ,
      @dia udtInteger
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON

    SELECT  a.horario ,
            a.dia_semana AS nodia ,
            b.media_hora AS redon ,
            a.entra1 ,
            a.sale1 ,
            a.entra2 ,
            a.sale2 ,
            a.descanso AS desca ,
            noc = ( CASE WHEN a.descanso = 'T'
                              AND c.turno = 2 THEN 'T'
                         WHEN a.descanso = 'T'
                              AND c.turno = 1 THEN 'F'
                         WHEN a.descanso = 'T'
                              AND c.turno = 3 THEN 'F'
                         WHEN a.descanso = 'T'
                              AND c.turno = 4 THEN 'F'
                         WHEN a.descanso = 'F' THEN a.turno_noc
                    END ) ,
            ISNULL(b.tolera, 0) AS tole ,
            ISNULL(b.tmp_ant_ent, 'F') AS texent ,
            ISNULL(b.comedor, 'F') AS come ,
            ISNULL(b.mincomedor, 0) AS mincome ,
            ISNULL(b.min_tmp_extra, 0) minext ,
            ( SELECT    codigo
              FROM      relch_exep
              WHERE     empresa = @empresa
                        AND codigo = @Codigo
            ) AS codigo ,
            ( SELECT    nochecar
              FROM      relch_exep
              WHERE     empresa = @empresa
                        AND codigo = @Codigo
            ) AS nchec ,
            ( SELECT    tarde
              FROM      relch_exep
              WHERE     empresa = @empresa
                        AND codigo = @Codigo
            ) AS tard ,
            ( SELECT    mintarde
              FROM      relch_exep
              WHERE     empresa = @empresa
                        AND codigo = @Codigo
            ) AS mtard ,
            ( SELECT    chora
              FROM      relch_exep
              WHERE     empresa = @empresa
                        AND codigo = @Codigo
            ) AS chor ,
            ( SELECT    aus
              FROM      relch_exep
              WHERE     empresa = @empresa
                        AND codigo = @Codigo
            ) AS aus ,
            ( SELECT    notmp_extra
              FROM      relch_exep
              WHERE     empresa = @empresa
                        AND codigo = @Codigo
            ) AS ntmpext ,
            ( SELECT    hor_esp
              FROM      relch_exep
              WHERE     empresa = @empresa
                        AND codigo = @Codigo
            ) AS hesp ,
            ( SELECT    hcomida
              FROM      relch_exep
              WHERE     empresa = @empresa
                        AND codigo = @Codigo
            ) AS hcome ,
            ( SELECT    entra1
              FROM      relch_exep
              WHERE     empresa = @empresa
                        AND codigo = @Codigo
            ) AS entra1 ,
            ( SELECT    sale1
              FROM      relch_exep
              WHERE     empresa = @empresa
                        AND codigo = @Codigo
            ) AS sale1 ,
            ( SELECT    entra2
              FROM      relch_exep
              WHERE     empresa = @empresa
                        AND codigo = @Codigo
            ) AS entra2 ,
            ( SELECT    sale2
              FROM      relch_exep
              WHERE     empresa = @empresa
                        AND codigo = @Codigo
            ) AS sale2 ,
            ISNULL(( SELECT sueldo = ( CASE WHEN tiposal = 1 THEN saldiaint
                                            ELSE sueldo
                                       END )
                     FROM   empleados
                     WHERE  empresa = @empresa
                            AND codigo = @Codigo
                   ), 0) AS sueldo ,
            ISNULL(c.hrsturno, 0) AS horas ,
            ISNULL(a.factor, 0) AS factor ,
            a.turno_noc ,
            ISNULL(( SELECT hcomida
                     FROM   relch_exep
                     WHERE  empresa = @empresa
                            AND codigo = @Codigo
                   ), '') AS corrido ,
            RTRIM(LTRIM(STR(c.horario))) + ' ' + RTRIM(LTRIM(c.nombre)) AS nombreHorario
    FROM    dbo.horarios_catalogo AS c
            INNER JOIN dbo.detalle_horarios AS a ON c.empresa = a.empresa
                                                    AND c.horario = @horario
            LEFT JOIN dbo.relch_paramet AS b ON a.empresa = b.empresa
    WHERE   a.empresa = @empresa
            AND a.horario = @horario
            AND a.dia_semana = @dia

GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'ModificaRelojRegistro')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ModificaRelojRegistro

GO


CREATE PROCEDURE dbo.ModificaRelojRegistro
    (
      @empresa udtInteger ,
      @codigo udtInteger ,
      @num_conc udtInteger ,
      @obs udtName ,
      @checada udtName ,
      @importe udtNumeric10_2 ,
      @fecha udtDateTime ,
      @serial udtLong ,
      @id udtLong ,
      @marcafalta udtName ,
      @row1 udtName ,
      @row2 udtName ,
      @tiempo udtNumeric10_2
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON

    BEGIN TRANSACTION
    BEGIN TRY
        UPDATE  dbo.relch_registro
        SET     obs = @obs ,
                num_conc = @num_conc ,
                checada = @checada ,
                importe = @importe ,
                marcafalta = @marcafalta ,
                crf = @row1 ,
                crf2 = @row2 ,
                tiempo = @tiempo
        WHERE   empresa = @empresa
                AND codigo = @codigo
                AND fecha = @fecha
                AND serial = @serial
                AND id = @id

        SELECT  'SUCCESSFULLY' AS returnTransaction
    END TRY
    BEGIN CATCH

        
        IF ( XACT_STATE() ) = -1
            OR @@TRANCOUNT > 0 
            ROLLBACK TRANSACTION

        SELECT  'ERROR' AS returnTransaction

    END CATCH
    IF @@TRANCOUNT > 0 
        COMMIT TRANSACTION
GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenRelojPantallaReloj')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojPantallaReloj
GO


CREATE PROCEDURE dbo.ObtenRelojPantallaReloj ( @empresa udtInteger )

    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 


    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    SET @debug = 0
    SET @whereClauseUsed = 0
    SET @whereClause = ''
    SET @orderByClause = ''
    
    
    IF @empresa > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'a.empresa = '
                + LTRIM(RTRIM(STR(@empresa)))
                 
        END
        
    

    SET @selectClause = 'SELECT  MAX(a.rutalogo)AS Logo,MAX(a.mostrar) AS Mostrar '
    SET @fromClause = ' FROM dbo.relch_paramet AS a '
					    
					    
					    
    IF @debug = 0 
        BEGIN 
            EXEC(
            @selectClause + @fromClause
            )
        END
    ELSE 
        BEGIN
            PRINT ( @selectClause + @fromClause )
        END
        
        
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenRelojTotalComidas')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojTotalComidas
GO


CREATE PROCEDURE dbo.ObtenRelojTotalComidas
    (
      @empresa udtInteger ,
      @fecha udtDateTime 
    )

    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 


    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    SET @debug = 0
    SET @whereClauseUsed = 0
    SET @whereClause = ''
    SET @orderByClause = ''
    
    
    IF @empresa > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'a.empresa = '
                + LTRIM(RTRIM(STR(@empresa)))
                 
        END
        
    IF @whereClauseUsed = 0 
        BEGIN
	       
            SET @whereClause = @whereClause + 'WHERE '
            SET @whereClauseUsed = 1

        END
    ELSE 
        SET @whereClause = @whereClause + ' AND '
	                 
    SET @whereClause = @whereClause + 'a.fecha = '''
        + CONVERT(NVARCHAR(30), @fecha, 112) + ''' '
    

    SET @selectClause = 'SELECT  SUM(isnull(a.comidas,0))AS Comidas '
    SET @fromClause = ' FROM dbo.relch_comidas AS a '
					    
					    
					    
    IF @debug = 0 
        BEGIN 
            EXEC(
            @selectClause + @fromClause
            )
        END
    ELSE 
        BEGIN
            PRINT ( @selectClause + @fromClause )
        END
        
        
GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenRelojCatalogoCentros')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojCatalogoCentros
GO

CREATE PROCEDURE dbo.ObtenRelojCatalogoCentros ( @empresa udtInteger )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
	
    SELECT  RTRIM(LTRIM(c.centro)) + ' ' + RTRIM(LTRIM(c.nomdepto)) AS horario
    FROM    dbo.empleados AS a
            INNER JOIN dbo.Llaves AS b ON a.empresa = b.empresa
                                          AND a.codigo = b.codigo
            INNER JOIN dbo.centros AS c ON b.centro = c.centro
                                           AND b.empresa = c.empresa
    WHERE   b.empresa = @empresa
            AND NOT b.centro IN ( '', '99999999999997' )
            AND a.activo = 'S'
    GROUP BY c.centro ,
            c.nomdepto

GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenRelojPermisosAdmin')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenRelojPermisosAdmin
GO

CREATE PROCEDURE dbo.ObtenRelojPermisosAdmin ( @cUsuario udtName )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    
    DECLARE @idPerfil udtInteger
    
    IF EXISTS ( SELECT  *
                FROM    dbo.perfil_usuarios AS a
                        INNER JOIN dbo.perfiles AS b ON a.idperfil = b.idperfil
                WHERE   a.usuario = @cUsuario
                        AND b.sistema = 'RC' ) 
        BEGIN
            SET @idPerfil = ( SELECT    b.idperfil
                              FROM      dbo.perfil_usuarios AS a
                                        INNER JOIN dbo.perfiles AS b ON a.idperfil = b.idperfil
                              WHERE     a.usuario = @cUsuario
                                        AND b.sistema = 'RC'
                            )
    
            SELECT  ISNULL(( SELECT 'S'
                             FROM   dbo.perfil_funcion
                             WHERE  idperfil = @idPerfil
                                    AND opcion = 'A1'
                           ), 'N') AS Consultar ,
                    ISNULL(( SELECT 'S'
                             FROM   dbo.perfil_funcion
                             WHERE  idperfil = @idPerfil
                                    AND opcion = 'A2'
                           ), 'N') AS Modificar ,
                    ISNULL(( SELECT 'S'
                             FROM   dbo.perfil_funcion
                             WHERE  idperfil = @idPerfil
                                    AND opcion = 'A3'
                           ), 'N') AS VerImportes ,
                    ISNULL(( SELECT 'S'
                             FROM   dbo.perfil_funcion
                             WHERE  idperfil = @idPerfil
                                    AND opcion = 'A4'
                           ), 'N') AS Parametros ,
                    ISNULL(( SELECT 'S'
                             FROM   dbo.perfil_funcion
                             WHERE  idperfil = @idPerfil
                                    AND opcion = 'A5'
                           ), 'N') AS Importar ,
                    ISNULL(( SELECT 'S'
                             FROM   dbo.perfil_funcion
                             WHERE  idperfil = @idPerfil
                                    AND opcion = 'A6'
                           ), 'N') AS Fotos ,
                    ISNULL(( SELECT 'S'
                             FROM   dbo.perfil_funcion
                             WHERE  idperfil = @idPerfil
                                    AND opcion = 'A7'
                           ), 'N') AS Mensajes ,
                    ISNULL(( SELECT 'S'
                             FROM   dbo.perfil_funcion
                             WHERE  idperfil = @idPerfil
                                    AND opcion = 'A8'
                           ), 'N') AS Horario ,
                    ISNULL(( SELECT 'S'
                             FROM   dbo.perfil_funcion
                             WHERE  idperfil = @idPerfil
                                    AND opcion = 'A9'
                           ), 'N') AS Reportes
        END
    ELSE 
        BEGIN
            SELECT  'N' AS Consultar ,
                    'N' AS Modificar ,
                    'N' AS VerImportes ,
                    'N' AS Parametros ,
                    'N' AS Importar ,
                    'N' AS Fotos ,
                    'N' AS Mensajes ,
                    'N' AS Horario ,
                    'N' AS Reportes
        END
        
    
    
GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.obtenRelojReporte003')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.obtenRelojReporte003
GO

CREATE PROCEDURE dbo.obtenRelojReporte003(@empresa udtInteger ,
    @fecha1 udtDateTime ,
    @fecha2 udtDateTime ,
    @tiponom udtInteger ,
    @filtroPor udtStringSize128 ,
    @filtroValor udtStringSize128 ,
    @grupo udtName ,
    @codigos udtName)

AS

SET NOCOUNT ON 
SET DATEFORMAT MDY

--SET @grupo = 'S'
--SET @fecha1 = '20140101'
--SET @fecha2 = '20140116'
--SET @empresa = 1 
--SET @tiponom = 4
--SET @codigos = ' '
--'4,16'

DECLARE @endDate udtDateTime
DECLARE @date udtDateTime
DECLARE @encabezado udtStringSize8000
DECLARE @campos udtStringSize8000
SET @date = @fecha1
SET @encabezado = ''
SET @campos = ''

DECLARE @tCodigos AS TABLE
    (
      empresa udtInteger ,
      codigo udtInteger
    )


IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'tEmpleados')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE dbo.tEmpleados
            (
              empresa udtInteger ,
              codigo udtInteger,
			  cod udtInteger,
			  nombre udtStringSize255,
			  fecha udtDateTime,
			  grupo udtStringSize128,
			  nombreGrupo udtStringSize128,
			  serial udtInteger
            )

    END
    
DELETE dbo.tEmpleados     
IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'tmp_rel_registros')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE dbo.tmp_rel_registros
            (
              empresa udtInteger ,
              codigo udtInteger,
			  cod udtInteger,
			  checada udtStringSize255,
			  fechaChecada udtDateTime,
			  fecha udtStringSize15,
			  serial udtInteger
            )

    END
DELETE dbo.tmp_rel_registros  

IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'tmp_rel_fechas')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE dbo.tmp_rel_fechas
            (
              empresa udtInteger ,
              fecha udtDateTime
            )

    END
DELETE dbo.tmp_rel_fechas  

WHILE @date <= @fecha2 
    BEGIN 
        SET @encabezado = @encabezado + '[' + dbo.PadL(DAY(@date), '', 2, '0')
            + '/' + dbo.PadL(MONTH(@date), '', 2, '0') + '] AS ['
            + dbo.PadL(DAY(@date), '', 2, '0') + '/' + dbo.PadL(MONTH(@date),
                                                              '', 2, '0')
            + '], '
        SET @campos = @campos + '[' + dbo.PadL(DAY(@date), '', 2, '0')
            + '/' + dbo.PadL(MONTH(@date), '', 2, '0') + '], '
            
		INSERT INTO dbo.tmp_rel_fechas 
		SELECT @empresa, @date   
		
        SET @date = @date + 1 
    END 

DECLARE @select AS udtStringSize8000




        SET @select = 'select distinct a.empresa, a.codigo '
        + ' from dbo.relch_registro as a inner join dbo.llaves as b on a.empresa=b.empresa and a.codigo=b.codigo where a.empresa=' + STR(@empresa)
        + ' AND a.aplicara BETWEEN ''' + CONVERT(varchar(20),@fecha1,112) + ''' and ''' + CONVERT(varchar(20),@fecha2,112)  +''' '
        + CASE WHEN LEN(@filtroPor) > 0
               THEN ' AND '
                    + CASE WHEN @filtroPor = 'S'
                           THEN ' b.supervisor = ' + @filtroValor
                           WHEN @filtroPor = 'D'
                           THEN ' b.centro = ' + '''' + @filtroValor + ''''
                           WHEN @filtroPor = 'L'
                           THEN ' b.linea = ' + @filtroValor
                           WHEN @filtroPor = 'H'
                           THEN ' b.horario = ' + @filtroValor
                           ELSE ' '
                      END
               ELSE ''
          END + CASE WHEN LEN(@codigos) > 0
                     THEN ' AND a.codigo BETWEEN ' + @codigos
                     ELSE ' '
                END +
          CASE WHEN @tiponom > 0
                     THEN ' AND a.tiponom = ' + RTRIM(LTRIM(STR(@tiponom)))
                     ELSE ' '
                END
                
                INSERT INTO @tcodigos
                EXEC ( @select
                    )
--print ( @select)
--                   
--SELECT * FROM @tCodigos

INSERT INTO dbo.tEmpleados
        ( empresa, codigo, cod, nombre,fecha, grupo,nombreGrupo, serial )
SELECT a.empresa,a.codigo,a.codigo AS cod,
	RTRIM(LTRIM(b.ap_paterno)) + ' ' + RTRIM(LTRIM(b.ap_materno)) + ' ' + RTRIM(LTRIM(b.nombre)) AS nombre,
	d.fecha, 
	CASE WHEN @grupo = ''
                         THEN REPLICATE('0',
                                        15 - LEN(LTRIM(RTRIM(STR(L.codigo)))))
                              + LTRIM(RTRIM(STR(L.codigo)))
                         WHEN @grupo = 'S'
                         THEN REPLICATE('0',
                                        15 - LEN(LTRIM(RTRIM(STR(L.supervisor)))))
                              + LTRIM(RTRIM(STR(L.supervisor)))
                         WHEN @grupo = 'L'
                         THEN REPLICATE('0',
                                        15 - LEN(LTRIM(RTRIM(STR(L.linea)))))
                              + LTRIM(RTRIM(STR(L.linea)))
                         WHEN @grupo = 'H'
                         THEN REPLICATE('0',
                                        15 - LEN(LTRIM(RTRIM(STR(L.horario)))))
                              + LTRIM(RTRIM(STR(L.horario)))
                         WHEN @grupo = 'D'
                         THEN REPLICATE('0', 15 - LEN(LTRIM(RTRIM(L.centro))))
                              + LTRIM(RTRIM(L.centro))
                    END AS grupo,
	CASE WHEN @grupo = ''
                         THEN ''
                         WHEN @grupo = 'S'
                         THEN LTRIM(RTRIM(s.nombre))
                         WHEN @grupo = 'L'
                         THEN LTRIM(RTRIM(li.nombre))
                         WHEN @grupo = 'H'
                         THEN LTRIM(RTRIM(h.nombre))
                         WHEN @grupo = 'D'
                         THEN LTRIM(RTRIM(c.nomdepto))
                    END AS nombreGrupo,
	1 AS sec
FROM dbo.tmp_rel_fechas  AS d
INNER JOIN @tCodigos AS a ON d.empresa=a.empresa
INNER JOIN dbo.empleados AS b ON a.empresa = b.empresa AND a.codigo = b.codigo
INNER JOIN dbo.Llaves AS l ON b.empresa = L.empresa AND b.codigo = L.codigo
LEFT JOIN dbo.relch_lineas AS li ON L.empresa = li.empresa AND L.linea = li.linea
INNER JOIN dbo.centros AS c ON L.centro = c.centro AND L.empresa = c.empresa
INNER JOIN dbo.horarios_catalogo AS h ON L.empresa = h.empresa AND L.horario = h.horario
INNER JOIN dbo.supervisores AS s ON L.empresa = s.empresa AND L.supervisor = s.supervisor
ORDER BY a.empresa,a.codigo

INSERT INTO dbo.tEmpleados
        ( empresa, codigo, cod, nombre, fecha, grupo,nombreGrupo, serial )
SELECT a.empresa,a.codigo,NULL AS cod,
	LTRIM(RTRIM(t.actividad)) AS nombre,
	d.fecha,
	CASE WHEN @grupo = ''
                         THEN REPLICATE('0',
                                        15 - LEN(LTRIM(RTRIM(STR(L.codigo)))))
                              + LTRIM(RTRIM(STR(L.codigo)))
                         WHEN @grupo = 'S'
                         THEN REPLICATE('0',
                                        15 - LEN(LTRIM(RTRIM(STR(L.supervisor)))))
                              + LTRIM(RTRIM(STR(L.supervisor)))
                         WHEN @grupo = 'L'
                         THEN REPLICATE('0',
                                        15 - LEN(LTRIM(RTRIM(STR(L.linea)))))
                              + LTRIM(RTRIM(STR(L.linea)))
                         WHEN @grupo = 'H'
                         THEN REPLICATE('0',
                                        15 - LEN(LTRIM(RTRIM(STR(L.horario)))))
                              + LTRIM(RTRIM(STR(L.horario)))
                         WHEN @grupo = 'D'
                         THEN REPLICATE('0', 15 - LEN(LTRIM(RTRIM(L.centro))))
                              + LTRIM(RTRIM(L.centro))
                    END AS grupo,
	CASE WHEN @grupo = ''
                         THEN ''
                         WHEN @grupo = 'S'
                         THEN LTRIM(RTRIM(s.nombre))
                         WHEN @grupo = 'L'
                         THEN LTRIM(RTRIM(li.nombre))
                         WHEN @grupo = 'H'
                         THEN LTRIM(RTRIM(h.nombre))
                         WHEN @grupo = 'D'
                         THEN LTRIM(RTRIM(c.nomdepto))
                    END AS nombreGrupo,
	2 AS sec
FROM dbo.tmp_rel_fechas  AS d
INNER JOIN @tCodigos AS a ON d.empresa=a.empresa
INNER JOIN dbo.Llaves AS l ON a.empresa = l.empresa AND a.codigo = l.codigo
LEFT JOIN dbo.relch_lineas AS li ON L.empresa = li.empresa AND L.linea = li.linea
INNER JOIN dbo.centros AS c ON L.centro = c.centro AND L.empresa = c.empresa
INNER JOIN dbo.horarios_catalogo AS h ON L.empresa = h.empresa AND L.horario = h.horario
INNER JOIN dbo.supervisores AS s ON L.empresa = s.empresa AND L.supervisor = s.supervisor
INNER JOIN dbo.tabulador AS t ON l.empresa = t.empresa AND l.ocupacion = t.ocupacion
ORDER BY a.empresa,a.codigo

IF LEN(@grupo)>0
BEGIN
INSERT INTO dbo.tEmpleados
        ( empresa, codigo, cod, nombre, fecha, grupo,nombreGrupo, serial )
SELECT empresa,NULL,NULL, nombreGrupo,NULL,grupo,nombreGrupo,1
FROM dbo.tEmpleados
GROUP BY empresa,grupo,nombreGrupo
END

--SELECT * FROM dbo.tEmpleados ORDER BY empresa,codigo,serial

INSERT INTO dbo.tmp_rel_registros
        ( empresa ,
          codigo ,
          cod ,
          checada ,
          fechaChecada,
          fecha ,
          serial
        )
SELECT  a.empresa ,
		a.codigo,
        a.codigo AS Cod,
        CASE WHEN a.obs = 'DESCANSO' THEN 'D'
             WHEN a.num_conc = 108 THEN 'F'
             WHEN a.num_conc = 30 THEN 'V'
             ELSE a.checada
        END AS checada ,
        a.aplicara,
        dbo.PadL(DAY(a.aplicara), '', 2, '0') + '/'
        + dbo.PadL(MONTH(a.aplicara), '', 2, '0') AS dia ,
		CASE WHEN a.EoS = 'E' OR a.EoS = '1' THEN 1 WHEN a.EoS = 'S' OR a.EoS = '2' THEN 2 END 
FROM    dbo.relch_registro AS a 
INNER JOIN @tCodigos AS b ON a.empresa = b.empresa AND a.codigo = b.codigo
WHERE   ( a.comedor = 'F'
          OR a.comedor IS NULL
        )
        AND ( a.aplicara >= @fecha1
              AND a.aplicara <= @fecha2
            )
        AND ( a.alerta IS NULL
              OR a.alerta = ''
            )
ORDER BY a.codigo ASC 

SET @campos = SUBSTRING(@campos,1,LEN(@campos)-1)
SET @encabezado = SUBSTRING(@encabezado,1,LEN(@encabezado)-1)

                    
EXEC(
    '(SELECT cod as Codigo,nombre as Nombre, '+@encabezado+'
    FROM
    (SELECT a.empresa,a.grupo,a.nombreGrupo,a.codigo as codEmp,a.cod,cast(a.nombre as varchar(70))as nombre,b.fecha,cast(b.checada as varchar(5)) as checada,a.serial
    FROM dbo.tEmpleados as a
	left JOIN  dbo.tmp_rel_registros AS b ON b.empresa=a.empresa and b.codigo=a.codigo AND b.fechachecada=a.fecha AND a.serial = b.serial
    ) AS relch_reporte 
    PIVOT
    (
    max(checada)
    FOR fecha IN ('+@campos+')
    ) AS PivotTable) order by grupo, codEmp,serial ')    
    
    
GO

